-- Create the new tables
CREATE TABLE page (
	pid INT(8) AUTO_INCREMENT PRIMARY KEY,
	LATEST INT(8) DEFAULT NULL,
	title VARCHAR(255) UNIQUE,
	is_new TINYINT(1) NOT NULL DEFAULT 0,
	is_redirect TINYINT(1) NOT NULL DEFAULT 0
) ENGINE=InnoDB,CHARACTER SET utf8;
 
CREATE TABLE revision (
	rid INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	page INT DEFAULT NULL,
	user VARCHAR(255) NOT NULL,
	minor_edit TINYINT(1) NOT NULL,
	timestamp CHAR(14) NOT NULL
) ENGINE=InnoDB, CHARACTER SET utf8;

CREATE TABLE text (
	tid INT(8) PRIMARY KEY,
	text MEDIUMBLOB
) ENGINE=InnoDB, CHARACTER SET utf8;


-- Fill the new tables
-- Fill REVISION. PAGE remains unbound until PAGE.PID is generated
insert into REVISION (RID, PAGE, USER, MINOR_EDIT, TIMESTAMP)
	select CID, NULL, USER, MINOR_EDIT, TIMESTAMP from CUR;
insert into REVISION (RID, PAGE, USER, MINOR_EDIT, TIMESTAMP)
	select OID, NULL, USER, MINOR_EDIT, TIMESTAMP from OLD;
-- Fill PAGE. PID is auto-generated
-- Notice that LATEST=REVISION.RID[latest]=CUR.CID.
-- Notice that the page information in OLD is not transferred (redundant)
insert into PAGE(PID,LATEST,TITLE,IS_NEW,IS_REDIRECT)
	select 0,CID,TITLE,IS_NEW,IS_REDIRECT FROM CUR;

-- Resolve pending FK REVISION.LATEST=PAGE.PID
update REVISION r, PAGE p, CUR c set r.PAGE=p.PID where r.RID=c.CID and c.TITLE=p.TITLE;
update REVISION r, PAGE p, OLD o set r.PAGE=p.PID where r.RID=o.OID and o.TITLE=p.TITLE;

-- Fill TEXT
insert into TEXT(TID,TEXT) select CID, TEXT from CUR;
insert into TEXT(TID,TEXT) select OID, TEXT from OLD;

-- Clear the old tables
drop table CUR;
drop table OLD;

