/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package uwiki.evol;

import java.lang.reflect.Method;
import java.sql.*;
import java.util.List;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.StatementAdaptorContext.SetParameter;
import ddbc.cpn2.impl.CpPreparedStatement;
import ddbc.cpn2.impl.CpStatement;
import ddbc.cpn2.st.BaseHandler;
import ddbc.commons.jdbc.JdbcUtils;
import ddbc.commons.util.FCollections;

public class HandlerCmdEdit41in42 extends BaseHandler {
	protected static final String STATE_CMDEDIT_INSERT_OLD = "cmdEdit-insertOld";
	protected static final String STATE_CMDEDIT_DELETE_CUR = "cmdEdit-deleteCur";
	
	protected static final String STATEMENT_41_INSERT_OLD = JdbcUtils.normalizeString(
		"insert into old(oid, title, user, minor_edit, text, timestamp) " +
		"select cid, title, user, minor_edit, text, timestamp from cur where title=?");
	protected static final String STATEMENT_41_DELETE_CUR = JdbcUtils.normalizeString("delete from cur where title=?");
	protected static final String STATEMENT_41_INSERT_CUR = JdbcUtils.normalizeString(
		"insert into cur (title, user, minor_edit, text," +
		" timestamp, is_new, is_redirect) values(?,?,?,?,?,?,?)");

//	// (returning rid into $rid)
//	protected static final String STATEMENT_42_INSERT_REVISION = "insert into REVISION (USER, MINOR_EDIT, TIMESTAMP, PAGE) values(?,?,?, 0)";
//	// (returning pid into $pid)
//	protected static final String STATEMENT_42_INSERT_PAGE = "insert into PAGE (LATEST, TITLE, IS_NEW, IS_REDIRECT) values($rid, $title, 1, $r) on duplicate key set LATEST=$rid, is_new=0";
//	protected static final String STATEMENT_42_INSERT_TEXT = "insert into TEXT (TID, TEXT) values ($rid, $tx)";
//	protected static final String STATEMENT_42_UPDATE_REVISION_FK = "update REVISION set PAGE=$pid where RID = $rid";

	private static Logger s_logger = LoggerFactory.getLogger(HandlerCmdEdit41in42.class);

	public HandlerCmdEdit41in42(Map<String, String> attributes,
			String leadStrData) {
		super(attributes, "");
	}

	
	/* (non-Javadoc)
	 * @see ddbc.cpn2.st.BaseHandler#applyStart(ddbc.cpn2.impl.CpPreparedStatement, ddbc.cpn2.JdbcMethod, java.lang.String, java.lang.Object[])
	 */
	@Override
	public void applyStart(CpPreparedStatement ps, JdbcMethod method,
			String sql, Object... moreParams) throws SQLException {
		String l_state = getState(ps);
		String l_strStatement = getStrStatement(ps);
		if (l_state.equals("initial") && l_strStatement.equals(STATEMENT_41_INSERT_OLD)) {
			// Ignore statement
			// TT_LOW Consider "dormant payload" scenario.
		} else if (l_state.equals(STATE_CMDEDIT_INSERT_OLD) && l_strStatement.equals(STATEMENT_41_DELETE_CUR)) {
			// Ignore statement
		} else if (l_state.equals(STATE_CMDEDIT_DELETE_CUR) && l_strStatement.equals(STATEMENT_41_INSERT_CUR)) {
			// The insert is spawned into many sentences.
			// The first of the sentences doesn't get all the parameters, so we don't start it
			/// super.applyStart(ps, method, STATEMENT_42_INSERT_REVISION, moreParams);
		} else {
			s_logger.error("Unexpected statement and state: \"{}\" @{}", l_strStatement, l_state);
			throw new SQLException("Unexpected statement @ state. Look up logs for details.");
		}
	}
	
	@Override
	public void applyParam(CpPreparedStatement ps, JdbcMethod method,
			int paramIdx, Object... moreParams) throws SQLException {
		// Do nothing. No handler should be appended.
	}
	
	/* (non-Javadoc)
	 * @see ddbc.cpn2.st.BaseHandler#executePs(ddbc.cpn2.impl.CpPreparedStatement, ddbc.cpn2.JdbcMethod, java.lang.Object[])
	 */
	@Override
	public Object executePs(CpPreparedStatement ps, JdbcMethod method,
			Object... moreParams) throws SQLException {
		String l_state = getState(ps);
		String l_strStatement = getStrStatement(ps);
		Object l_result = null;
		if (l_state.equals("initial") && l_strStatement.equals(STATEMENT_41_INSERT_OLD)) {
			// No statement is executed, expected value is returned
			l_result = Integer.valueOf(1);
			ps.cpConnection().cpContext().setState(STATE_CMDEDIT_INSERT_OLD);
		} else if (l_state.equals(STATE_CMDEDIT_INSERT_OLD) && l_strStatement.equals(STATEMENT_41_DELETE_CUR)) {
			// No statement is executed, expected value is returned
			l_result = Integer.valueOf(1);
			ps.cpConnection().cpContext().setState(STATE_CMDEDIT_DELETE_CUR);
		} else if (l_state.equals(STATE_CMDEDIT_DELETE_CUR) && l_strStatement.equals(STATEMENT_41_INSERT_CUR)) {
			l_result = execute_insertIntoCur(ps, method, moreParams);
		} else {
			s_logger.error("Unexpected statement and state: \"{}\" @{}", l_strStatement, l_state);
			throw new SQLException("Unexpected statement @ state. Look up logs for details.");
		}
		return l_result;
	}

	private Object execute_insertIntoCur(CpPreparedStatement ps, JdbcMethod method,
			Object... moreParams) throws SQLException {
		// In either case (success or failure) the initial state is set.
		ps.cpConnection().cpContext().setState("initial");
		
		List<SetParameter> l_parameters = ps.cpContext().getParameters();
		// insert into cur (title, user, minor_edit,text,timestamp, is_new, is_redirect) values(?,?,?,?,?,?,?)
		final int IDX_TITLE = 1;
		final int IDX_USER = 2;
		final int IDX_MIN_ED = 3;
		final int IDX_TEXT = 4;
		final int IDX_TMS = 5;
		final int IDX_ISNEW = 6; // TT_LOW Ignored?
		final int IDX_ISRDR = 7;
		
		// insert into REVISION
		Connection l_wrappedConnection = ps.cpConnection().cpWrapped();
		PreparedStatement l_psInsertRev = l_wrappedConnection.prepareStatement(
				"insert into REVISION (USER, MINOR_EDIT, TIMESTAMP, PAGE) values(?,?,?, 0)");
		applyParameterDeferred(l_psInsertRev, 1, l_parameters, IDX_USER);
		applyParameterDeferred(l_psInsertRev, 2, l_parameters, IDX_MIN_ED);
		applyParameterDeferred(l_psInsertRev, 3, l_parameters, IDX_TMS);
		int l_updatedCount = (Integer)l_psInsertRev.executeUpdate();
		// (return $rid)
		ResultSet rsGenKeys = l_psInsertRev.getGeneratedKeys();
		rsGenKeys.next();
		int newRId = rsGenKeys.getInt(1);
		rsGenKeys.close(); l_psInsertRev.close();
		
		// insert into PAGE
		PreparedStatement l_psInsertPage = l_wrappedConnection.prepareStatement(
				"insert into PAGE (LATEST, TITLE, IS_NEW, IS_REDIRECT) values(?, ?, 1, ?) " +
				"on duplicate key update LATEST=?, IS_NEW=0");
		l_psInsertPage.setInt(1, newRId);
		applyParameterDeferred(l_psInsertPage, 2, l_parameters, IDX_TITLE);
		applyParameterDeferred(l_psInsertPage, 3, l_parameters, IDX_ISRDR);
		l_psInsertPage.setInt(4, newRId);
		l_updatedCount = (Integer)l_psInsertPage.executeUpdate();
		// (return $pid)
		rsGenKeys = l_psInsertPage.getGeneratedKeys();
		rsGenKeys.next();
		int newPId = rsGenKeys.getInt(1);
		rsGenKeys.close(); l_psInsertPage.close();
		
		// insert into TEXT
		PreparedStatement l_psInsertText = l_wrappedConnection.prepareStatement(
				"insert into TEXT (TID, TEXT) values (?, ?)");
		l_psInsertText.setInt(1, newRId);
		applyParameterDeferred(l_psInsertText, 2, l_parameters, IDX_TEXT);
		l_updatedCount = (Integer)l_psInsertText.executeUpdate();

		// update REVISION set PAGE
		PreparedStatement l_psUpdateRevFk = l_wrappedConnection.prepareStatement(
				"update REVISION set PAGE=? where RID=?");
		l_psUpdateRevFk.setInt(1, newPId);
		l_psUpdateRevFk.setInt(2, newRId);
		l_updatedCount = (Integer)l_psUpdateRevFk.executeUpdate();

		return (Integer)l_updatedCount;
	}

	private static String getState(CpStatement stmt) {
		return stmt.cpConnection().cpContext().getState();
	}
	
	/**
	 * @param ps
	 * @return
	 */
	private static String getStrStatement(CpPreparedStatement ps) {
		return JdbcUtils.normalizeString(ps.cpContext().getStrStatement());
	}

	private void applyParameterDeferred(PreparedStatement ps, int idxApply,
			List<SetParameter> parameters, int idxSrc) throws SQLException {
		boolean l_applied = false;
		for (SetParameter l_parameter : parameters) {
			// The parameters may not be in their natural order?
			if (l_parameter.getParameterIndex() == idxSrc) {
				try {
					Method l_method = l_parameter.getSetMethod().getMethod();
					Object[] l_paramsInvoke = FCollections.concatArray(Object.class, idxApply, l_parameter.getSetParameters());
					l_method.invoke(ps, l_paramsInvoke);
				} catch (Throwable t) {
					// Wrap and propagate
					throw new SQLException(t);
				}
				l_applied = true;
				break;
			}
		}
	}

}
