/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package uwiki.evol;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.NoSuchElementException;

import org.apache.commons.dbcp.ConnectionFactory;
import org.apache.commons.dbcp.DriverManagerConnectionFactory;
import org.apache.commons.dbcp.PoolableConnectionFactory;
import org.apache.commons.pool.ObjectPool;
import org.apache.commons.pool.impl.GenericObjectPool;
import org.dbunit.database.DatabaseConnection;
import org.dbunit.database.IDatabaseConnection;
import org.dbunit.dataset.DataSetException;
import org.dbunit.dataset.IDataSet;
import org.dbunit.dataset.xml.FlatDtdDataSet;
import org.dbunit.dataset.xml.FlatXmlDataSet;
import org.dbunit.ext.mysql.MySqlConnection;

/**
 * @author Javier
 *
 */
public class GenDBUnitData {

	
	private static PoolableConnectionFactory s_poolableConnectionFactory;

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		try {
			init();
			IDatabaseConnection conn = borrowConnection();
			try {
				IDataSet fullDataSet = conn.createDataSet();
				generateFlatXml(fullDataSet);
				generateDtd(fullDataSet);
			} finally {
				returnConnection(conn);
			}
		} catch (Exception e) {
			System.err.println("GenDBUnitData.main()");
			e.printStackTrace();
		}
	}

	private static void init() throws ClassNotFoundException {
		// TODO Fetch the information from configuration file
		String jdbcDriver = "com.mysql.jdbc.Driver";
		String jdbcUrl = "jdbc:mysql://localhost:3306/uwiki";
		String jdbcUser = "uwiki";
		String jdbcPwd = "uwiki";
		
		// Initialization based on http://svn.apache.org/viewvc/commons/proper/dbcp/trunk/doc/ManualPoolingDriverExample.java?view=co
		Class.forName(jdbcDriver);
		ObjectPool connectionPool = new GenericObjectPool(null);
		ConnectionFactory connectionFactory = new DriverManagerConnectionFactory(jdbcUrl,jdbcUser,jdbcPwd);
		s_poolableConnectionFactory = new PoolableConnectionFactory(
				connectionFactory,connectionPool,null,"SELECT 1=1 FROM DUAL",false,true);
	}
	
	private static IDatabaseConnection  borrowConnection() throws NoSuchElementException, IllegalStateException, Exception {
		Connection jdbcConn = (Connection)s_poolableConnectionFactory.getPool().borrowObject();
		//IDatabaseConnection conn = new DatabaseConnection(jdbcConn);
		IDatabaseConnection conn = new MySqlConnection(jdbcConn, "uwiki");
		return conn;
	}
	
	private static void returnConnection(IDatabaseConnection  conn) throws SQLException, Exception {
		s_poolableConnectionFactory.getPool().returnObject(conn.getConnection());
	}
	
	private static void generateFlatXml(IDataSet fullDataSet) throws DataSetException, FileNotFoundException, IOException {
		FlatXmlDataSet.write(fullDataSet, new FileOutputStream("uwiki_full_flat.xml"));
	}
	
	private static void generateDtd(IDataSet fullDataSet) throws DataSetException, FileNotFoundException, IOException {
		// write DTD file
		FlatDtdDataSet.write(fullDataSet, new FileOutputStream("uwiki_flat.dtd"));
	}
}
