package uwiki.evol;

import java.io.FileInputStream;
import java.sql.Connection;
import java.util.ArrayList;
import java.util.Date;
import java.util.Properties;

import org.apache.commons.dbcp.ConnectionFactory;
import org.apache.log4j.PropertyConfigurator;
import org.dbunit.DBTestCase;
import org.dbunit.IDatabaseTester;
import org.dbunit.database.IDatabaseConnection;
import org.dbunit.dataset.IDataSet;
import org.dbunit.dataset.xml.FlatXmlDataSetBuilder;

import ddbc.cpn2.log.CpLogger;

import uwiki.DataCur;
import uwiki.WData;
import ddbc.commons.jdbc.DbcpDatabaseTester;
import ddbc.commons.jdbc.JdbcUtils;
import ddbc.commons.util.Configs;
import ddbc.commons.util.Strings;

public class UWikiDbTest extends DBTestCase {
	private Properties i_properties;
	public UWikiDbTest(String name) throws Exception {
		super( name );
/*
		System.setProperty( PropertiesBasedJdbcDatabaseTester.DBUNIT_DRIVER_CLASS, "com.mysql.jdbc.Driver" );
		System.setProperty( PropertiesBasedJdbcDatabaseTester.DBUNIT_CONNECTION_URL, "jdbc:mysql://localhost:3306/uwiki_test" );
		System.setProperty( PropertiesBasedJdbcDatabaseTester.DBUNIT_USERNAME, "uwiki" );
		System.setProperty( PropertiesBasedJdbcDatabaseTester.DBUNIT_PASSWORD, "uwiki" );
		System.setProperty( PropertiesBasedJdbcDatabaseTester.DBUNIT_SCHEMA, "uwiki_test" );
*/
		String cfgLocation = Configs.getStandAloneProperty("test_config", null, "rsrc:/uwiki/evol/dbtest41.properties");
		i_properties = Configs.loadSimplePropertiesFromLocation(cfgLocation);
		
		String log4jLocation = i_properties.getProperty("log4j_config", "file:log4j.properties");
		Properties l_log4jProperties = Configs.loadSimplePropertiesFromLocation(log4jLocation);
		PropertyConfigurator.configure(l_log4jProperties);
		
		String ddbcLocation = i_properties.getProperty("ddbc_config");
		if (!Strings.isEmpty(ddbcLocation)) {
			System.setProperty("DDBC_CONFIG", ddbcLocation);
		}

		ConnectionFactory l_connFactory = JdbcUtils.createDriverConnectionFactoryFromProperties(
				i_properties, "proxy.", false);
		JdbcUtils.bindConnectionFactoryAsDriverManagerPool(l_connFactory, "uwiki_wrapped");
		l_connFactory = JdbcUtils.createDriverConnectionFactoryFromProperties(
				i_properties, "base.", false);
		JdbcUtils.bindConnectionFactoryAsDriverManagerPool(l_connFactory, "uwiki_base");
	}

	protected IDatabaseTester tester = null;
	@Override
	protected IDatabaseTester getDatabaseTester() throws Exception {
//		return super.getDatabaseTester();
		if (this.tester == null) {
			this.tester = new DbcpDatabaseTester(JdbcUtils.getPoolByAlias("uwiki_base"));
		}
		return this.tester;
	}
	
	protected IDataSet getDataSet() throws Exception {
		return new FlatXmlDataSetBuilder().build(new FileInputStream(
				i_properties.getProperty("dbunit.datasetBuilder","uwiki_initial_flat.xml")));
	}
	
	private IDatabaseTester i_wrapperTester = null;
	protected IDatabaseConnection getWrappedConnection() throws Exception {
		if (this.i_wrapperTester == null) {
			i_wrapperTester = new DbcpDatabaseTester(JdbcUtils.getPoolByAlias("uwiki_wrapped"));
		}
		return i_wrapperTester.getConnection();
	}
	
	public void testListCurrent() throws Exception {
		// This test performs at least one of each WData operation.
		// First we test that the data look like the initial data
		// After that, the data is modified, and it is checked that the database is altered as expected.
		// 
		IDatabaseConnection l_connection = getWrappedConnection();
		Connection jdbcConn = l_connection.getConnection();
		// #1 Obtain the initial history (listCurrent+listOld), returning 2+1=3 rows.
		jdbcConn.setAutoCommit(true);
		ArrayList<Object> l_listHistory = new ArrayList<Object>();
		WData.listCurrent(jdbcConn, l_listHistory);
		assertEquals(2, l_listHistory.size());
		// TODO Further testing
		WData.listOld(jdbcConn, l_listHistory);
		assertEquals(3, l_listHistory.size());
		
		// #2 Modify the page titled "Mercurio"
		DataCur l_curMercurio = WData.getSingleCurByTitle(jdbcConn, "Mercurio");
		l_curMercurio.setText(l_curMercurio.getText() + " (modified)");
		jdbcConn.setAutoCommit(false);
		WData.moveCurIntoOld(jdbcConn, "Mercurio");
		WData.insertIntoCur(jdbcConn, l_curMercurio);
		jdbcConn.commit();
		
		// #3 Check latest "Mercurio" has the expected data, and that page history has the expected size.
		jdbcConn.setAutoCommit(true);
		DataCur l_curMercurioNew = WData.getSingleCurByTitle(jdbcConn, "Mercurio");
		assertEquals(l_curMercurio.getText(), l_curMercurioNew.getText());
		ArrayList<Object> l_mercuryHistory = new ArrayList<Object>();
		l_mercuryHistory.add(l_curMercurioNew);
		WData.listOldWhereTitle(jdbcConn, "Mercurio", l_mercuryHistory);
		assertEquals(l_mercuryHistory.size(), 2);
		
		// #4 Insert a new page "Mercury"(redirect page, different attributes than previous modification).

		DataCur l_newMercuryRedirect = new DataCur();
		//l_newMercuryRedirect.setCid(0);
		l_newMercuryRedirect.setUser("test");
		l_newMercuryRedirect.setText("#REDIRECT [Mercurio]");
		l_newMercuryRedirect.setTimestamp(new Date());
		l_newMercuryRedirect.setTitle("Mercury");
		l_newMercuryRedirect.setMinorEdit(false);
		l_newMercuryRedirect.setNew(true);
		l_newMercuryRedirect.setRedirect(true);
		jdbcConn.setAutoCommit(false);
		WData.moveCurIntoOld(jdbcConn, "Mercury");
		WData.insertIntoCur(jdbcConn, l_newMercuryRedirect);
		
		jdbcConn.commit();
		jdbcConn.close();
		
		CpLogger.flushAll();
	}
}