/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package uwiki;

import java.util.Comparator;
import java.util.Date;

/**
 * Comparator for pages (both current ( {@link DataCur} ) and old ( {@link DataOld} )) by descending age.
 * Newer ones come first, null goes at the end.
 */
public class ComparatorPagesByTimestamp implements Comparator<Object> {
	/** Singleton (reusable without synchronization concerns) instance. */
	private static ComparatorPagesByTimestamp singleton = new ComparatorPagesByTimestamp();
	/** Obtain the singleton instance of the comparator. */
	public static ComparatorPagesByTimestamp instance() { return singleton; }
	
	public int compare(Object o1, Object o2) {
		// Obtain the date objects to compare.
		Date ts1 = null;
		if (o1 instanceof DataCur) ts1 = ((DataCur)o1).getTimestamp();
		else if (o1 instanceof DataOld) ts1 = ((DataOld)o1).getTimestamp();
		
		Date ts2 = null;
		if (o2 instanceof DataCur) ts2 = ((DataCur)o2).getTimestamp();
		else if (o2 instanceof DataOld) ts2 = ((DataOld)o2).getTimestamp();
		
		// Compare dates. null goes to the end.
		if (ts1 == null) {
			if (ts2 == null) {return 0;
			} else { return -1; }
		} else {
			if (ts2 == null) { return 1;
			} else {
				// In case of equality ts1==ts2, there would be an incongruence
				// compare(o1,o2)==-1 && compare(o2,o1)==-1
				// But we ignore it because it doesn't spoil the sorting.
				return ts1.before(ts2) ? 1 : -1;
		}	}
	}

}
