/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package uwiki;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;

import org.apache.log4j.ConsoleAppender;
import org.apache.log4j.Logger;
import org.apache.log4j.PropertyConfigurator;

import ddbc.commons.jdbc.JdbcUtils;
import ddbc.commons.util.Strings;


public class InitServlet extends HttpServlet {
	private static final long serialVersionUID = 1L;

	@Override
	public void init(ServletConfig svConfig) throws ServletException {
		super.init(svConfig);
		
		// Init Logging
		try {
			Properties log4jProperties = getServletProperties("log4jFileName", "log4j.properties");
			PropertyConfigurator.configure(log4jProperties);
		} catch(Exception e) {
			// Configure plain console appender for all.
			Logger.getRootLogger().addAppender(new ConsoleAppender());
			Logger.getLogger(InitServlet.class).fatal("Couldn't load/configure LOG4J", e);
		}

		// Init Configuration
		try {
			Properties configProperties = getServletProperties("configFileName", "uwiki.config");
			WOps.setConfig(configProperties);
		} catch (Exception e) {
			Logger.getLogger(InitServlet.class).fatal("Couldn't load configuration", e);
		}
	}

	@Override
	public void destroy() {
		JdbcUtils.closePool("uwiki");
		super.destroy();
	}

	/**
	 * Obtain some configuration properties.
	 * Its location can be specified with a servlet init parameter,
	 * or it can be in the WEB-INF directory of the deploy.
	 * @param paramName Name of the init parameter than (posibly) specifies the location.
	 * @param defaultResourceName Name of the properties file in the WEB-INF directory.
	 * @return Properties instance loaded.
	 * @throws FileNotFoundException
	 * @throws IOException
	 */
	private Properties getServletProperties(String paramName,
			String defaultResourceName) throws FileNotFoundException,
			IOException {
		String svConfigFileName = getServletConfig().getInitParameter(paramName);
		InputStream istream = null;
		if (Strings.isEmpty(svConfigFileName)) {
			// Load from embedded file
			istream = getServletContext().getResourceAsStream("WEB-INF/" + defaultResourceName);
		} else {
			// Load from local file.
			istream = new FileInputStream(svConfigFileName);
		}
		Properties retValue = new Properties();
		try {
			retValue.load(istream);
		} finally {
			istream.close();
		}
		return retValue;
	}

}
