/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.commons.digest;

import java.security.MessageDigest;
import java.util.zip.CRC32;

/**
 * MessageDigest implementation that produces a CRC32 (java.util.zip) hash.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class Crc32Digest extends MessageDigest {
	/** CRC32 instance calculating the hash. */
	private CRC32 i_crc32 = new CRC32();
	
	/**
	 * 
	 */
	public Crc32Digest() {
		super("CRC32");
	}

	@Override
	protected byte[] engineDigest() {
		long l_value = i_crc32.getValue();
		// Little endian
		return new byte[]{
				(byte) (l_value & 0xffL),
				(byte) (l_value >> 8 & 0xffL),
				(byte) (l_value >> 16 & 0xffL),
				(byte) (l_value >> 24 & 0xffL)
		};
	}

	@Override
	protected void engineReset() {
		i_crc32.reset();
	}

	@Override
	protected void engineUpdate(byte a_input) {
		i_crc32.update(a_input);
	}

	@Override
	protected void engineUpdate(byte[] a_input, int a_offset, int a_len) {
		i_crc32.update(a_input,a_offset, a_len);
	}

}
