/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.commons.jdbc;

import java.sql.Connection;

import org.apache.commons.dbcp.PoolableConnectionFactory;
import org.dbunit.AbstractDatabaseTester;
import org.dbunit.JdbcDatabaseTester;
import org.dbunit.database.DatabaseConnection;
import org.dbunit.database.IDatabaseConnection;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * DBUnit DatabaseTester that uses a DBCP AbstractDatabaseTester to creato connections.<br>
 * It is based on DBUnit JdbcDatabaseTester by A.Almiray & F. Leme.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class DbcpDatabaseTester extends AbstractDatabaseTester
{

	/**
	 * Logger for this class
	 */
	private static final Logger logger = LoggerFactory.getLogger(JdbcDatabaseTester.class);

	private PoolableConnectionFactory i_pool;

	public DbcpDatabaseTester(PoolableConnectionFactory pool) {
		this(pool, null);
	}

	/**
	 * Creates a new JdbcDatabaseTester with the specified properties.
	 *
	 * @param driverClass the classname of the JDBC driver to use
	 * @param connectionUrl the connection url
	 * @param username a username that can has access to the database - can be <code>null</code>
	 * @param password the user's password - can be <code>null</code>
	 * @param schema the database schema to be tested - can be <code>null</code>
	 * @throws ClassNotFoundException If the given <code>driverClass</code> was not found
	 * @since 2.4.3
	 */
	public DbcpDatabaseTester(PoolableConnectionFactory pool, String schema) {
		super(schema);
		this.i_pool = pool;
	}

	public IDatabaseConnection getConnection() throws Exception
	{
		logger.debug("getConnection() - start");

		Connection conn = (Connection)i_pool.getPool().borrowObject();
		return new DatabaseConnection( conn, getSchema() );
	}

	public String toString()
	{
		StringBuilder sb = new StringBuilder();
		sb.append(getClass().getName()).append("[");
		sb.append("schema=").append(super.getSchema());
		sb.append("]");
		return sb.toString();
	}

}
