/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.commons.util;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Conversion utility.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class Convert {
	private static final Logger LOGGER = LoggerFactory.getLogger(Convert.class);
	public static Boolean toBoolean(Object src) {
		if (src == null) {
			LOGGER.warn("Irregular conversion: null -> boolean: returning false");
			return false;
		} else if (src instanceof Boolean) {
			return (Boolean)src;
		} else if (src instanceof CharSequence) {
			return Strings.parseBoolean(src.toString());
		} else if (src instanceof Number) {
			return ((Number)src).doubleValue() != 0.0;
		} else {
			throw new IllegalArgumentException("Can't convert value to boolean: " + src);
		}
	}
	
	public static Integer toInteger(Object src) {
		if (src == null) {
			LOGGER.warn("Irregular conversion: null -> int: returning 0");
			return 0;
		} else if (src instanceof Number) {
			return ((Number)src).intValue();
		} else if (src instanceof Boolean) {
			return (Boolean)src ? 1 : 0;
		} else if (src instanceof CharSequence) {
			return Integer.parseInt(src.toString());
		} else {
			throw new IllegalArgumentException("Can't convert value to Integer: " + src);
		}
	}
	
	// TODO Add conversion for more essential types
	// TODO Add conversion to parametrized type toType(Object a_value, Class<?> a_type)
}
