/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.commons.util;

import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;

import javax.servlet.http.HttpServletResponse;

/**
 * Utility class for Http operations.
 * @author Javier Aranda
 */
public class Http {
	/**
	 * Encodes an URL for inserting in a page or sending in a send-redirect.
	 * @param response HttpServletResponse object
	 * @param pageName Name of the linked page
	 * @return Encoded URL String.
	 */
	public static String encodeUrl(HttpServletResponse response, String pageName) {
		return response.encodeRedirectURL(pageName);
	}
	
	/**
	 * Encodes an URL with parameters for inserting in a page or sending in a send-redirect.
	 * @param response HttpServletResponse object
	 * @param pageName Name or the linked page.
	 * @param paramParts Parameters for the request, in the form name1,value1,name2,value2, etc.
	 *	Every parameter name must have its value.
	 * @return Encoded URL String.
	 */
	public static String encodeUrl(HttpServletResponse response, String pageName, String... paramParts) {
		assert paramParts.length % 2 == 0;
		try {
			StringBuffer sb = new StringBuffer(150);
			sb.append(response.encodeRedirectURL(pageName));
			char separator = '?';
			for (int i = 0; i < paramParts.length; i += 2) {
				sb.append(separator);
				sb.append(URLEncoder.encode(paramParts[i], "ISO-8859-1"));
				sb.append('=');
				sb.append(URLEncoder.encode(paramParts[i + 1], "ISO-8859-1"));
				separator = '&';
			}
			return sb.toString();
		} catch (UnsupportedEncodingException ue) { // Impossible exception
			throw new Error(ue);
		}
	}

}
