/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.commons.util;

import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.util.Date;

/**
 * Utility Class with functions regarding database access.
 * Inmature state: Trust this and die.
 * @author Javier Aranda
 */
public class Jdbc {

	/**
	 * Sets the parameter values for a {@link PreparedStatement}
	 * @param ps PreparedStatement object.
	 * @param parameters Parameter values. Must be supplied in the correct number and order.
	 * @throws SQLException
	 */
	public static void fillParams(PreparedStatement ps, Object... parameters) throws SQLException {
		for (int i = 0; i < parameters.length; i++) {
			Object o = parameters[i];
			// WHATIF We could decide the set method in function of the metadata.
			if (o instanceof CharSequence) { // From most common to least common.
				ps.setString(i + 1, String.valueOf(o));
			} else if (o instanceof Integer) {
				ps.setInt(i + 1, (Integer)o);
			} else if (o instanceof Date) {
				ps.setTimestamp(i + 1, new Timestamp(((Date)o).getTime()));
			} else if (o instanceof Boolean) {
				ps.setBoolean(i + 1, (Boolean)o);
			} else if (o instanceof byte[]) {
				ps.setBytes(i + 1, (byte[])o);
			} else if (o == null) {
				ps.setNull(i + 1, ps.getParameterMetaData().getParameterType(i + 1));
			} else {
				ps.setString(i + 1, String.valueOf(o));
			}
		}
	}
	
}
