/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.commons.util;

import java.util.Arrays;

public class Logs {

	/**
	 * Obtains the stacktrace, excluding a number of levels from the top.
	 * @param levelsSubstract Number of levels to exclude, counting from the caller. 0 keeps the caller,
	 * 	 1 excludes the callers level, 2 excludes the caller's father ...
	 * @return
	 */
	public static StackTraceElement[] getStackTrace(int levelsSubstract) {
		return getStackTrace(levelsSubstract, 5);
	}

	/**
	 * Obtains the stacktrace, excluding a number of levels from the top.
	 * @param levelsSubstract Number of levels to exclude, counting from the caller. 0 keeps the caller,
	 * 	 1 excludes the callers level, 2 excludes the caller's father ...
	 * @param maxLevels Max levels of stack to include in the result. Too many levels may be nonsense.
	 * @return
	 */
	public static StackTraceElement[] getStackTrace(int levelsSubstract, int maxLevels) {
		StackTraceElement[] stackTrace1 = new Throwable().getStackTrace();
		maxLevels = Math.min(maxLevels, stackTrace1.length - levelsSubstract - 1);
		return Arrays.copyOfRange(stackTrace1, levelsSubstract + 1, levelsSubstract + maxLevels + 1);
	}

}
