/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.tool.as;

import java.io.StringReader;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import ddbc.commons.jdbc.JdbcUtils;

import net.sf.jsqlparser.expression.JdbcParameter;
import net.sf.jsqlparser.expression.operators.relational.ExpressionList;
import net.sf.jsqlparser.parser.CCJSqlParserManager;
import net.sf.jsqlparser.schema.Column;
import net.sf.jsqlparser.statement.Statement;
import net.sf.jsqlparser.statement.insert.Insert;
import net.sf.jsqlparser.util.deparser.InsertDeParser;
import net.sf.jsqlparser.util.deparser.StatementDeParser;

public class TestSpawnInsert {

	public static void main(String[] args) {
		try {
			List<String> statements = new ArrayList<String>();
			Collections.addAll(statements,
					"INSERT INTO cur (title, user, minor_edit, text, timestamp, is_new, is_redirect) VALUES(?,?,?,?,?,?,?)",
					"INSERT INTO old(oid, title, user, minor_edit, text, timestamp)SELECT cid, title, user, minor_edit, text, timestamp FROM cur WHERE title = ?"
			);
			for (String strStatement : statements) {
				transformStatement(strStatement);
			}
			System.out.println("done");
		} catch (Throwable e) {
			e.printStackTrace();
		}
	}

	private static void transformStatement(String strStatement) {
		System.out.println("Transforming Statement: " + strStatement);
		try {
			// baseLoc = helper.parse(strStatement)
			Statement jspStatement = new CCJSqlParserManager().parse(new StringReader(strStatement));
			// for (loc : helper.getLocsTableOp("cur", "insert") {
			if (jspStatement instanceof Insert &&
					((Insert)jspStatement).getTable().getName().equalsIgnoreCase("cur")) {
				System.out.println("IS INSERT INTO CUR");
				// replacement = newSpawnReplacement()
				// replacement.addMain(statement)
				Insert jspInsert = (Insert)jspStatement;
				StringBuffer genStmt = new StringBuffer();
				StatementDeParser deparser = new StatementDeParser(genStmt);
				jspInsert.accept(deparser);
				System.out.println("Spawn main Statement:" + JdbcUtils.normalizeString(genStmt.toString()));
				
				// replacement.addGeneratedKeys("newId")
				// helper.replaceTable(loc, "cur", "cur1");
				jspInsert.getTable().setName("cur1");
				// replacement.addFetchGenKeys("newId");
				// helper.insertColumnAtInsert(loc, BEGIN, "cid", ref("newId"))
				System.out.println("Spawn gets generated key into variable newId");
				Column newColumn = new Column(jspInsert.getTable(), "cid");
				jspInsert.getColumns().add(0, newColumn);
				// Unsafe, should have verified.
				ExpressionList expressions = (ExpressionList)jspInsert.getItemsList();
				expressions.getExpressions().add(0, new JdbcParameter());
				genStmt.setLength(0);
				jspInsert.accept(deparser);
				System.out.println("Spawn subordinate statement: " + genStmt);
				System.out.println("Spawn remaps parameters to include ref(newId) as [0]");
				
			} else {
				System.out.println("not transformed");
			}
		} catch(Exception e) {
			System.err.println("At transformStatement");
			e.printStackTrace(System.err);
		}
	}
}
