/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.tool.sr;

import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.List;

public class DataStatementClass implements Comparable<DataStatementClass> {
	private static int s_idCounter = 0;
	private static DecimalFormat DF_ID = new DecimalFormat("'SR-stmtC'0000");

	private String i_srId;
	private String i_normSql;
	private int i_paramCount;
	private ArrayList<String> i_rsColumns = new ArrayList<String>();
	private ArrayList<String> i_gkColumns = new ArrayList<String>();
	private boolean i_isUpdate = false;
	
	private ArrayList<String> i_instanceIds = new ArrayList<String>();
	private ArrayList<StackTraceElement[]> i_framesList = new ArrayList<StackTraceElement[]>();

	// TT_LOW Check if the update flag is really needed (alt: we could induce it from the sql)
	public DataStatementClass(String normSql, boolean isUpdate) {
		super();
		i_srId = DF_ID.format(s_idCounter++);
		i_normSql = normSql;
		i_isUpdate = isUpdate;
	}

	public void addInstance(DataStatementInstance stI) {
		boolean l_fistInstance = i_instanceIds.isEmpty();
		i_instanceIds.add(stI.getStmtId());
		if (l_fistInstance) {
			// Add the data as it comes
			i_paramCount = stI.getSetParametersCount();
			ArrayList<Object> l_tmpList = new ArrayList<Object>();
			stI.getFirstRsRow(l_tmpList);
			for (Object l_obj : l_tmpList) {
				i_rsColumns.add(String.valueOf(l_obj));
			}
			l_tmpList.clear();
			for (Object l_obj : l_tmpList) {
				i_gkColumns.add(String.valueOf(l_obj));
			}
			i_framesList.add(stI.getFrames());
		} else {
			// i_paramCount -- if normSql is the same, must be the same
			// TT_LOW The management of the resultsets may change (would be strange, although).
			i_framesList.add(stI.getFrames());
		}
	}
	
	/**
	 * @return the srId
	 */
	public String getSrId() {
		return i_srId;
	}

	/**
	 * @return the normSql
	 */
	public String getNormSql() {
		return i_normSql;
	}

	/**
	 * @return the paramCount
	 */
	public int getParamCount() {
		return i_paramCount;
	}

	/**
	 * @return the rsColumns
	 */
	public <TList extends List<? super String>> TList getRsColumns(TList target) {
		target.addAll(i_rsColumns);
		return target;
	}

	/**
	 * @return the gkColumns
	 */
	public <TList extends List<? super String>> TList getGkColumns(TList target) {
		target.addAll(i_gkColumns);
		return target;
	}

	/**
	 * @return the isUpdate
	 */
	public boolean isUpdate() {
		return i_isUpdate;
	}
	
	/**
	 * @return the gkColumns
	 */
	public <TList extends List<? super String>> TList getInstanceIds(TList target) {
		target.addAll(i_instanceIds);
		return target;
	}

	public <TList extends List<? super StackTraceElement[]>> TList getFramesList(TList target) {
		target.addAll(i_framesList);
		return target;
	}

	/* (non-Javadoc)
	 * @see java.lang.Comparable#compareTo(java.lang.Object)
	 */
	@Override
	public int compareTo(DataStatementClass o) {
		return this.i_srId.compareTo(o.i_srId);
	}

	
}
