/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.tool.sr;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import ddbc.cpn2.JdbcMethod;
import ddbc.commons.util.FCollections;

public class DataStatementInstance implements Serializable {
	private static final long serialVersionUID = 1L;
	
	private String i_stmtId;
	private DataSequenceInstance i_sequence;
	private String i_normSql;
	// TODO This approach might not be best one, as there may be deferred values
	//   and what really matters is the value, not the method.
	private ArrayList<Object> i_setParameters = new ArrayList<Object>();
	private ArrayList<JdbcMethod> i_setMethods = new ArrayList<JdbcMethod>();
	// TT_LOW Consider the following rows
	/** Sequence of key-value for the first row from the statement resultset. */
	private ArrayList<Object> i_firstRsRow = new ArrayList<Object>();
	private int i_rsCount = -1;
	/** Sequence key-value for the first row for the Generated keys resultset. */
	private ArrayList<Object> i_firstGkRow = new ArrayList<Object>();
	private int i_gkCount = -1;
	private StackTraceElement[] i_frames;
	
	private ArrayList<String> i_liveResultSets = new ArrayList<String>();

	public DataStatementInstance(String stmtId, String normSql, StackTraceElement[] frames) {
		super();
		
		i_stmtId = stmtId;
		i_normSql = normSql;
		i_frames = frames;
	}

	/**
	 * @return the normalizedString
	 */
	public String getNormSql() {
		return i_normSql;
	}

	/**
	 * @return the stmtId
	 */
	public String getStmtId() {
		return i_stmtId;
	}

	public void onSetParameter(JdbcMethod method, int setIndex, Object[] parameters) {
		FCollections.setAtListFillingGaps(i_setMethods, setIndex - 1, method, null);
		FCollections.setAtListFillingGaps(i_setParameters, setIndex - 1, parameters, null);
	}
	
	public void onResultSetNext() {
		i_rsCount++;
	}
	
	public void onResultSetGet(JdbcMethod method, Object key, Object a_value) {
		if (i_rsCount == 0) {
			i_firstRsRow.add(key);
			i_firstRsRow.add(a_value);
		}
	}

	public void onGkNext() {
		i_gkCount++;
	}
	
	public void onGkGet(JdbcMethod method, Object key, Object a_value) {
		if (i_gkCount == 0) {
			i_firstGkRow.add(key);
			i_firstGkRow.add(a_value);
		}
	}

	public <TList extends List<Object>> TList getSetParameters(TList target) {
		for (int i = 0; i < i_setParameters.size(); i++) {
			target.add(i_setMethods.get(i));
			target.add(i_setParameters.get(i));
		}
		return target;
	}
	
	public int getSetParametersCount() {
		return i_setParameters.size();
	}

	public <TList extends List<Object>> TList getFirstRsRow(TList target) {
		target.addAll(i_firstRsRow);
		return target;
	}
	
	public <TList extends List<Object>> TList getFirstGkRow(TList target) {
		target.addAll(i_firstGkRow);
		return target;
	}
	
	public StackTraceElement[] getFrames() {
		return i_frames.clone();
	}

	/**
	 * @return the sequence
	 */
	public DataSequenceInstance getSequence() {
		return i_sequence;
	}

	/**
	 * @param sequence the sequence to set
	 */
	public void setSequence(DataSequenceInstance sequence) {
		i_sequence = sequence;
	}

	public void addLiveResultSet(String idResultset) {
		i_liveResultSets.add(idResultset);
	}
	
	public <TList extends List<? super String>> TList getLiveResultSets(TList target) {
		target.addAll(i_liveResultSets);
		return target;
	}
}
