/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.tool.sr;

import java.io.*;
import java.util.*;

import org.apache.commons.codec.binary.StringUtils;
import org.apache.commons.xmlio.in.SimpleImporter;
import org.apache.commons.xmlio.out.XMLWriter;
import org.xml.sax.InputSource;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.XMLReaderFactory;

/**
 * Generate the statements report (from the listener log)
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class GenStmtReport {

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		try {
			String l_fnInput = args[0];
			String l_fnOutput = args[1];

			System.err.println(String.format("GenStmtReport %s -> %s", l_fnInput, l_fnOutput));
			
			// Compose Reader for xml file.
			byte[] l_bytesHeader = StringUtils.getBytesUtf8(
					"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<listenerLog>\n");
			byte[] l_bytesFooter = StringUtils.getBytesUtf8("</listenerLog>\n");
			ArrayList<InputStream> l_listSequenceInputs = new ArrayList<InputStream>();
			Collections.addAll(l_listSequenceInputs,
					new ByteArrayInputStream(l_bytesHeader),
					new BufferedInputStream(new FileInputStream(l_fnInput)),
					new ByteArrayInputStream(l_bytesFooter));
			SequenceInputStream l_isSeq = new SequenceInputStream(
					Collections.enumeration(l_listSequenceInputs));
			InputSource l_source = new InputSource(l_isSeq);
			SimpleImporter l_importer = new SimpleImporter();
			SrImportHandler l_handler = new SrImportHandler();
			l_importer.addSimpleImportHandler(l_handler);
			l_importer.parse(l_source);
			
			ArrayList<SrDataSequence> l_sequences = (ArrayList<SrDataSequence> )l_handler.getSequences(new ArrayList<SrDataSequence>());
			ArrayList<SrDataStatement> l_statements = (ArrayList<SrDataStatement>)l_handler.getStatements(new ArrayList<SrDataStatement>());
			
			BufferedOutputStream l_bof = new BufferedOutputStream(new FileOutputStream(l_fnOutput));
			try {
				writeStatementReport(l_sequences, l_statements, l_bof);
			} finally {
				l_bof.close();
			}
//			for (SrDataStatement stmt: l_statements) {
//				System.out.println(stmt.getNormalizedString());
//			}
//
//			for (SrDataSequence seq : l_sequences) {
//				System.out.print("{");
//				List<SrDataStatement> l_stmtAtSeq = (List<SrDataStatement>)seq.getStatements(new ArrayList<SrDataStatement>());
//				String l_sep = "";
//				for (SrDataStatement stmtSeq : l_stmtAtSeq) {
//					System.out.print(l_sep + stmtSeq.getNormalizedString());
//					l_sep = ",\n";
//				}
//				System.out.println("}\n");
//			}

			System.err.println("GenStmtReport done");
		} catch (Throwable e) {
			System.err.println("GenStmtReport.main()");
			e.printStackTrace();
		}

	}

	private static void writeStatementReport(
			ArrayList<SrDataSequence> sequences,
			ArrayList<SrDataStatement> statements, OutputStream a_output) throws IOException {
		int nextRefStatement = 1;
		HashMap<SrDataStatement, Integer> l_stmtRefsByStmt = new HashMap<SrDataStatement, Integer>();
		int nextRefSequence = 1;

		XMLWriter l_writer = new XMLWriter(new OutputStreamWriter(a_output, "UTF-8"));
		l_writer.writeXMLDeclaration();
		l_writer.writeStartTag(XMLWriter.createStartTag("statementReport", new String[][]{
				{"xmlns", "http://www.example.org/jdbc-proxy/statements-report"},
				{"xmlns:xsi","http://www.w3.org/2001/XMLSchema-instance"},
				{"xsi:schemaLocation","http://www.example.org/jdbc-proxy/statements-report statements-report.xsd"}
		}));

		l_writer.writeStartTag("<statements>");
		for (SrDataStatement l_statement : statements) {
			int l_stmtRef = nextRefStatement++;
			l_stmtRefsByStmt.put(l_statement, (Integer)l_stmtRef);
			l_writer.writeStartTag(XMLWriter.createStartTag(
					"statement", new String[][]{
							{"stmtId", Integer.toString(l_stmtRef)}}
					));
			l_writer.writeElementWithCData("<norm-strStmt>",
					l_statement.getNormalizedString(), "</norm-strStmt>");
			l_writer.writeEndTag("</statement>");
		}
		l_writer.writeEndTag("</statements>");

		l_writer.writeStartTag("<sequences>");
		for (SrDataSequence l_sequence : sequences) {
			int l_seqRef = nextRefSequence++;
			l_writer.writeStartTag(XMLWriter.createStartTag(
					"sequence", new String[][]{
							{"seqId", Integer.toString(l_seqRef)}}
					));

			l_writer.writeStartTag("<stmtRefs>");
			List<SrDataStatement> l_sequenceStatements =
				(ArrayList<SrDataStatement>)l_sequence.getStatements(new ArrayList<SrDataStatement>());
			for (SrDataStatement l_stmtSeq : l_sequenceStatements) {
				Integer l_stmtRef = l_stmtRefsByStmt.get(l_stmtSeq);
				assert l_stmtRef != null;
				l_writer.writeEmptyElement(XMLWriter.createEmptyTag("stmtRef",
						"idRef", Integer.toString(l_stmtRef)));
			}
			l_writer.writeEndTag("</stmtRefs>");
			l_writer.writeEndTag("</sequence>");
		}
		l_writer.writeEndTag("</sequences>");
		
		l_writer.writeEndTag("</statementReport>");
		l_writer.flush();
	}

}
