/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.tool.sr;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import org.apache.commons.xmlio.in.SimpleImportHandler;
import org.apache.commons.xmlio.in.SimplePath;
import org.xml.sax.helpers.AttributesImpl;

public class SrImportHandler implements SimpleImportHandler { 
	
	protected HashMap<String, SrDataStatement> i_statementsByStr = new HashMap<String, SrDataStatement>();
	protected HashMap<String, SrDataSequence> i_sequencesByStr = new HashMap<String, SrDataSequence>();
	
	// TODO Have a current statement and sequence per open connection.
	/** Current statement (under construction) */
	protected SrDataStatement i_statementCur = null;
	/** Current sequence (under construction) */
	protected SrDataSequence i_sequenceCur = null;
	
	public SrImportHandler() {
		super();
	}
	
	public void startDocument() { }
	public void endDocument() { }

	public void cData(SimplePath path, String cdata) { }

	public void startElement(SimplePath path, String name, AttributesImpl attributes, String leadingCDdata) {
		if (path.matches("/listenerLog/eventTx")) {
			String l_txType = attributes.getValue("type");
			if (l_txType.equals("start")) {
				i_sequenceCur = new SrDataSequence();
			} else if (l_txType.equals("commit")) {
				// Check if the sequence was already in the map.
				String l_strSequence = SrUtil.getSequenceString(i_sequenceCur);
				SrDataSequence l_prevSequence = i_sequencesByStr.get(l_strSequence);
				if (l_prevSequence == null) {
					i_sequencesByStr.put(l_strSequence, i_sequenceCur);
				}
				i_sequenceCur = null;
			} else if (l_txType.equals("rollback")) {
				// Discard the sequence.
				i_sequenceCur = null;
			}
		} else if(path.matches("/listenerLog/eventStatement")) {
			i_statementCur = new SrDataStatement();
			// Pending process the information at the end of the element.
		} else if(path.matches("/listenerLog/eventStatement/statement")) {
			i_statementCur.setNormalizedString(SrUtil.normalizeString(leadingCDdata));
		} 
	}
	public void endElement(SimplePath path, String name) {
		if(path.matches("/listenerLog/eventStatement")) {
			SrDataStatement l_selectedStatement = i_statementsByStr.get(i_statementCur.getNormalizedString());
			if (l_selectedStatement == null) {
				i_statementsByStr.put(i_statementCur.getNormalizedString(), i_statementCur);
				l_selectedStatement = i_statementCur;
			}
			i_sequenceCur.addStatement(l_selectedStatement);
			i_statementCur = null;
		}
	}

	// TODO Prefer SrDataSequence instead of ? super.
	public List<? super SrDataSequence>getSequences(List<? super SrDataSequence> target) {
		target.addAll(i_sequencesByStr.values());
		return target;
	}

	public List<? super SrDataStatement>getStatements(List<? super SrDataStatement> target) {
		target.addAll(i_statementsByStr.values());
		return target;
	}
}