/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.codegen;

import java.io.BufferedReader;
import java.io.PrintWriter;
import java.sql.SQLException;
import java.util.*;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.JdbcMethod;

import ddbc.commons.util.Strings;

public class GcMain {

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		try {
			String[] classNames = GcUtils.getClassesToProcess();
			PrintWriter outCodes = GcUtils.getMethodCodesWriter();
			GcGenerator generator = new GcGenerator();
			for (String className : classNames) {
				BufferedReader inMethods = GcUtils.getClassMethodsReader(className);
//				PrintWriter outGenCode = GcUtils.getClassGenCodeWriter(className);
				StringBuilder classFileFrameContent = GcUtils.loadClassFileFrame(className, new StringBuilder(40000));
				String lineMethod = inMethods.readLine();
				while (lineMethod != null) {
					if (! Strings.isEmpty(lineMethod)) {
						ParsedMethod method = GcUtils.parseMethod(className, lineMethod);
						outCodes.println(method.getMethodCode());
//						writeMethodGenCode(method, outGenCode);
						GcUtils.replaceMethodInFrame(method, classFileFrameContent, generator);
						
					}
					lineMethod = inMethods.readLine();
				}
				inMethods.close();
//				outGenCode.close();
				GcUtils.saveClassFileFrame(className, classFileFrameContent);
			}
			outCodes.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public static class GcGenerator implements GcUtils.MethodCodeGenerator {
		public StringBuilder writeMethod(ParsedMethod methodInfo, CharSequence customizable, StringBuilder target) throws java.io.IOException {
			String l_methodId = methodInfo.getMethodCode();
			target.append(String.format("\tpublic %s {\n", methodInfo.getStrSignature() ));

			String l_strParamsLog = methodInfo.getStrParameterNames();
			if (!Strings.isEmpty(l_strParamsLog)) { l_strParamsLog = ", " + l_strParamsLog; }
			target.append(String.format("\t\ti_logger.logStart(i_objId, JdbcMethod.%s%s);\n", l_methodId, l_strParamsLog));
			
			String returnType = methodInfo.getReturn();
			boolean returnsVoid = returnType.equals("void");
			if (!returnsVoid) {
				target.append(String.format("\t\t%s l_result = %s;\n", returnType, GcUtils.getStrTypeDefaultValue(returnType)));
			}
			target.append("\t\ttry {\n");
			target.append(String.format("\t\t\t//{AUTOGEN:CUSTOM_BEGIN}\n", l_methodId));
			String returnRef = returnsVoid ? "null" : "l_result";
			if (customizable == null || customizable.toString().equals("")) {
				if (returnsVoid) {
					target.append(String.format("\t\t\ti_wrapped.%s;\n", methodInfo.getStrDelegate()));
				} else {
					target.append(String.format("\t\t\tl_result = i_wrapped.%s;\n", methodInfo.getStrDelegate()));
				}
			} else {
				target.append(customizable);
			}
			target.append(String.format("\t\t\t//{AUTOGEN:CUSTOM_END}\n", l_methodId));

			String[] l_throws = methodInfo.getThrows();
			if (l_throws.length == 0) {
				// No checked exceptions
				target.append("\t\t} catch (Throwable t) {\n");
				target.append(String.format(
						"\t\t\tCpUtils.handleCatchUnchecked(i_logger, i_objId, JdbcMethod.%s, t);\n",
						l_methodId));
			} else if (l_throws.length == 1 && (CpUtils.hasHandleMethod(l_throws[0]))) {
				// One well-known checked exception
				String handleMethodName = CpUtils.getHandleMethodName(l_throws[0]);
				target.append("\t\t} catch (Throwable t) {\n");
				target.append(String.format(
						"\t\t\tCpUtils.%s(i_logger, i_objId, JdbcMethod.%s, t);\n",
						handleMethodName, l_methodId));
			} else {
				// Some unforeseen combination of throwables
				// Handle checked exceptions
				for (String strThrows : l_throws) {
					target.append(String.format("\t\t} catch (%s e) {\n", strThrows));
					target.append(String.format("\t\t\ti_logger.logFailure(i_objId, JdbcMethod.%s, e);\n", l_methodId));
					target.append("\t\t\tthrow e;\n");
				}
				// Umbrella for unchecked throwables
				target.append("\t\t} catch (Throwable t) {\n");
				target.append(String.format(
						"\t\t\tCpUtils.handleCatchUnchecked(i_logger, i_objId, JdbcMethod.%s, t);\n",
						l_methodId));
			}
			target.append("\t\t}\n"); // close try-catch
			target.append(String.format("\t\ti_logger.logSuccess(i_objId, JdbcMethod.%s, %s);\n", l_methodId, returnRef));
			if (!returnsVoid) {
				target.append("\t\treturn l_result;\n");
			}
			target.append("\t}\n"); // close method


			return target;
		}
	}
	
//	public static void writeMethodGenCode(ParsedMethod method, PrintWriter out) {
//		String l_methodId = method.getMethodCode();
//		out.println(String.format("\t//{AUTOGEN:%s:BEGIN}", l_methodId));
//		out.println(String.format("\tpublic %s {", method.getStrSignature() ));
//		out.println(String.format(	"\t\ti_logger.logStart(i_loggerContext, i_objId, JdbcMethod.%s);", l_methodId));
//		out.println("\t\ttry {");
//		out.println(String.format("\t\t\t//{AUTOGEN:INLINE1_BEGIN}", l_methodId));
//		String l_return = method.getReturn();
//		if (l_return.equals("void")) {
//			out.println(String.format("\t\t\ti_wrapped.%s;", method.getStrDelegate()));
//			out.println(String.format("\t\t\t//{AUTOGEN:INLINE1_END}", l_methodId));
//			out.println(String.format("\t\t\ti_logger.logSuccess(i_loggerContext, i_objId, JdbcMethod.%s, null);", l_methodId));
//		} else {
//			out.println(String.format("\t\t\t%s l_result = i_wrapped.%s;", l_return, method.getStrDelegate()));
//			out.println(String.format("\t\t\t//{AUTOGEN:INLINE1_END}", l_methodId));
//			out.println(String.format("\t\t\ti_logger.logSuccess(i_loggerContext, i_objId, JdbcMethod.%s, l_result);", l_methodId));
//			out.println("\t\t\treturn l_result;");
//		}
//
//		List<String> listThrows = new ArrayList<String>();
//		listThrows.addAll(Arrays.asList(method.getThrows()));
//		Collections.addAll(listThrows, "RuntimeException", "Error");
//		for (String strThrows : listThrows) {
//			out.println(String.format("\t\t} catch (%s e) {", strThrows));
//			out.println(String.format("\t\t\ti_logger.logFailure(i_loggerContext, i_objId, JdbcMethod.%s, e);", l_methodId));
//			out.println("\t\t\tthrow e;");
//		}
//		out.println("\t\t}");
//		out.println("\t}");
//		out.println(String.format("\t//{AUTOGEN:%s:END}", l_methodId));
//	}
}
