/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.codegen;

import ddbc.commons.util.*;

import java.io.*;
import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.io.IOUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class GcUtils {
	private static Logger LOGGER = LoggerFactory.getLogger(GcUtils.class);
	private static Properties s_properties;
	private static Map<String,String> s_abbrevFromType;
	private static Map<String,String> s_mainClassIds = new HashMap<String, String>();
	
	static {
		try {
			String configLocation = Configs.getStandAloneProperty("GCCONFIG", null,
					"rsrc:/gen/ddbc/genCp.properties");
			s_properties = Configs.loadSimplePropertiesFromLocation(configLocation);
			
			InputStream isClassAbrevs = Configs.getInputStreamFromLocation(
					s_properties.getProperty("src_classAbrev"),
					GcUtils.class);
			s_abbrevFromType = createStringMapping(isClassAbrevs, false);
			isClassAbrevs.close();
		} catch(IOException e) {
			LOGGER.error("Could not load properties", e);
		}
	}

	// TODO Promote to library (ie Configs )
	private static Map<String, String> createStringMapping(
			InputStream input, boolean directionForward) throws IOException {
		HashMap<String,String> l_result = new HashMap<String,String>();
		BufferedReader brd = new BufferedReader(new InputStreamReader(input));
		String line = brd.readLine();
		while (line != null) {
			StringTokenizer tokenizer = new StringTokenizer(line, " \t");
			String token1 = tokenizer.nextToken();
			String token2 = tokenizer.nextToken();
			if (directionForward) {
				l_result.put(token1, token2);
			} else {
				l_result.put(token2, token1);
			}
			line = brd.readLine();
		}
		return l_result;
	}

	/**
	 * @return the properties
	 */
	public static Properties getProperties() {
		return s_properties;
	}

	public static String[] getClassesToProcess() {
		return s_properties.getProperty("processClasses").split(",");
	}
	
	public static BufferedReader getClassMethodsReader(String className) throws IOException {
		String l_pattern = s_properties.getProperty("src_methodsPattern");
		String l_location = l_pattern.replaceAll("\\$\\{name\\}", className);
		InputStream stream = Configs.getInputStreamFromLocation(l_location, GcUtils.class);
		String fileContent = IOUtils.toString(stream, "UTF-8");

		int sectionLocation = fileContent.indexOf("%%%");
		
		Pattern patternAbbrev = Pattern.compile("abbrev=(.*)");
		Matcher matcherAbbrev = patternAbbrev.matcher(fileContent.subSequence(0, sectionLocation));
		matcherAbbrev.find();
		String classAbbrev = matcherAbbrev.group(1);
		// Register abbreviature
		s_mainClassIds.put(className, classAbbrev);
		
		// Return reader for the rest
		BufferedReader breader = new BufferedReader(new StringReader(
				fileContent.substring(sectionLocation + 4)));
		return breader;
	}
	
	public static PrintWriter getClassGenCodeWriter(String className) throws IOException {
		String l_pattern = s_properties.getProperty("dst_gencodePattern");
		String l_filename = l_pattern.replaceAll("\\$\\{name\\}", className);
		return new PrintWriter(new FileWriter(l_filename));
	}
	
	public static PrintWriter getMethodCodesWriter() throws IOException {
		String l_filename = s_properties.getProperty("dst_codesMethods");
		return new PrintWriter(new FileWriter(l_filename));
	}
	
	public static <T extends Appendable> T loadClassFileFrame(String className, T target) throws IOException {
		String l_pattern = s_properties.getProperty("dst_classFilePattern");
		String l_filename = l_pattern.replaceAll("\\$\\{name\\}", className);
		InputStream inputStream = new FileInputStream(l_filename);
		// TT_LOW Could be interesting to use a buffered inputStream that reads/skips using matches/regex 
		String wholeFile = IOUtils.toString(inputStream);
		inputStream.close();
		Matcher matcherFrameStart = FlyWeight.getPattern("(?m)^\\s*///\\{AUTOGEN:FRAME_BEGIN\\}.*$").matcher(wholeFile);
		Matcher matcherFrameEnd = FlyWeight.getPattern("(?m)^\\s*///\\{AUTOGEN:FRAME_END\\}.*$").matcher(wholeFile);
		int idxFrameStart = matcherFrameStart.find() ? matcherFrameStart.end()+2 : 0;
		int idxFrameEnd = matcherFrameEnd.find() ? matcherFrameEnd.start() : wholeFile.length();
		target.append(wholeFile.subSequence(idxFrameStart, idxFrameEnd));
		return target;
	}
	
	public static void saveClassFileFrame(String className, CharSequence frameContent) throws IOException {
		// TODO Very similar to loadClass.
		String l_pattern = s_properties.getProperty("dst_classFilePattern");
		String l_filename = l_pattern.replaceAll("\\$\\{name\\}", className);
		InputStream inputStream = new FileInputStream(l_filename);
		// TT_LOW Could be interesting to use a buffered inputStream that reads/skips using matches/regex 
		String wholeFile = IOUtils.toString(inputStream);
		inputStream.close();
		Matcher matcherFrameStart = FlyWeight.getPattern("(?m)^\\s*///\\{AUTOGEN:FRAME_BEGIN\\}.*$").matcher(wholeFile);
		Matcher matcherFrameEnd = FlyWeight.getPattern("(?m)^\\s*///\\{AUTOGEN:FRAME_END\\}.*$").matcher(wholeFile);
		int idxFrameStart = matcherFrameStart.find() ? matcherFrameStart.start(): 0;
		int idxFrameEnd = matcherFrameEnd.find() ? matcherFrameEnd.end() + 2: wholeFile.length();
		
		OutputStream outputStream = new FileOutputStream(l_filename);
		outputStream.write(wholeFile.substring(0, idxFrameStart).getBytes("UTF-8"));
		outputStream.write("\t///{AUTOGEN:FRAME_BEGIN}\r\n".getBytes());
		outputStream.write(frameContent.toString().getBytes("UTF-8"));
		outputStream.write("\t///{AUTOGEN:FRAME_END}\r\n".getBytes());
		outputStream.write(wholeFile.substring(idxFrameEnd).getBytes("UTF-8"));
		outputStream.close();
	}
	
	//// Code substitution
	public static interface MethodCodeGenerator {
		public StringBuilder writeMethod (ParsedMethod methodInfo,
				CharSequence customizable, StringBuilder target) throws IOException;
	}
	
	public static void replaceMethodInFrame(ParsedMethod methodInfo, StringBuilder frameContent, MethodCodeGenerator generator) throws IOException {
		String methodId = methodInfo.getMethodCode();
		Matcher matcherMethodStart = Pattern.compile("(?m)^\\s*//\\{AUTOGEN:" + methodId + ":BEGIN\\}.*$").matcher(frameContent);
		Matcher matcherMethodEnd = Pattern.compile("(?m)^\\s*//\\{AUTOGEN:" + methodId + ":END\\}.*$").matcher(frameContent);
		int idxFrameInsertStart = frameContent.length();
		int idxFrameInsertEnd = frameContent.length();
		boolean addDelimiters = true;
		CharSequence customizable = null;
		if (matcherMethodStart.find() && matcherMethodEnd.find(matcherMethodStart.end())) {
			idxFrameInsertStart = matcherMethodStart.end() + 1;
			idxFrameInsertEnd = matcherMethodEnd.start();
			addDelimiters = false;
			CharSequence previousMethod = frameContent.subSequence(idxFrameInsertStart, idxFrameInsertEnd);
			Matcher matcherCustomizableStart = Pattern.compile("(?m)^\\s*//\\{AUTOGEN:CUSTOM_BEGIN\\}.*$").matcher(previousMethod);
			Matcher matcherCustomizableEnd = Pattern.compile("(?m)^\\s*//\\{AUTOGEN:CUSTOM_END\\}.*$").matcher(previousMethod);
			if (matcherCustomizableStart.find() && matcherCustomizableEnd.find(matcherCustomizableStart.end())) {
				customizable = previousMethod.subSequence(matcherCustomizableStart.end() + 1, matcherCustomizableEnd.start());
			}
		}
		StringBuilder newMethod = generator.writeMethod(methodInfo, customizable, new StringBuilder());
		if (addDelimiters) {
			newMethod.insert(0, "\t//{AUTOGEN:" + methodId + ":BEGIN}\r\n");
			newMethod.append("\t//{AUTOGEN:" + methodId + ":END}\r\n");
		}
		frameContent.replace(idxFrameInsertStart, idxFrameInsertEnd, newMethod.toString());
	}

	/**
	 * @return the abbrevFromType
	 */
	public static String getAbbrevFromType(String typeName) {
		// Remove parameter types if present
		int idxLT = typeName.indexOf('<');
		if (idxLT >= 0) { typeName = typeName.substring(0, idxLT); }
		
		String l_abbrev = s_abbrevFromType.get(typeName);
		if (l_abbrev == null) {
			LOGGER.warn("parameter type {} has no registered abbreviation", typeName);
			l_abbrev = "Xx";
		}
		return l_abbrev;
	}
	
	public static ParsedMethod parseMethod(String ownerClass, String methodLine) {
		ParsedMethod l_result = new ParsedMethod();
		l_result.setClassName(ownerClass);
		
		// #1: (<.*>\\s?)? Optional type parameters. No inner parameters.
		// #2: (.*)\\s+ Return type. No inner space.
		// #3: (.*)\\s*\\( Method name. Precedes parentheses.
		// #4: (.*)\\)\\s* Parameters Block.
		// #5: (?:throws\\s+(.*))? Optional throws declaration. External block is non-capturing.
		Pattern patternMethod = FlyWeight.getPattern("(<.*>\\s?)?(.*)\\s+(.*)\\s*\\((.*)\\)\\s*(?:throws\\s+(.*))?");
		
		Matcher matcherMethod = patternMethod.matcher(methodLine);
		if (!matcherMethod.matches()) {
			LOGGER.warn("Not complying line: " + methodLine);
		}
		l_result.setParameterTypes(matcherMethod.group(1));
		l_result.setReturn(matcherMethod.group(2).trim());
		l_result.setMethodName(matcherMethod.group(3));
		String methodParamBlock = matcherMethod.group(4);
		String methodThrowsBlock = matcherMethod.group(5);
		
		StringBuffer l_bufferCode = FlyWeight.borrowStringBuffer(100);
		
		l_bufferCode.append(s_mainClassIds.get(ownerClass) + "_" + l_result.getMethodName());
		
		// TT_LOW This parameter separation is not perfect, as type parameters <T...> can have commas.
		// Suggestion: Suppress type parameters, as they are of no use in this context.
		StringTokenizer tokenizerParams = new StringTokenizer(methodParamBlock, ",");
		ArrayList<String[]> listParameters = (ArrayList<String[]>)FlyWeight.borrowCollection(ArrayList.class);
		parseParameters(methodParamBlock, listParameters);
		String[][] l_parameters = new String[listParameters.size()][];
		listParameters.toArray(l_parameters);
		FlyWeight.returnCollection(listParameters);
		l_result.setParameters(l_parameters);
		
		for (int i = 0; i < l_parameters.length; i++) {
			String l_typeAbbrev = getAbbrevFromType(l_parameters[i][0]);
			l_bufferCode.append(l_typeAbbrev);
		}
		l_result.setMethodCode(l_bufferCode.toString());
		FlyWeight.returnStringBuffer(l_bufferCode);
		
		ArrayList<String> listExceptions = (ArrayList<String>)FlyWeight.borrowCollection(ArrayList.class);
		if (!Strings.isEmpty(methodThrowsBlock)) {
			StringTokenizer tokenizerExceptions = new StringTokenizer(methodThrowsBlock, ",");
			while (tokenizerExceptions.hasMoreTokens()) {
				listExceptions.add(tokenizerExceptions.nextToken().trim());
			}
		}
		String[] l_exceptions = new String[listExceptions.size()];
		listExceptions.toArray(l_exceptions);
		l_result.setThrows(l_exceptions);

		return l_result;
	}

	public static void parseParameters(String paramBlock, List<String[]> targetList) {

		if (Strings.isEmptyOrWhiteSpace(paramBlock)) { return; }
		// Pattern for parameter, excludes comma, unless it is inside type parameters(<T,X>).
		// But type parameters might have nested blocks which may confuse a bit more (eg Class<T,X<Y,A>> ifc )
		// (<.*>)*: 0-many innermost blocks (hope there isn't a 3+ level).
		// (<.*(<.*>)*>)?: At most one level-1 block.
		Pattern patternParam = FlyWeight.getPattern("[^,<]+(<.*(<.*>)*>)?[^,]*");
		// Pattern for searching the parameter name (after the last space or symbol)
		// "[^\\s>]+$": At the end: One or more characters Not being space or end of type parameter block.
		Pattern patternParamName = FlyWeight.getPattern("[^\\s>]+$");
		
		Matcher matcherParam = patternParam.matcher(paramBlock);
		
		while(matcherParam.find()) {
			String strParam = matcherParam.group().trim();
			Matcher matcherParamName = patternParamName.matcher(strParam);
			matcherParamName.find();
			String paramName = matcherParamName.group();
			String paramType = strParam.substring(0, matcherParamName.start()).trim();
			targetList.add(new String[]{paramType, paramName});
			
		}
	}

	private static Map<String,String> s_defaultValueByPrimitiveType =
		FCollections.newHashMap("byte","0","short","0","int","0","long","0L",
				"char","' '","float","0.0f","double","0.0","boolean","false");
	public static String getStrTypeDefaultValue(String varType) {
		String l_result = s_defaultValueByPrimitiveType.get(varType);
		if (l_result == null) {
			l_result = "null";
		}
		return l_result;
	}

}
