/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.codegen;

import java.io.*;
import java.util.StringTokenizer;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.io.IOUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import ddbc.commons.util.Strings;

/**
 * Generate method codes.
 * The names are obtained from a file instead of using instrospections because there is no
 * easy way to obtain the parameter names (Maybe a Javadoc doclet, or analyzing bytecode, provided debug
 * information is available).
 * 
 * @author F.Javier Aranda (fjarandag@gmail.com)
 *
 */
public class GenMethodCodes {
	private static Logger LOGGER = LoggerFactory.getLogger(GenMethodCodes.class);
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		try {
			String classLocations = GcUtils.getProperties().getProperty(
					"locs_classMethodList");
			StringTokenizer tokenizer = new StringTokenizer(classLocations, ",");
			while (tokenizer.hasMoreTokens()) {
				String location = tokenizer.nextToken().trim();
				processLocation(location);
			}
		} catch (Exception e) {
			System.err.println("Error in main()");
			e.printStackTrace();
		}

	}

	private static void processLocation(String location) throws IOException {
		InputStream stream = GenMethodCodes.class.getResourceAsStream(location);
		String classMethodInfo = IOUtils.toString(stream, "UTF-8");
		stream.close();
		int sectionLocation = classMethodInfo.indexOf("%%%");
		
		Pattern patternAbbrev = Pattern.compile("abbrev=(.*)");
		Matcher matcherAbbrev = patternAbbrev.matcher(classMethodInfo.subSequence(0, sectionLocation));
		matcherAbbrev.find();
		String classAbbrev = matcherAbbrev.group(1);
		
		// Process each method.
		BufferedReader breader = new BufferedReader(new StringReader(
				classMethodInfo.substring(sectionLocation + 4)));
		String methodLine = breader.readLine();
		while (methodLine != null) {
			methodLine = methodLine.trim();
			if (!Strings.isEmpty(methodLine)) {
				Pattern patternMethod = Pattern
						.compile("(<.*>\\s?)?(.*)\\s+(.*)\\s*\\((.*)\\)\\s*(throws\\s+.*)?");
				Matcher matcherMethod = patternMethod.matcher(methodLine);
				if (!matcherMethod.matches()) {
					LOGGER.warn("Not complying line: " + methodLine);
				}
				String typeParams = matcherMethod.group(1);
				String methodReturn = matcherMethod.group(2);
				String methodName = matcherMethod.group(3);
				String methodParamBlock = matcherMethod.group(4);
				String methodThrowsBlock = matcherMethod.group(5);
				
				StringBuilder l_builder = new StringBuilder(100);
				l_builder.append(classAbbrev + "_" + methodName);
				
				// TT_LOW This parameter separation is not perfect, as type parameters <T...> can have commas.
				// Suggestion: Suppress type parameters, as they are of no use in this context.
				StringTokenizer tokenizerParams = new StringTokenizer(methodParamBlock, ",");
				Pattern patternParam = Pattern.compile("([^<]*)(<.*>)?\\s+(.*)");
				while(tokenizerParams.hasMoreTokens()) {
					String strParam = tokenizerParams.nextToken().trim();
					Matcher matcherParam = patternParam.matcher(strParam);
					String abbrevType;
					if (!matcherParam.matches()) {
						LOGGER.warn("parameter {} does not comply pattern", strParam);
						abbrevType = "Xx";
					} else {
						String strType = matcherParam.group(1).trim();
						abbrevType = GcUtils.getAbbrevFromType(strType);
					}
					l_builder.append(abbrevType);
				}
				System.out.println(l_builder);
			}
			methodLine = breader.readLine();
		}
	}

}
