/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.codegen;

import ddbc.commons.util.Strings;

public class ParsedMethod {
	private String i_className;
	private String i_parameterTypes;
	private String i_return;
	private String i_methodName;
	private String[][] i_parameters;
	private String[] i_throws;
	private String i_methodCode;

	public ParsedMethod() {
		super();
		// TODO Auto-generated constructor stub
	}

	/**
	 * @return the className
	 */
	public String getClassName() {
		return i_className;
	}

	/**
	 * @return the parameterTypes
	 */
	public String getParameterTypes() {
		return i_parameterTypes;
	}

	/**
	 * @return the return
	 */
	public String getReturn() {
		return i_return;
	}

	/**
	 * @return the methodName
	 */
	public String getMethodName() {
		return i_methodName;
	}

	/**
	 * @return the parameters
	 */
	public String[][] getParameters() {
		return i_parameters;
	}

	/**
	 * @return the throws
	 */
	public String[] getThrows() {
		return i_throws;
	}

	/**
	 * @param a_className the className to set
	 */
	public void setClassName(String a_className) {
		i_className = a_className;
	}

	/**
	 * @param a_parameterTypes the parameterTypes to set
	 */
	public void setParameterTypes(String a_parameterTypes) {
		i_parameterTypes = a_parameterTypes;
	}

	/**
	 * @param a_return the return to set
	 */
	public void setReturn(String a_return) {
		i_return = a_return;
	}

	/**
	 * @param a_methodName the methodName to set
	 */
	public void setMethodName(String a_methodName) {
		i_methodName = a_methodName;
	}

	/**
	 * @param a_parameters the parameters to set
	 */
	public void setParameters(String[][] a_parameters) {
		i_parameters = a_parameters;
	}

	/**
	 * @param a_throws the throws to set
	 */
	public void setThrows(String[] a_throws) {
		i_throws = a_throws;
	}

	/**
	 * @return the methodCode
	 */
	public String getMethodCode() {
		return i_methodCode;
	}

	/**
	 * @param a_methodCode the methodCode to set
	 */
	public void setMethodCode(String a_methodCode) {
		i_methodCode = a_methodCode;
	}
	
	public String getStrDelegate() {
		return i_methodName + "(" + getStrParameterNames() + ")";
	}
	
	public String getStrParameterNames() {
		StringBuilder l_builder = new StringBuilder();
		String l_prevSeparator = "";
		for (String[] typeName : i_parameters) {
			l_builder.append(l_prevSeparator);
			l_prevSeparator = ", ";
			l_builder.append(typeName[1]);
		}
		return l_builder.toString();
	}

	public String getStrSignature() {
		StringBuilder l_builder = new StringBuilder();
		if (!Strings.isEmpty(i_parameterTypes)) {
			l_builder.append(i_parameterTypes + " ");
		}
		l_builder.append(i_return + " ");
		l_builder.append(i_methodName);
		
		l_builder.append('(');
		String l_prevSeparator = "";
		for (String[] typeName : i_parameters) {
			l_builder.append(l_prevSeparator);
			l_prevSeparator = ", ";
			l_builder.append(typeName[0] + " ");
			l_builder.append(typeName[1]);
		}
		l_builder.append(")");
		l_prevSeparator = " throws ";
		if (i_throws != null && i_throws.length > 0) {
			for (String strException : i_throws) {
				l_builder.append(l_prevSeparator);
				l_prevSeparator = ", ";
				l_builder.append(strException);
			}
		}
		return l_builder.toString();
	}

}
