/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2;

import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.sql.RowId;
import java.sql.SQLException;

import org.apache.commons.codec.binary.Base64;
import org.apache.commons.codec.binary.StringUtils;

import ddbc.cpn2.log.ConnectionLogger;
import ddbc.cpn2.log.CpLogger;
import ddbc.commons.digest.DigestData;
import ddbc.commons.util.Strings;

public class CpUtils {
	public static void handleCatchSqle(ConnectionLogger logger, String srcId, JdbcMethod methodId, Throwable t) throws SQLException {
		logger.logFailure(srcId, methodId, t);
		// Unwrap if applies.
		if (t instanceof InvocationTargetException) {
			t = ((InvocationTargetException)t).getTargetException();
		}
		if (t instanceof SQLException) {
			throw (SQLException) t;
		} else if (t instanceof RuntimeException) { // Unchecked
			throw (RuntimeException)t;
		} else if (t instanceof Error) { // Unchecked
			throw (Error)t;
		} else { // Unexpected
			throw new Error("Unexpected throwable", t);
		}
	}
	public static void handleCatchIoe(ConnectionLogger logger, String srcId, JdbcMethod methodId, Throwable t) throws IOException {
		logger.logFailure(srcId, methodId, t);
		if (t instanceof IOException) {
			throw (IOException) t;
		} else if (t instanceof RuntimeException) { // Unchecked
			throw (RuntimeException)t;
		} else if (t instanceof Error) { // Unchecked
			throw (Error)t;
		} else { // Unexpected
			throw new Error("Unexpected throwable", t);
		}
	}
	public static void handleCatchUnchecked(ConnectionLogger logger, String srcId, JdbcMethod methodId, Throwable t) {
		logger.logFailure(srcId, methodId, t);
		if (t instanceof RuntimeException) { // Unchecked
			throw (RuntimeException)t;
		} else if (t instanceof Error) { // Unchecked
			throw (Error)t;
		} else { // Unexpected
			throw new Error("Unexpected throwable", t);
		}
	}
	
	public static boolean hasHandleMethod(String throwableName) {
		return (!Strings.isEmpty(throwableName) &&
				(	throwableName.equals("SQLException") || 
					throwableName.equals("IOException")));
	}
	public static String getHandleMethodName(String throwableName) {
		if (throwableName.equals("SQLException")) {
			return "handleCatchSqle";
		} else if (throwableName.equals("IOException")) {
			return "handleCatchIoe";
		} else {
			// Did want a single handle method...
			// But might not like it when an error is raised.
			// Anyway shouldn't have asked when an specific method wasn't available.
			return "handleCatchUnchecked";
		}
	}
	
	public static String toString(Object o) {
		// TODO Introduce particular cases
		// TODO Check through the used classes and provide a toString() method.
		if (o instanceof byte[]) {
			DigestData l_digest = DigestData.createDigestData((byte[])o);
			return l_digest.toString();
//		} else if (o instanceof CharSequence && ((CharSequence)o).length() > 16) {
//			DigestData l_digest = DigestData.createDigestData((CharSequence)o);
//			return l_digest.toString();
		} else if (o instanceof RowId) {
			return "RowId:" + Base64.encodeBase64String(((RowId)o).getBytes());
		} else {
			return Strings.toString(o);
		}
	}
}
