/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2;

import java.io.InputStream;
import java.io.Reader;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.math.BigDecimal;
import java.net.URL;
import java.sql.*;
import java.sql.Date;
import java.util.*;


/**
 * @author Javier
 *
 */
public enum JdbcMethod {
	CONN_clearWarnings ("CONN_clearWarnings"),
	CONN_close ("CONN_close"),
	CONN_commit ("CONN_commit"),
	CONN_createArrayOfSOa ("CONN_createArrayOfSOa"),
	CONN_createBlob ("CONN_createBlob"),
	CONN_createClob ("CONN_createClob"),
	CONN_createNClob ("CONN_createNClob"),
	CONN_createQueryObjectCs ("CONN_createQueryObjectCs"),
	CONN_createSQLXML ("CONN_createSQLXML"),
	CONN_createStatement ("CONN_createStatement"),
	CONN_createStatementII ("CONN_createStatementII"),
	CONN_createStatementIII ("CONN_createStatementIII"),
	CONN_createStructSOa ("CONN_createStructSOa"),
	CONN_getAutoCommit ("CONN_getAutoCommit"),
	CONN_getCatalog ("CONN_getCatalog"),
	CONN_getClientInfo ("CONN_getClientInfo"),
	CONN_getClientInfoS ("CONN_getClientInfoS"),
	CONN_getHoldability ("CONN_getHoldability"),
	CONN_getMetaData ("CONN_getMetaData"),
	CONN_getTransactionIsolation ("CONN_getTransactionIsolation"),
	CONN_getTypeMap ("CONN_getTypeMap"),
	CONN_getWarnings ("CONN_getWarnings"),
	CONN_isClosed ("CONN_isClosed"),
	CONN_isReadOnly ("CONN_isReadOnly"),
	CONN_isValidI ("CONN_isValidI"),
	CONN_nativeSQLS ("CONN_nativeSQLS"),
	CONN_prepareCallS ("CONN_prepareCallS"),
	CONN_prepareCallSII ("prepareCallSII"),
	CONN_prepareCallSIII ("CONN_prepareCallSIII"),
	CONN_prepareStatementS ("CONN_prepareStatementS"),
	CONN_prepareStatementSI ("CONN_prepareStatementSI"),
	CONN_prepareStatementSIa ("CONN_prepareStatementSIa"),
	CONN_prepareStatementSII ("CONN_prepareStatementSII"),
	CONN_prepareStatementSIII ("CONN_prepareStatementSIII"),
	CONN_prepareStatementSSa ("CONN_prepareStatementSSa"),
	CONN_releaseSavepointSv ("CONN_releaseSavepointSv"),
	CONN_rollback ("CONN_rollback"),
	CONN_rollbackSv ("CONN_rollbackSv"),
	CONN_setAutoCommitB ("CONN_setAutoCommitB"),
	CONN_setCatalogS ("CONN_setCatalogS"),
	CONN_setClientInfoPr ("CONN_setClientInfoPr"),
	CONN_setClientInfoSS ("CONN_setClientInfoSS"),
	CONN_setHoldabilityI ("CONN_setHoldabilityI"),
	CONN_setReadOnlyB ("CONN_setReadOnlyB"),
	CONN_setSavepoint ("CONN_setSavepoint"),
	CONN_setSavepointS ("CONN_setSavepointS"),
	CONN_setTransactionIsolationI ("CONN_setTransactionIsolationI"),
	CONN_setTypeMapMp ("CONN_setTypeMapMp"),
	STMT_addBatchS ("STMT_addBatchS"),
	STMT_cancel  ("STMT_cancel"),
	STMT_clearBatch  ("STMT_clearBatch"),
	STMT_clearWarnings  ("STMT_clearWarnings"),
	STMT_close ("STMT_close"),
	STMT_executeS ("STMT_executeS"), 
	STMT_executeSI  ("STMT_executeSI"),
	STMT_executeSIa  ("STMT_executeSIa"),
	STMT_executeSSa ("STMT_executeSSa"),
	STMT_executeBatch ("STMT_executeBatch"), 
	STMT_executeQueryS ("STMT_executeQueryS"), 
	STMT_executeUpdateS ("STMT_executeUpdateS"), 
	STMT_executeUpdateSI ("STMT_executeUpdateSI"), 
	STMT_executeUpdateSIa ("STMT_executeUpdateSIa"), 
	STMT_executeUpdateSSa ("STMT_executeUpdateSSa"), 
	STMT_getConnection ("STMT_getConnection"),
	STMT_getFetchDirection ("STMT_getFetchDirection"), 
	STMT_getFetchSize ("STMT_getFetchSize"),
	STMT_getGeneratedKeys ("STMT_getGeneratedKeys"), 
	STMT_getMaxFieldSize ("STMT_getMaxFieldSize"), 
	STMT_getMaxRows ("STMT_getMaxRows"), 
	STMT_getMoreResults ("STMT_getMoreResults"), 
	STMT_getMoreResultsI ("STMT_getMoreResultsI"), 
	STMT_getQueryTimeout ("STMT_getQueryTimeout"), 
	STMT_getResultSet ("STMT_getResultSet"),
	STMT_getResultSetConcurrency ("STMT_getResultSetConcurrency"), 
	STMT_getResultSetHoldability ("STMT_getResultSetHoldability"), 
	STMT_getResultSetType ("STMT_getResultSetType"),
	STMT_getUpdateCount ("STMT_getUpdateCount"), 
	STMT_getWarnings ("STMT_getWarnings"),
	STMT_isClosed ("STMT_isClosed"),
	STMT_isPoolable ("STMT_isPoolable"),
	STMT_setCursorNameS ("STMT_setCursorNameS"), 
	STMT_setEscapeProcessingB  ("STMT_setEscapeProcessingB"),
	STMT_setFetchDirectionI ("STMT_setFetchDirectionI"), 
	STMT_setFetchSizeI ("STMT_setFetchSizeI"), 
	STMT_setMaxFieldSizeI ("STMT_setMaxFieldSizeI"), 
	STMT_setMaxRowsI ("STMT_setMaxRowsI"), 
	STMT_setPoolableB ("STMT_setPoolableB"),
	STMT_setQueryTimeoutI ("STMT_setQueryTimeoutI"),
	
	PRST_addBatch ("PRST_addBatch"),
	PRST_clearParameters ("PRST_clearParameters"),
	PRST_execute ("PRST_execute"),
	PRST_executeQuery ("PRST_executeQuery"),
	PRST_executeUpdate ("PRST_executeUpdate"),
	PRST_getMetaData ("PRST_getMetaData"),
	PRST_getParameterMetaData ("PRST_getParameterMetaData"),
	PRST_isPoolable ("PRST_isPoolable"),
	PRST_setArrayIAr ("PRST_setArrayIAr"),
	PRST_setAsciiStreamIIs ("PRST_setAsciiStreamIIs"),
	PRST_setAsciiStreamIIsI ("PRST_setAsciiStreamIIsI"),
	PRST_setAsciiStreamIIsL ("PRST_setAsciiStreamIIsL"),
	PRST_setBigDecimalIBd ("PRST_setBigDecimalIBd"),
	PRST_setBinaryStreamIIs ("PRST_setBinaryStreamIIs"),
	PRST_setBinaryStreamIIsI ("PRST_setBinaryStreamIIsI"),
	PRST_setBinaryStreamIIsL ("PRST_setBinaryStreamIIsL"),
	PRST_setBlobIBl ("PRST_setBlobIBl"),
	PRST_setBlobIIs ("PRST_setBlobIIs"),
	PRST_setBlobIIsL ("PRST_setBlobIIsL"),
	PRST_setBooleanIB ("PRST_setBooleanIB"),
	PRST_setByteIBy ("PRST_setByteIBy"),
	PRST_setBytesIBya ("PRST_setBytesIBya"),
	PRST_setCharacterStreamIRd ("PRST_setCharacterStreamIRd"),
	PRST_setCharacterStreamIRdI ("PRST_setCharacterStreamIRdI"),
	PRST_setCharacterStreamIRdL ("PRST_setCharacterStreamIRdL"),
	PRST_setClobICl ("PRST_setClobICl"),
	PRST_setClobIRd ("PRST_setClobIRd"),
	PRST_setClobIRdL ("PRST_setClobIRdL"),
	PRST_setDateIDa ("PRST_setDateIDa"),
	PRST_setDateIDaCa ("PRST_setDateIDaCa"),
	PRST_setDoubleID ("PRST_setDoubleID"),
	PRST_setFloatIF ("PRST_setFloatIF"),
	PRST_setIntII ("PRST_setIntII"),
	PRST_setLongIL ("PRST_setLongIL"),
	PRST_setNCharacterStreamIRd ("PRST_setNCharacterStreamIRd"),
	PRST_setNCharacterStreamIRdL ("PRST_setNCharacterStreamIRdL"),
	PRST_setNClobINc ("PRST_setNClobINc"),
	PRST_setNClobIRd ("PRST_setNClobIRd"),
	PRST_setNClobIRdL ("PRST_setNClobIRdL"),
	PRST_setNStringIS ("PRST_setNStringIS"),
	PRST_setNullII ("PRST_setNullII"),
	PRST_setNullIIS ("PRST_setNullIIS"),
	PRST_setObjectIO ("PRST_setObjectIO"),
	PRST_setObjectIOI ("PRST_setObjectIOI"),
	PRST_setObjectIOII ("PRST_setObjectIOII"),
	PRST_setPoolable ("PRST_setPoolable"),
	PRST_setRefIRf ("PRST_setRefIRf"),
	PRST_setRowIdIRi ("PRST_setRowIdIRi"),
	PRST_setShortISh ("PRST_setShortISh"),
	PRST_setSQLXMLISx ("PRST_setSQLXMLISx"),
	PRST_setStringIS ("PRST_setStringIS"),
	PRST_setTimeITi ("PRST_setTimeITi"),
	PRST_setTimeITiCa ("PRST_setTimeITiCa"),
	PRST_setTimestampITm ("PRST_setTimestampITm"),
	PRST_setTimestampITmCa ("PRST_setTimestampITmCa"),
	PRST_setUnicodeStreamIIsI ("PRST_setUnicodeStreamIIsI"),
	PRST_setURLIUr ("PRST_setURLIUr"),
	
	CLST_getArrayI ("CLST_getArrayI"),
	CLST_getArrayS ("CLST_getArrayS"),
	CLST_getBigDecimalI ("CLST_getBigDecimalI"),
	CLST_getBigDecimalII ("CLST_getBigDecimalII"),
	CLST_getBigDecimalS ("CLST_getBigDecimalS"),
	CLST_getBlobI ("CLST_getBlobI"),
	CLST_getBlobS ("CLST_getBlobS"),
	CLST_getBooleanI ("CLST_getBooleanI"),
	CLST_getBooleanS ("CLST_getBooleanS"),
	CLST_getByteI ("CLST_getByteI"),
	CLST_getByteS ("CLST_getByteS"),
	CLST_getBytesI ("CLST_getBytesI"),
	CLST_getBytesS ("CLST_getBytesS"),
	CLST_getCharacterStreamI ("CLST_getCharacterStreamI"),
	CLST_getCharacterStreamS ("CLST_getCharacterStreamS"),
	CLST_getClobI ("CLST_getClobI"),
	CLST_getClobS ("CLST_getClobS"),
	CLST_getDateI ("CLST_getDateI"),
	CLST_getDateICa ("CLST_getDateICa"),
	CLST_getDateS ("CLST_getDateS"),
	CLST_getDateSCa ("CLST_getDateSCa"),
	CLST_getDoubleI ("CLST_getDoubleI"),
	CLST_getDoubleS ("CLST_getDoubleS"),
	CLST_getFloatI ("CLST_getFloatI"),
	CLST_getFloatS ("CLST_getFloatS"),
	CLST_getIntI ("CLST_getIntI"),
	CLST_getIntS ("CLST_getIntS"),
	CLST_getLongI ("CLST_getLongI"),
	CLST_getLongS ("CLST_getLongS"),
	CLST_getNCharacterStreamI ("CLST_getNCharacterStreamI"),
	CLST_getNCharacterStreamS ("CLST_getNCharacterStreamS"),
	CLST_getNClobI ("CLST_getNClobI"),
	CLST_getNClobS ("CLST_getNClobS"),
	CLST_getNStringI ("CLST_getNStringI"),
	CLST_getNStringS ("CLST_getNStringS"),
	CLST_getObjectI ("CLST_getObjectI"),
	CLST_getObjectIMp ("CLST_getObjectIMp"),
	CLST_getObjectS ("CLST_getObjectS"),
	CLST_getObjectSMp ("CLST_getObjectSMp"),
	CLST_getRefI ("CLST_getRefI"),
	CLST_getRefS ("CLST_getRefS"),
	CLST_getRowIdI ("CLST_getRowIdI"),
	CLST_getRowIdS ("CLST_getRowIdS"),
	CLST_getShortI ("CLST_getShortI"),
	CLST_getShortS ("CLST_getShortS"),
	CLST_getSQLXMLI ("CLST_getSQLXMLI"),
	CLST_getSQLXMLS ("CLST_getSQLXMLS"),
	CLST_getStringI ("CLST_getStringI"),
	CLST_getStringS ("CLST_getStringS"),
	CLST_getTimeI ("CLST_getTimeI"),
	CLST_getTimeICa ("CLST_getTimeICa"),
	CLST_getTimeS ("CLST_getTimeS"),
	CLST_getTimeSCa ("CLST_getTimeSCa"),
	CLST_getTimestampI ("CLST_getTimestampI"),
	CLST_getTimestampICa ("CLST_getTimestampICa"),
	CLST_getTimestampS ("CLST_getTimestampS"),
	CLST_getTimestampSCa ("CLST_getTimestampSCa"),
	CLST_getURLI ("CLST_getURLI"),
	CLST_getURLS ("CLST_getURLS"),
	CLST_registerOutParameterII ("CLST_registerOutParameterII"),
	CLST_registerOutParameterIII ("CLST_registerOutParameterIII"),
	CLST_registerOutParameterIIS ("CLST_registerOutParameterIIS"),
	CLST_registerOutParameterSI ("CLST_registerOutParameterSI"),
	CLST_registerOutParameterSII ("CLST_registerOutParameterSII"),
	CLST_registerOutParameterSIS ("CLST_registerOutParameterSIS"),
	CLST_setAsciiStreamSIs ("CLST_setAsciiStreamSIs"),
	CLST_setAsciiStreamSIsI ("CLST_setAsciiStreamSIsI"),
	CLST_setAsciiStreamSIsL ("CLST_setAsciiStreamSIsL"),
	CLST_setBigDecimalSBd ("CLST_setBigDecimalSBd"),
	CLST_setBinaryStreamSIs ("CLST_setBinaryStreamSIs"),
	CLST_setBinaryStreamSIsI ("CLST_setBinaryStreamSIsI"),
	CLST_setBinaryStreamSIsL ("CLST_setBinaryStreamSIsL"),
	CLST_setBlobSBl ("CLST_setBlobSBl"),
	CLST_setBlobSIs (""),
	CLST_setBlobSIsL ("CLST_setBlobSIsL"),
	CLST_setBooleanSB ("CLST_setBooleanSB"),
	CLST_setByteSBy ("CLST_setByteSBy"),
	CLST_setBytesSBya ("CLST_setBytesSBya"),
	CLST_setCharacterStreamSRd ("CLST_setCharacterStreamSRd"),
	CLST_setCharacterStreamSRdI ("CLST_setCharacterStreamSRdI"),
	CLST_setCharacterStreamSRdL ("CLST_setCharacterStreamSRdL"),
	CLST_setClobSCl ("CLST_setClobSCl"),
	CLST_setClobSRd ("CLST_setClobSRd"),
	CLST_setClobSRdL ("CLST_setClobSRdL"),
	CLST_setDateSDa ("CLST_setDateSDa"),
	CLST_setDateSDaCa ("CLST_setDateSDaCa"),
	CLST_setDoubleSD ("CLST_setDoubleSD"),
	CLST_setFloatSF ("CLST_setFloatSF"),
	CLST_setIntSI ("CLST_setIntSI"),
	CLST_setLongSL ("CLST_setLongSL"),
	CLST_setNCharacterStreamSRd (""),
	CLST_setNCharacterStreamSRdL ("CLST_setNCharacterStreamSRdL"),
	CLST_setNClobSNc ("CLST_setNClobSNc"),
	CLST_setNClobSRd ("CLST_setNClobSRd"),
	CLST_setNClobSRdL ("CLST_setNClobSRdL"),
	CLST_setNStringSS ("CLST_setNStringSS"),
	CLST_setNullSI ("CLST_setNullSI"),
	CLST_setNullSIS ("CLST_setNullSIS"),
	CLST_setObjectSO ("CLST_setObjectSO"),
	CLST_setObjectSOI ("CLST_setObjectSOI"),
	CLST_setObjectSOII ("CLST_setObjectSOII"),
	CLST_setRowIdSRi ("CLST_setRowIdSRi"),
	CLST_setShortSSh ("CLST_setShortSSh"),
	CLST_setSQLXMLSSx ("CLST_setSQLXMLSSx"),
	CLST_setStringSS ("CLST_setStringSS"),
	CLST_setTimeSTi ("CLST_setTimeSTi"),
	CLST_setTimeSTiCa ("CLST_setTimeSTiCa"),
	CLST_setTimestampSTm ("CLST_setTimestampSTm"),
	CLST_setTimestampSTmCa ("CLST_setTimestampSTmCa"),
	CLST_setURLSUr ("CLST_setURLSUr"),
	CLST_wasNull ("CLST_wasNull"),
	
	RSST_absoluteI ("RSST_absoluteI"),
	RSST_afterLast ("RSST_afterLast"),
	RSST_beforeFirst ("RSST_beforeFirst"),
	RSST_cancelRowUpdates ("RSST_cancelRowUpdates"),
	RSST_clearWarnings ("RSST_clearWarnings"),
	RSST_close ("RSST_close"),
	RSST_deleteRow ("RSST_deleteRow"),
	RSST_findColumnS ("RSST_findColumnS"),
	RSST_first ("RSST_first"),
	RSST_getArrayI ("RSST_getArrayI"),
	RSST_getArrayS ("RSST_getArrayS"),
	RSST_getAsciiStreamI ("RSST_getAsciiStreamI"),
	RSST_getAsciiStreamS ("RSST_getAsciiStreamS"),
	RSST_getBigDecimalI ("RSST_getBigDecimalI"),
	RSST_getBigDecimalII ("RSST_getBigDecimalII"),
	RSST_getBigDecimalS ("RSST_getBigDecimalS"),
	RSST_getBigDecimalSI ("RSST_getBigDecimalSI"),
	RSST_getBinaryStreamI ("RSST_getBinaryStreamI"),
	RSST_getBinaryStreamS ("RSST_getBinaryStreamS"),
	RSST_getBlobI ("RSST_getBlobI"),
	RSST_getBlobS ("RSST_getBlobS"),
	RSST_getBooleanI ("RSST_getBooleanI"),
	RSST_getBooleanS ("RSST_getBooleanS"),
	RSST_getByteI ("RSST_getByteI"),
	RSST_getByteS ("RSST_getByteS"),
	RSST_getBytesI ("RSST_getBytesI"),
	RSST_getBytesS ("RSST_getBytesS"),
	RSST_getCharacterStreamI ("RSST_getCharacterStreamI"),
	RSST_getCharacterStreamS ("RSST_getCharacterStreamS"),
	RSST_getClobI ("RSST_getClobI"),
	RSST_getClobS ("RSST_getClobS"),
	RSST_getConcurrency ("RSST_getConcurrency"),
	RSST_getCursorName ("RSST_getCursorName"),
	RSST_getDateI ("RSST_getDateI"),
	RSST_getDateICa ("RSST_getDateICa"),
	RSST_getDateS ("RSST_getDateS"),
	RSST_getDateSCa ("RSST_getDateSCa"),
	RSST_getDoubleI ("RSST_getDoubleI"),
	RSST_getDoubleS ("RSST_getDoubleS"),
	RSST_getFetchDirection ("RSST_getFetchDirection"),
	RSST_getFetchSize ("RSST_getFetchSize"),
	RSST_getFloatI ("RSST_getFloatI"),
	RSST_getFloatS ("RSST_getFloatS"),
	RSST_getHoldability ("RSST_getHoldability"),
	RSST_getIntI ("RSST_getIntI"),
	RSST_getIntS ("RSST_getIntS"),
	RSST_getLongI ("RSST_getLongI"),
	RSST_getLongS ("RSST_getLongS"),
	RSST_getMetaData ("RSST_getMetaData"),
	RSST_getNCharacterStreamI ("RSST_getNCharacterStreamI"),
	RSST_getNCharacterStreamS ("RSST_getNCharacterStreamS"),
	RSST_getNClobI ("RSST_getNClobI"),
	RSST_getNClobS ("RSST_getNClobS"),
	RSST_getNStringI ("RSST_getNStringI"),
	RSST_getNStringS ("RSST_getNStringS"),
	RSST_getObjectI ("RSST_getObjectI"),
	RSST_getObjectIMp ("RSST_getObjectIMp"),
	RSST_getObjectS ("RSST_getObjectS"),
	RSST_getObjectSMp ("RSST_getObjectSMp"),
	RSST_getRefI ("RSST_getRefI"),
	RSST_getRefS ("RSST_getRefS"),
	RSST_getRow ("RSST_getRow"),
	RSST_getRowIdI ("RSST_getRowIdI"),
	RSST_getRowIdS ("RSST_getRowIdS"),
	RSST_getShortI ("RSST_getShortI"),
	RSST_getShortS ("RSST_getShortS"),
	RSST_getSQLXMLI ("RSST_getSQLXMLI"),
	RSST_getSQLXMLS ("RSST_getSQLXMLS"),
	RSST_getStatement ("RSST_getStatement"),
	RSST_getStringI ("RSST_getStringI"),
	RSST_getStringS ("RSST_getStringS"),
	RSST_getTimeI ("RSST_getTimeI"),
	RSST_getTimeICa ("RSST_getTimeICa"),
	RSST_getTimeS ("RSST_getTimeS"),
	RSST_getTimeSCa ("RSST_getTimeSCa"),
	RSST_getTimestampI ("RSST_getTimestampI"),
	RSST_getTimestampICa ("RSST_getTimestampICa"),
	RSST_getTimestampS ("RSST_getTimestampS"),
	RSST_getTimestampSCa ("RSST_getTimestampSCa"),
	RSST_getType ("RSST_getType"),
	RSST_getUnicodeStreamI ("RSST_getUnicodeStreamI"),
	RSST_getUnicodeStreamS ("RSST_getUnicodeStreamS"),
	RSST_getURLI ("RSST_getURLI"),
	RSST_getURLS ("RSST_getURLS"),
	RSST_getWarnings ("RSST_getWarnings"),
	RSST_insertRow ("RSST_insertRow"),
	RSST_isAfterLast ("RSST_isAfterLast"),
	RSST_isBeforeFirst ("RSST_isBeforeFirst"),
	RSST_isClosed ("RSST_isClosed"),
	RSST_isFirst ("RSST_isFirst"),
	RSST_isLast ("RSST_isLast"),
	RSST_last ("RSST_last"),
	RSST_moveToCurrentRow ("RSST_moveToCurrentRow"),
	RSST_moveToInsertRow ("RSST_moveToInsertRow"),
	RSST_next ("RSST_next"),
	RSST_previous ("RSST_previous"),
	RSST_refreshRow ("RSST_refreshRow"),
	RSST_relativeI ("RSST_relativeI"),
	RSST_rowDeleted ("RSST_rowDeleted"),
	RSST_rowInserted ("RSST_rowInserted"),
	RSST_rowUpdated ("RSST_rowUpdated"),
	RSST_setFetchDirectionI ("RSST_setFetchDirectionI"),
	RSST_setFetchSizeI ("RSST_setFetchSizeI"),
	RSST_updateArrayIAr ("RSST_updateArrayIAr"),
	RSST_updateArraySAr ("RSST_updateArraySAr"),
	RSST_updateAsciiStreamIIs (""),
	RSST_updateAsciiStreamIIsI ("RSST_updateAsciiStreamIIsI"),
	RSST_updateAsciiStreamIIsL ("RSST_updateAsciiStreamIIsL"),
	RSST_updateAsciiStreamSIs ("RSST_updateAsciiStreamSIs"),
	RSST_updateAsciiStreamSIsI ("RSST_updateAsciiStreamSIsI"),
	RSST_updateAsciiStreamSIsL ("RSST_updateAsciiStreamSIsL"),
	RSST_updateBigDecimalIBd ("RSST_updateBigDecimalIBd"),
	RSST_updateBigDecimalSBd ("RSST_updateBigDecimalSBd"),
	RSST_updateBinaryStreamIIs ("RSST_updateBinaryStreamIIs"),
	RSST_updateBinaryStreamIIsI ("RSST_updateBinaryStreamIIsI"),
	RSST_updateBinaryStreamIIsL ("RSST_updateBinaryStreamIIsL"),
	RSST_updateBinaryStreamSIs ("RSST_updateBinaryStreamSIs"),
	RSST_updateBinaryStreamSIsI ("RSST_updateBinaryStreamSIsI"),
	RSST_updateBinaryStreamSIsL ("RSST_updateBinaryStreamSIsL"),
	RSST_updateBlobIIs ("RSST_updateBlobIIs"),
	RSST_updateBlobIBl ("RSST_updateBlobIBl"),
	RSST_updateBlobIIsL ("RSST_updateBlobIIsL"),
	RSST_updateBlobSIs ("RSST_updateBlobSIs"),
	RSST_updateBlobSBl ("RSST_updateBlobSBl"),
	RSST_updateBlobSIsL ("RSST_updateBlobSIsL"),
	RSST_updateBooleanIB ("RSST_updateBooleanIB"),
	RSST_updateBooleanSB ("RSST_updateBooleanSB"),
	RSST_updateByteIBy ("RSST_updateByteIBy"),
	RSST_updateByteSBy ("RSST_updateByteSBy"),
	RSST_updateBytesIBya ("RSST_updateBytesIBya"),
	RSST_updateBytesSBya ("RSST_updateBytesSBya"),
	RSST_updateCharacterStreamIRd ("RSST_updateCharacterStreamIRd"),
	RSST_updateCharacterStreamIRdI ("RSST_updateCharacterStreamIRdI"),
	RSST_updateCharacterStreamIRdL ("RSST_updateCharacterStreamIRdL"),
	RSST_updateCharacterStreamSRd ("RSST_updateCharacterStreamSRd"),
	RSST_updateCharacterStreamSRdI ("RSST_updateCharacterStreamSRdI"),
	RSST_updateCharacterStreamSRdL ("RSST_updateCharacterStreamSRdL"),
	RSST_updateClobIRd ("RSST_updateClobIRd"),
	RSST_updateClobICl ("RSST_updateClobICl"),
	RSST_updateClobIRdL ("RSST_updateClobIRdL"),
	RSST_updateClobSRd ("RSST_updateClobSRd"),
	RSST_updateClobSCl ("RSST_updateClobSCl"),
	RSST_updateClobSRdL ("RSST_updateClobSRdL"),
	RSST_updateDateIDa ("RSST_updateDateIDa"),
	RSST_updateDateSDa ("RSST_updateDateSDa"),
	RSST_updateDoubleID ("RSST_updateDoubleID"),
	RSST_updateDoubleSD ("RSST_updateDoubleSD"),
	RSST_updateFloatIF ("RSST_updateFloatIF"),
	RSST_updateFloatSF ("RSST_updateFloatSF"),
	RSST_updateIntII ("RSST_updateIntII"),
	RSST_updateIntSI ("RSST_updateIntSI"),
	RSST_updateLongIL ("RSST_updateLongIL"),
	RSST_updateLongSL ("RSST_updateLongSL"),
	RSST_updateNCharacterStreamIRd ("RSST_updateNCharacterStreamIRd"),
	RSST_updateNCharacterStreamIRdI ("RSST_updateNCharacterStreamIRdI"),
	RSST_updateNCharacterStreamIRdL ("RSST_updateNCharacterStreamIRdL"),
	RSST_updateNCharacterStreamSRd ("RSST_updateNCharacterStreamSRd"),
	RSST_updateNCharacterStreamSRdI ("RSST_updateNCharacterStreamSRdI"),
	RSST_updateNCharacterStreamSRdL ("RSST_updateNCharacterStreamSRdL"),
	RSST_updateNClobIRd ("RSST_updateNClobIRd"),
	RSST_updateNClobINc ("RSST_updateNClobINc"),
	RSST_updateNClobIRdL ("RSST_updateNClobIRdL"),
	RSST_updateNClobSRd ("RSST_updateNClobSRd"),
	RSST_updateNClobSNc ("RSST_updateNClobSNc"),
	RSST_updateNClobSRdL ("RSST_updateNClobSRdL"),
	RSST_updateNStringIS ("RSST_updateNStringIS"),
	RSST_updateNStringSS ("RSST_updateNStringSS"),
	RSST_updateNullI ("RSST_updateNullI"),
	RSST_updateNullS ("RSST_updateNullS"),
	RSST_updateObjectIO ("RSST_updateObjectIO"),
	RSST_updateObjectIOI ("RSST_updateObjectIOI"),
	RSST_updateObjectSO ("RSST_updateObjectSO"),
	RSST_updateObjectSOI ("RSST_updateObjectSOI"),
	RSST_updateRefIRf ("RSST_updateRefIRf"),
	RSST_updateRefSRf ("RSST_updateRefSRf"),
	RSST_updateRow ("RSST_updateRow"),
	RSST_updateRowIdIRi ("RSST_updateRowIdIRi"),
	RSST_updateRowIdSRi ("RSST_updateRowIdSRi"),
	RSST_updateShortISh ("RSST_updateShortISh"),
	RSST_updateShortSSh ("RSST_updateShortSSh"),
	RSST_updateSQLXMLISx ("RSST_updateSQLXMLISx"),
	RSST_updateSQLXMLSSx ("RSST_updateSQLXMLSSx"),
	RSST_updateStringIS ("RSST_updateStringIS"),
	RSST_updateStringSS ("RSST_updateStringSS"),
	RSST_updateTimeITi ("RSST_updateTimeITi"),
	RSST_updateTimeSTi ("RSST_updateTimeSTi"),
	RSST_updateTimestampITm ("RSST_updateTimestampITm"),
	RSST_updateTimestampSTm ("RSST_updateTimestampSTm"),
	RSST_wasNull ("RSST_wasNull"),
	
	DBMD_allProceduresAreCallable ("DBMD_allProceduresAreCallable"),
	DBMD_allTablesAreSelectable ("DBMD_allTablesAreSelectable"),
	DBMD_autoCommitFailureClosesAllResultSets ("DBMD_autoCommitFailureClosesAllResultSets"),
	DBMD_dataDefinitionCausesTransactionCommit ("DBMD_dataDefinitionCausesTransactionCommit"),
	DBMD_dataDefinitionIgnoredInTransactions ("DBMD_dataDefinitionIgnoredInTransactions"),
	DBMD_deletesAreDetectedI ("DBMD_deletesAreDetectedI"),
	DBMD_doesMaxRowSizeIncludeBlobs ("DBMD_doesMaxRowSizeIncludeBlobs"),
	DBMD_getAttributesSSSS ("DBMD_getAttributesSSSS"),
	DBMD_getBestRowIdentifierSSSIB ("DBMD_getBestRowIdentifierSSSIB"),
	DBMD_getCatalogs ("DBMD_getCatalogs"),
	DBMD_getCatalogSeparator ("DBMD_getCatalogSeparator"),
	DBMD_getCatalogTerm ("DBMD_getCatalogTerm"),
	DBMD_getClientInfoProperties ("DBMD_getClientInfoProperties"),
	DBMD_getColumnPrivilegesSSSS ("DBMD_getColumnPrivilegesSSSS"),
	DBMD_getColumnsSSSS ("DBMD_getColumnsSSSS"),
	DBMD_getConnection ("DBMD_getConnection"),
	DBMD_getCrossReferenceSSSSSS ("DBMD_getCrossReferenceSSSSSS"),
	DBMD_getDatabaseMajorVersion ("DBMD_getDatabaseMajorVersion"),
	DBMD_getDatabaseMinorVersion ("DBMD_getDatabaseMinorVersion"),
	DBMD_getDatabaseProductName ("DBMD_getDatabaseProductName"),
	DBMD_getDatabaseProductVersion ("DBMD_getDatabaseProductVersion"),
	DBMD_getDefaultTransactionIsolation ("DBMD_getDefaultTransactionIsolation"),
	DBMD_getDriverMajorVersion ("DBMD_getDriverMajorVersion"),
	DBMD_getDriverMinorVersion ("DBMD_getDriverMinorVersion"),
	DBMD_getDriverName ("DBMD_getDriverName"),
	DBMD_getDriverVersion ("DBMD_getDriverVersion"),
	DBMD_getExportedKeysSSS ("DBMD_getExportedKeysSSS"),
	DBMD_getExtraNameCharacters ("DBMD_getExtraNameCharacters"),
	DBMD_getFunctionColumnsSSSS ("DBMD_getFunctionColumnsSSSS"),
	DBMD_getFunctionsSSS ("DBMD_getFunctionsSSS"),
	DBMD_getIdentifierQuoteString ("DBMD_getIdentifierQuoteString"),
	DBMD_getImportedKeysSSS ("DBMD_getImportedKeysSSS"),
	DBMD_getIndexInfoSSSBB ("DBMD_getIndexInfoSSSBB"),
	DBMD_getJDBCMajorVersion ("DBMD_getJDBCMajorVersion"),
	DBMD_getJDBCMinorVersion ("DBMD_getJDBCMinorVersion"),
	DBMD_getMaxBinaryLiteralLength ("DBMD_getMaxBinaryLiteralLength"),
	DBMD_getMaxCatalogNameLength ("DBMD_getMaxCatalogNameLength"),
	DBMD_getMaxCharLiteralLength ("DBMD_getMaxCharLiteralLength"),
	DBMD_getMaxColumnNameLength ("DBMD_getMaxColumnNameLength"),
	DBMD_getMaxColumnsInGroupBy ("DBMD_getMaxColumnsInGroupBy"),
	DBMD_getMaxColumnsInIndex ("DBMD_getMaxColumnsInIndex"),
	DBMD_getMaxColumnsInOrderBy ("DBMD_getMaxColumnsInOrderBy"),
	DBMD_getMaxColumnsInSelect ("DBMD_getMaxColumnsInSelect"),
	DBMD_getMaxColumnsInTable ("DBMD_getMaxColumnsInTable"),
	DBMD_getMaxConnections ("DBMD_getMaxConnections"),
	DBMD_getMaxCursorNameLength ("DBMD_getMaxCursorNameLength"),
	DBMD_getMaxIndexLength ("DBMD_getMaxIndexLength"),
	DBMD_getMaxProcedureNameLength ("DBMD_getMaxProcedureNameLength"),
	DBMD_getMaxRowSize ("DBMD_getMaxRowSize"),
	DBMD_getMaxSchemaNameLength ("DBMD_getMaxSchemaNameLength"),
	DBMD_getMaxStatementLength ("DBMD_getMaxStatementLength"),
	DBMD_getMaxStatements ("DBMD_getMaxStatements"),
	DBMD_getMaxTableNameLength ("DBMD_getMaxTableNameLength"),
	DBMD_getMaxTablesInSelect ("DBMD_getMaxTablesInSelect"),
	DBMD_getMaxUserNameLength ("DBMD_getMaxUserNameLength"),
	DBMD_getNumericFunctions ("DBMD_getNumericFunctions"),
	DBMD_getPrimaryKeysSSS ("DBMD_getPrimaryKeysSSS"),
	DBMD_getProcedureColumnsSSSS ("DBMD_getProcedureColumnsSSSS"),
	DBMD_getProceduresSSS ("DBMD_getProceduresSSS"),
	DBMD_getProcedureTerm ("DBMD_getProcedureTerm"),
	DBMD_getResultSetHoldability ("DBMD_getResultSetHoldability"),
	DBMD_getRowIdLifetime ("DBMD_getRowIdLifetime"),
	DBMD_getSchemas ("DBMD_getSchemas"),
	DBMD_getSchemasSS ("DBMD_getSchemasSS"),
	DBMD_getSchemaTerm ("DBMD_getSchemaTerm"),
	DBMD_getSearchStringEscape ("DBMD_getSearchStringEscape"),
	DBMD_getSQLKeywords ("DBMD_getSQLKeywords"),
	DBMD_getSQLStateType ("DBMD_getSQLStateType"),
	DBMD_getStringFunctions ("DBMD_getStringFunctions"),
	DBMD_getSuperTablesSSS ("DBMD_getSuperTablesSSS"),
	DBMD_getSuperTypesSSS ("DBMD_getSuperTypesSSS"),
	DBMD_getSystemFunctions ("DBMD_getSystemFunctions"),
	DBMD_getTablePrivilegesSSS ("DBMD_getTablePrivilegesSSS"),
	DBMD_getTablesSSSSa ("DBMD_getTablesSSSSa"),
	DBMD_getTableTypes ("DBMD_getTableTypes"),
	DBMD_getTimeDateFunctions ("DBMD_getTimeDateFunctions"),
	DBMD_getTypeInfo ("DBMD_getTypeInfo"),
	DBMD_getUDTsSSSIa ("DBMD_getUDTsSSSIa"),
	DBMD_getURL ("DBMD_getURL"),
	DBMD_getUserName ("DBMD_getUserName"),
	DBMD_getVersionColumnsSSS ("DBMD_getVersionColumnsSSS"),
	DBMD_insertsAreDetectedI ("DBMD_insertsAreDetectedI"),
	DBMD_isCatalogAtStart ("DBMD_isCatalogAtStart"),
	DBMD_isReadOnly ("DBMD_isReadOnly"),
	DBMD_locatorsUpdateCopy ("DBMD_locatorsUpdateCopy"),
	DBMD_nullPlusNonNullIsNull ("DBMD_nullPlusNonNullIsNull"),
	DBMD_nullsAreSortedAtEnd ("DBMD_nullsAreSortedAtEnd"),
	DBMD_nullsAreSortedAtStart ("DBMD_nullsAreSortedAtStart"),
	DBMD_nullsAreSortedHigh ("DBMD_nullsAreSortedHigh"),
	DBMD_nullsAreSortedLow ("DBMD_nullsAreSortedLow"),
	DBMD_othersDeletesAreVisibleI ("DBMD_othersDeletesAreVisibleI"),
	DBMD_othersInsertsAreVisibleI ("DBMD_othersInsertsAreVisibleI"),
	DBMD_othersUpdatesAreVisibleI ("DBMD_othersUpdatesAreVisibleI"),
	DBMD_ownDeletesAreVisibleI ("DBMD_ownDeletesAreVisibleI"),
	DBMD_ownInsertsAreVisibleI ("DBMD_ownInsertsAreVisibleI"),
	DBMD_ownUpdatesAreVisibleI ("DBMD_ownUpdatesAreVisibleI"),
	DBMD_providesQueryObjectGenerator ("DBMD_providesQueryObjectGenerator"),
	DBMD_storesLowerCaseIdentifiers ("DBMD_storesLowerCaseIdentifiers"),
	DBMD_storesLowerCaseQuotedIdentifiers ("DBMD_storesLowerCaseQuotedIdentifiers"),
	DBMD_storesMixedCaseIdentifiers ("DBMD_storesMixedCaseIdentifiers"),
	DBMD_storesMixedCaseQuotedIdentifiers ("DBMD_storesMixedCaseQuotedIdentifiers"),
	DBMD_storesUpperCaseIdentifiers ("DBMD_storesUpperCaseIdentifiers"),
	DBMD_storesUpperCaseQuotedIdentifiers ("DBMD_storesUpperCaseQuotedIdentifiers"),
	DBMD_supportsAlterTableWithAddColumn ("DBMD_supportsAlterTableWithAddColumn"),
	DBMD_supportsAlterTableWithDropColumn ("DBMD_supportsAlterTableWithDropColumn"),
	DBMD_supportsANSI92EntryLevelSQL ("DBMD_supportsANSI92EntryLevelSQL"),
	DBMD_supportsANSI92FullSQL ("DBMD_supportsANSI92FullSQL"),
	DBMD_supportsANSI92IntermediateSQL ("DBMD_supportsANSI92IntermediateSQL"),
	DBMD_supportsBatchUpdates ("DBMD_supportsBatchUpdates"),
	DBMD_supportsCatalogsInDataManipulation ("DBMD_supportsCatalogsInDataManipulation"),
	DBMD_supportsCatalogsInIndexDefinitions ("DBMD_supportsCatalogsInIndexDefinitions"),
	DBMD_supportsCatalogsInPrivilegeDefinitions ("DBMD_supportsCatalogsInPrivilegeDefinitions"),
	DBMD_supportsCatalogsInProcedureCalls ("DBMD_supportsCatalogsInProcedureCalls"),
	DBMD_supportsCatalogsInTableDefinitions ("DBMD_supportsCatalogsInTableDefinitions"),
	DBMD_supportsColumnAliasing ("DBMD_supportsColumnAliasing"),
	DBMD_supportsConvert ("DBMD_supportsConvert"),
	DBMD_supportsConvertII ("DBMD_supportsConvertII"),
	DBMD_supportsCoreSQLGrammar ("DBMD_supportsCoreSQLGrammar"),
	DBMD_supportsCorrelatedSubqueries ("DBMD_supportsCorrelatedSubqueries"),
	DBMD_supportsDataDefinitionAndDataManipulationTransactions ("DBMD_supportsDataDefinitionAndDataManipulationTransactions"),
	DBMD_supportsDataManipulationTransactionsOnly ("DBMD_supportsDataManipulationTransactionsOnly"),
	DBMD_supportsDifferentTableCorrelationNames ("DBMD_supportsDifferentTableCorrelationNames"),
	DBMD_supportsExpressionsInOrderBy ("DBMD_supportsExpressionsInOrderBy"),
	DBMD_supportsExtendedSQLGrammar ("DBMD_supportsExtendedSQLGrammar"),
	DBMD_supportsFullOuterJoins ("DBMD_supportsFullOuterJoins"),
	DBMD_supportsGetGeneratedKeys ("DBMD_supportsGetGeneratedKeys"),
	DBMD_supportsGroupBy ("DBMD_supportsGroupBy"),
	DBMD_supportsGroupByBeyondSelect ("DBMD_supportsGroupByBeyondSelect"),
	DBMD_supportsGroupByUnrelated ("DBMD_supportsGroupByUnrelated"),
	DBMD_supportsIntegrityEnhancementFacility ("DBMD_supportsIntegrityEnhancementFacility"),
	DBMD_supportsLikeEscapeClause ("DBMD_supportsLikeEscapeClause"),
	DBMD_supportsLimitedOuterJoins ("DBMD_supportsLimitedOuterJoins"),
	DBMD_supportsMinimumSQLGrammar ("DBMD_supportsMinimumSQLGrammar"),
	DBMD_supportsMixedCaseIdentifiers ("DBMD_supportsMixedCaseIdentifiers"),
	DBMD_supportsMixedCaseQuotedIdentifiers ("DBMD_supportsMixedCaseQuotedIdentifiers"),
	DBMD_supportsMultipleOpenResults ("DBMD_supportsMultipleOpenResults"),
	DBMD_supportsMultipleResultSets ("DBMD_supportsMultipleResultSets"),
	DBMD_supportsMultipleTransactions ("DBMD_supportsMultipleTransactions"),
	DBMD_supportsNamedParameters ("DBMD_supportsNamedParameters"),
	DBMD_supportsNonNullableColumns ("DBMD_supportsNonNullableColumns"),
	DBMD_supportsOpenCursorsAcrossCommit ("DBMD_supportsOpenCursorsAcrossCommit"),
	DBMD_supportsOpenCursorsAcrossRollback ("DBMD_supportsOpenCursorsAcrossRollback"),
	DBMD_supportsOpenStatementsAcrossCommit ("DBMD_supportsOpenStatementsAcrossCommit"),
	DBMD_supportsOpenStatementsAcrossRollback ("DBMD_supportsOpenStatementsAcrossRollback"),
	DBMD_supportsOrderByUnrelated ("DBMD_supportsOrderByUnrelated"),
	DBMD_supportsOuterJoins ("DBMD_supportsOuterJoins"),
	DBMD_supportsPositionedDelete ("DBMD_supportsPositionedDelete"),
	DBMD_supportsPositionedUpdate ("DBMD_supportsPositionedUpdate"),
	DBMD_supportsResultSetConcurrencyII ("DBMD_supportsResultSetConcurrencyII"),
	DBMD_supportsResultSetHoldabilityI ("DBMD_supportsResultSetHoldabilityI"),
	DBMD_supportsResultSetTypeI ("DBMD_supportsResultSetTypeI"),
	DBMD_supportsSavepoints ("DBMD_supportsSavepoints"),
	DBMD_supportsSchemasInDataManipulation ("DBMD_supportsSchemasInDataManipulation"),
	DBMD_supportsSchemasInIndexDefinitions ("DBMD_supportsSchemasInIndexDefinitions"),
	DBMD_supportsSchemasInPrivilegeDefinitions ("DBMD_supportsSchemasInPrivilegeDefinitions"),
	DBMD_supportsSchemasInProcedureCalls ("DBMD_supportsSchemasInProcedureCalls"),
	DBMD_supportsSchemasInTableDefinitions ("DBMD_supportsSchemasInTableDefinitions"),
	DBMD_supportsSelectForUpdate ("DBMD_supportsSelectForUpdate"),
	DBMD_supportsStatementPooling ("DBMD_supportsStatementPooling"),
	DBMD_supportsStoredFunctionsUsingCallSyntax ("DBMD_supportsStoredFunctionsUsingCallSyntax"),
	DBMD_supportsStoredProcedures ("DBMD_supportsStoredProcedures"),
	DBMD_supportsSubqueriesInComparisons ("DBMD_supportsSubqueriesInComparisons"),
	DBMD_supportsSubqueriesInExists ("DBMD_supportsSubqueriesInExists"),
	DBMD_supportsSubqueriesInIns ("DBMD_supportsSubqueriesInIns"),
	DBMD_supportsSubqueriesInQuantifieds ("DBMD_supportsSubqueriesInQuantifieds"),
	DBMD_supportsTableCorrelationNames ("DBMD_supportsTableCorrelationNames"),
	DBMD_supportsTransactionIsolationLevelI ("DBMD_supportsTransactionIsolationLevelI"),
	DBMD_supportsTransactions ("DBMD_supportsTransactions"),
	DBMD_supportsUnion ("DBMD_supportsUnion"),
	DBMD_supportsUnionAll ("DBMD_supportsUnionAll"),
	DBMD_updatesAreDetectedI ("DBMD_updatesAreDetectedI"),
	DBMD_usesLocalFilePerTable ("DBMD_usesLocalFilePerTable"),
	DBMD_usesLocalFiles ("DBMD_usesLocalFiles"),
	
	RSMD_getCatalogNameI ("RSMD_getCatalogNameI"),
	RSMD_getColumnClassNameI ("RSMD_getColumnClassNameI"),
	RSMD_getColumnCount ("RSMD_getColumnCount"),
	RSMD_getColumnDisplaySizeI ("RSMD_getColumnDisplaySizeI"),
	RSMD_getColumnLabelI ("RSMD_getColumnLabelI"),
	RSMD_getColumnNameI ("RSMD_getColumnNameI"),
	RSMD_getColumnTypeI ("RSMD_getColumnTypeI"),
	RSMD_getColumnTypeNameI ("RSMD_getColumnTypeNameI"),
	RSMD_getPrecisionI ("RSMD_getPrecisionI"),
	RSMD_getScaleI ("RSMD_getScaleI"),
	RSMD_getSchemaNameI ("RSMD_getSchemaNameI"),
	RSMD_getTableNameI ("RSMD_getTableNameI"),
	RSMD_isAutoIncrementI ("RSMD_isAutoIncrementI"),
	RSMD_isCaseSensitiveI ("RSMD_isCaseSensitiveI"),
	RSMD_isCurrencyI ("RSMD_isCurrencyI"),
	RSMD_isDefinitelyWritableI ("RSMD_isDefinitelyWritableI"),
	RSMD_isNullableI ("RSMD_isNullableI"),
	RSMD_isReadOnlyI ("RSMD_isReadOnlyI"),
	RSMD_isSearchableI ("RSMD_isSearchableI"),
	RSMD_isSignedI ("RSMD_isSignedI"),
	RSMD_isWritableI ("RSMD_isWritableI"),

	PMMD_getParameterClassNameI ("PMMD_getParameterClassNameI"),
	PMMD_getParameterCount ("PMMD_getParameterCount"),
	PMMD_getParameterModeI ("PMMD_getParameterModeI"),
	PMMD_getParameterTypeI ("PMMD_getParameterTypeI"),
	PMMD_getParameterTypeNameI ("PMMD_getParameterTypeNameI"),
	PMMD_getPrecisionI ("PMMD_getPrecisionI"),
	PMMD_getScaleI ("PMMD_getScaleI"),
	PMMD_isNullableI ("PMMD_isNullableI"),
	PMMD_isSignedI ("PMMD_isSignedI"),
	
	ARRY_free ("ARRY_free"),
	ARRY_getArray ("ARRY_getArray"),
	ARRY_getArrayLIMp ("ARRY_getArrayLIMp"),
	ARRY_getArrayLI ("ARRY_getArrayLI"),
	ARRY_getArrayMp ("ARRY_getArrayMp"),
	ARRY_getBaseType ("ARRY_getBaseType"),
	ARRY_getBaseTypeName ("ARRY_getBaseTypeName"),
	ARRY_getResultSet ("ARRY_getResultSet"),
	ARRY_getResultSetLIMp ("ARRY_getResultSetLIMp"),
	ARRY_getResultSetLI ("ARRY_getResultSetLI"),
	ARRY_getResultSetMp ("ARRY_getResultSetMp"),

	BLOB_free ("BLOB_free"),
	BLOB_getBinaryStream ("BLOB_getBinaryStream"),
	BLOB_getBinaryStreamLL ("BLOB_getBinaryStreamLL"),
	BLOB_getBytesLI ("BLOB_getBytesLI"),
	BLOB_length ("BLOB_length"),
	BLOB_positionBlL ("BLOB_positionBlL"),
	BLOB_positionByaL ("BLOB_positionByaL"),
	BLOB_setBinaryStreamL ("BLOB_setBinaryStreamL"),
	BLOB_setBytesLByaII ("BLOB_setBytesLByaII"),
	BLOB_setBytesLBya ("BLOB_setBytesLBya"),
	BLOB_truncateL ("BLOB_truncateL"),
	CLOB_free ("CLOB_free"),
	CLOB_getAsciiStream ("CLOB_getAsciiStream"),
	CLOB_getCharacterStream ("CLOB_getCharacterStream"),
	CLOB_getCharacterStreamLL ("CLOB_getCharacterStreamLL"),
	CLOB_getSubStringLI ("CLOB_getSubStringLI"),
	CLOB_length ("CLOB_length"),
	CLOB_positionClL ("CLOB_positionClL"),
	CLOB_positionSL ("CLOB_positionSL"),
	CLOB_setAsciiStreamL ("CLOB_setAsciiStreamL"),
	CLOB_setCharacterStreamL ("CLOB_setCharacterStreamL"),
	CLOB_setStringLSII ("CLOB_setStringLSII"),
	CLOB_setStringLS ("CLOB_setStringLS"),
	CLOB_truncateL ("CLOB_truncateL"),
	NLOB_free ("NLOB_free"),
	NLOB_getAsciiStream ("NLOB_getAsciiStream"),
	NLOB_getCharacterStream ("NLOB_getCharacterStream"),
	NLOB_getCharacterStreamLL ("NLOB_getCharacterStreamLL"),
	NLOB_getSubStringLI ("NLOB_getSubStringLI"),
	NLOB_length ("NLOB_length"),
	NLOB_positionClL ("NLOB_positionClL"),
	NLOB_positionSL ("NLOB_positionSL"),
	NLOB_setAsciiStreamL ("NLOB_setAsciiStreamL"),
	NLOB_setCharacterStreamL ("NLOB_setCharacterStreamL"),
	NLOB_setStringLSII ("NLOB_setStringLSII"),
	NLOB_setStringLS ("NLOB_setStringLS"),
	NLOB_truncateL ("NLOB_truncateL"),

	REF__getBaseTypeName ("REF__getBaseTypeName"),
	REF__getObject ("REF__getObject"),
	REF__getObjectMp ("REF__getObjectMp"),
	REF__setObjectO ("REF__setObjectO"),
	SVPT_getSavepointId ("SVPT_getSavepointId"),
	SVPT_getSavepointName ("SVPT_getSavepointName"),
	SXML_free ("SXML_free"),
	SXML_getBinaryStream ("SXML_getBinaryStream"),
	SXML_getCharacterStream ("SXML_getCharacterStream"),
	SXML_getSourceCs ("SXML_getSourceCs"),
	SXML_getString ("SXML_getString"),
	SXML_setBinaryStream ("SXML_setBinaryStream"),
	SXML_setCharacterStream ("SXML_setCharacterStream"),
	SXML_setResultCs ("SXML_setResultCs"),
	SXML_setStringS ("SXML_setStringS"),
	STRT_getAttributes ("STRT_getAttributes"),
	STRT_getAttributesMp ("STRT_getAttributesMp"),
	STRT_getSQLTypeName ("STRT_getSQLTypeName")

;

	public static final Map<String,JdbcMethod> methodsById = genMethodsById();
	public static final List<Class<?>> reflectedClasses = genReflectedClasses();
	public static final Map<Class<?>,String> prefixByReflectedClass = genPrefixByReflectedClass();
	public static final Map<Class<?>,String> abbrevByParamType = getAbbrevByParamType();
	
	private static Map<String,JdbcMethod> genMethodsById() {
		JdbcMethod[] l_instances = JdbcMethod.class.getEnumConstants();
		HashMap<String,JdbcMethod> l_map = new HashMap<String, JdbcMethod>((int)(l_instances.length / 0.75 + 1)); 
		for (JdbcMethod l_method : l_instances) {
			l_map.put(l_method.name(), l_method);
		}
		return Collections.unmodifiableMap(l_map);
	}

	private static List<Class<?>> genReflectedClasses() {
		return Collections.unmodifiableList(Arrays.<Class<?>>asList(Connection.class,
				Statement.class,PreparedStatement.class,CallableStatement.class,ResultSet.class,
				Array.class,Blob.class,Clob.class,NClob.class,
				Ref.class,Struct.class,SQLXML.class,Savepoint.class,
				DatabaseMetaData.class,ResultSetMetaData.class,ParameterMetaData.class));
	}

	private static Map<Class<?>, String> genPrefixByReflectedClass() {
		HashMap<Class<?>, String> l_map = new HashMap<Class<?>, String>(32);
		l_map.put(Connection.class,"CONN");
		l_map.put(Statement.class,"STMT");
		l_map.put(PreparedStatement.class,"PRST");
		l_map.put(CallableStatement.class,"CLST");
		l_map.put(ResultSet.class,"RSST");
		l_map.put(Array.class,"ARRY");
		l_map.put(Blob.class,"BLOB");
		l_map.put(Clob.class,"CLOB");
		l_map.put(NClob.class,"NLOB");
		l_map.put(Ref.class,"REF_");
		l_map.put(Struct.class,"STRT");
		l_map.put(SQLXML.class,"SXML");
		l_map.put(Savepoint.class,"SVPT");
		l_map.put(DatabaseMetaData.class,"DBMD");
		l_map.put(ResultSetMetaData.class,"RSMD");
		l_map.put(ParameterMetaData.class,"PRMD");

		return Collections.unmodifiableMap(l_map);
	}

	private static Map<Class<?>, String> getAbbrevByParamType() {
		HashMap<Class<?>, String> l_map = new HashMap<Class<?>, String>(32);
		l_map.put(Array.class,"Ar");
		l_map.put(boolean.class,"B");
		l_map.put(BigDecimal.class,"Bd");
		l_map.put(Blob.class,"Bl");
		l_map.put(byte.class,"By");
		l_map.put(byte[].class,"Bya");
		l_map.put(Calendar.class,"Ca");
		l_map.put(Clob.class,"Cl");
		l_map.put(Class.class,"Cs");
		l_map.put(double.class,"D");
		l_map.put(Date.class,"Da");
		l_map.put(float.class,"F");
		l_map.put(int.class,"I");
		l_map.put(int[].class,"Ia");
		l_map.put(InputStream.class,"Is");
		l_map.put(long.class,"L");
		l_map.put(Map.class,"Mp");
		l_map.put(NClob.class,"Nc");
		l_map.put(Object.class,"O");
		l_map.put(Object[].class,"Oa");
		l_map.put(Properties.class,"Pr");
		l_map.put(Reader.class,"Rd");
		l_map.put(RowId.class,"Ri");
		l_map.put(Ref.class,"Rf");
		l_map.put(String.class,"S");
		l_map.put(String[].class,"Sa");
		l_map.put(short.class,"Sh");
		l_map.put(Savepoint.class,"Sv");
		l_map.put(SQLXML.class,"Sx");
		l_map.put(Time.class,"Ti");
		l_map.put(Timestamp.class,"Tm");
		l_map.put(URL.class,"Ur");
		return Collections.unmodifiableMap(l_map);
	}


	static {
		// Assign reflection method to each constant.
		for (Map.Entry<Class<?>,String> l_entry : prefixByReflectedClass.entrySet()) {
			Class<?> l_class = l_entry.getKey();
			String l_prefix = l_entry.getValue() + "_";
			StringBuilder l_methodId = new StringBuilder();
			Method[] l_methods = l_class.getDeclaredMethods();
			for (Method l_method : l_methods) {
				if (Modifier.isPublic(l_method.getModifiers())) {
					l_methodId.setLength(0);
					l_methodId.append(l_prefix);
					l_methodId.append(l_method.getName());
					Class<?>[] l_parameterTypes = l_method.getParameterTypes();
					for (Class<?> l_parameterType : l_parameterTypes) {
						String l_abbrev = abbrevByParamType.get(l_parameterType);
						l_methodId.append(l_abbrev);
					}
					JdbcMethod l_constant = methodsById.get(l_methodId.toString());
					if (l_constant != null) {
						l_constant.setMethod(l_method);
					}
				}
			}
		}
	}
		
	String i_code;
	Method i_method;
	JdbcMethod(String code) {
		i_code = code;
	}
	public String getCode() { return i_code; }
	/**
	 * @return the method
	 */
	public Method getMethod() {
		return i_method;
	}
	/**
	 * @param a_method the method to set
	 */
	public void setMethod(Method a_method) {
		i_method = a_method;
	}
	
}
