/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2;

import java.util.*;

public class StatementAdaptorContext {
	public static class SetParameter {
		private JdbcMethod i_setMethod;
		private int i_parameterIndex;
		private Object[] i_setParameters;
		protected SetParameter(JdbcMethod setMethod, int parameterIndex,
				Object[] a_setParameters) {
			super();
			i_setMethod = setMethod;
			i_parameterIndex = parameterIndex;
			i_setParameters = a_setParameters;
		}
		/**
		 * @return the setMethod
		 */
		public JdbcMethod getSetMethod() {
			return i_setMethod;
		}
		/**
		 * @return the parameterIndex
		 */
		public int getParameterIndex() {
			return i_parameterIndex;
		}
		/**
		 * @return the setParameters
		 */
		public Object[] getSetParameters() {
			return i_setParameters;
		}
	}

	private JdbcMethod i_createMethod;
	private Object[] i_createParameters;
	private String i_strStatement;
	private List<SetParameter> i_parameters = new ArrayList<SetParameter>();
	private JdbcMethod i_executeMethod;
	private Object[] i_executeParameters;
	private Map<String,Object> i_custom = new HashMap<String, Object>();
	
	public void setCreateMethod(JdbcMethod createMethod, Object ... createParameters) {
		i_createMethod = createMethod;
		i_createParameters = createParameters;
		switch (createMethod) {
		case CONN_prepareStatementS:
		case CONN_prepareStatementSI:
		case CONN_prepareStatementSIa:
		case CONN_prepareStatementSII:
		case CONN_prepareStatementSIII:
		case CONN_prepareStatementSSa:
			i_strStatement = (String)createParameters[0];
			i_createParameters = Arrays.copyOfRange(createParameters, 1, createParameters.length);
		}
	}
	public void setParameter(JdbcMethod setMethod, int paramIndex, Object ...parameterValues) {
		SetParameter newParameter = new SetParameter(setMethod, paramIndex, parameterValues);
		i_parameters.add(newParameter);
	}
	public void setExecute(JdbcMethod execMethod, Object ... execParameters) {
		i_executeMethod = execMethod;
		i_executeParameters = execParameters;
		switch (execMethod) {
		case STMT_executeQueryS:
		case STMT_executeS:
		case STMT_executeSI:
		case STMT_executeSIa:
		case STMT_executeSSa:
		case STMT_executeUpdateS:
		case STMT_executeUpdateSI:
		case STMT_executeUpdateSIa:
		case STMT_executeUpdateSSa:
			i_strStatement = (String)execParameters[0];
			i_executeParameters = Arrays.copyOfRange(execParameters, 1, execParameters.length);
		}
	}
	
	public StatementAdaptorContext() {
		super();
	}
	/**
	 * @return the createMethod
	 */
	public JdbcMethod getCreateMethod() {
		return i_createMethod;
	}
	/**
	 * @return the createParameters
	 */
	public Object[] getCreateParameters() {
		return i_createParameters;
	}
	/**
	 * @return the statementFrontEnd
	 */
	public String getStrStatement() {
		return i_strStatement;
	}
	/**
	 * @return the parameters
	 */
	public List<SetParameter> getParameters() {
		return i_parameters;
	}
	/**
	 * @return the executeMethod
	 */
	public JdbcMethod getExecuteMethod() {
		return i_executeMethod;
	}
	/**
	 * @return the executeParameters
	 */
	public Object[] getExecuteParameters() {
		return i_executeParameters;
	}
	
	public Object getCustom(String name) {
		return i_custom.get(name);
	}
	
	public void setCustom(String name, Object value) {
		i_custom.put(name, value);
	}
}
