/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.impl;

import java.sql.Array;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Map;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.CpWrapper;
import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.log.ConnectionLogger;

/**
 * Decorator for sql.Array.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class CpArray implements Array, CpWrapper {
	private CpResultSet i_resultSet;
	private Array i_wrapped;
	private ConnectionLogger i_logger;
	private String i_objId;

	public CpArray(CpResultSet rs, Array a_wrapped, String a_objId) {
		super();
		i_resultSet = rs;
		i_wrapped = a_wrapped;
		i_logger = rs.cpStatement().cpConnection().cpLogger();
		i_objId = a_objId;
	}

	/**
	 * @return the wrapped
	 */
	public Array cpWrapped() {
		return i_wrapped;
	}
	
	public String cpObjectId() {
		return i_objId;
	}
	
	public CpResultSet cpResultSet() {
		return i_resultSet;
	}

	////////////////////////////////////////////////////////////////////////////
	///{AUTOGEN:FRAME_BEGIN}
	//{AUTOGEN:ARRY_free:BEGIN}
	public void free() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.ARRY_free);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.free();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.ARRY_free, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.ARRY_free, null);
	}
	//{AUTOGEN:ARRY_free:END}
	//{AUTOGEN:ARRY_getArray:BEGIN}
	public Object getArray() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.ARRY_getArray);
		Object l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getArray();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.ARRY_getArray, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.ARRY_getArray, l_result);
			return l_result;
	}
	//{AUTOGEN:ARRY_getArray:END}
	//{AUTOGEN:ARRY_getArrayLIMp:BEGIN}
	public Object getArray(long a_index, int a_count, Map<String, Class<?>> a_map) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.ARRY_getArrayLIMp,a_index, a_count, a_map);
		Object l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getArray(a_index, a_count, a_map);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.ARRY_getArrayLIMp, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.ARRY_getArrayLIMp, l_result);
			return l_result;
	}
	//{AUTOGEN:ARRY_getArrayLIMp:END}
	//{AUTOGEN:ARRY_getArrayLI:BEGIN}
	public Object getArray(long a_index, int a_count) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.ARRY_getArrayLI,a_index, a_count);
		Object l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getArray(a_index, a_count);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.ARRY_getArrayLI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.ARRY_getArrayLI, l_result);
			return l_result;
	}
	//{AUTOGEN:ARRY_getArrayLI:END}
	//{AUTOGEN:ARRY_getArrayMp:BEGIN}
	public Object getArray(Map<String, Class<?>> a_map) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.ARRY_getArrayMp,a_map);
		Object l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getArray(a_map);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.ARRY_getArrayMp, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.ARRY_getArrayMp, l_result);
			return l_result;
	}
	//{AUTOGEN:ARRY_getArrayMp:END}
	//{AUTOGEN:ARRY_getBaseType:BEGIN}
	public int getBaseType() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.ARRY_getBaseType);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getBaseType();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.ARRY_getBaseType, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.ARRY_getBaseType, l_result);
			return l_result;
	}
	//{AUTOGEN:ARRY_getBaseType:END}
	//{AUTOGEN:ARRY_getBaseTypeName:BEGIN}
	public String getBaseTypeName() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.ARRY_getBaseTypeName);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getBaseTypeName();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.ARRY_getBaseTypeName, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.ARRY_getBaseTypeName, l_result);
			return l_result;
	}
	//{AUTOGEN:ARRY_getBaseTypeName:END}
	//{AUTOGEN:ARRY_getResultSet:BEGIN}
	public ResultSet getResultSet() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.ARRY_getResultSet);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getResultSet();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.ARRY_getResultSet, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.ARRY_getResultSet, l_result);
			return l_result;
	}
	//{AUTOGEN:ARRY_getResultSet:END}
	//{AUTOGEN:ARRY_getResultSetLIMp:BEGIN}
	public ResultSet getResultSet(long a_index, int a_count, Map<String, Class<?>> a_map) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.ARRY_getResultSetLIMp,a_index, a_count, a_map);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getResultSet(a_index, a_count, a_map);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.ARRY_getResultSetLIMp, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.ARRY_getResultSetLIMp, l_result);
			return l_result;
	}
	//{AUTOGEN:ARRY_getResultSetLIMp:END}
	//{AUTOGEN:ARRY_getResultSetLI:BEGIN}
	public ResultSet getResultSet(long a_index, int a_count) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.ARRY_getResultSetLI,a_index, a_count);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getResultSet(a_index, a_count);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.ARRY_getResultSetLI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.ARRY_getResultSetLI, l_result);
			return l_result;
	}
	//{AUTOGEN:ARRY_getResultSetLI:END}
	//{AUTOGEN:ARRY_getResultSetMp:BEGIN}
	public ResultSet getResultSet(Map<String, Class<?>> a_map) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.ARRY_getResultSetMp,a_map);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getResultSet(a_map);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.ARRY_getResultSetMp, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.ARRY_getResultSetMp, l_result);
			return l_result;
	}
	//{AUTOGEN:ARRY_getResultSetMp:END}
	///{AUTOGEN:FRAME_END}
	////////////////////////////////////////////////////////////////////////////

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "CpArray:" + i_objId;
	}

	
}
