/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.impl;

import java.io.InputStream;
import java.io.OutputStream;
import java.sql.Blob;
import java.sql.SQLException;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.CpWrapper;
import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.log.ConnectionLogger;

// TODO Interesaría un proxy del OutputStream para controlar qué valores se introducen.
/**
 * Base Proxy/Decorator class for a java.sql.Blob.
 * It's just a filter-delegate implementation, ready to override in a subclass.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class CpBlob implements Blob, CpWrapper {
	/** JpConnection used to create the Blob. */
	protected CpConnection i_connection = null;
	/** Wrapped Blob object. */
	protected Blob i_wrapped = null;
	private ConnectionLogger i_logger;
	private String i_objId;
	
	// Default constructor, just in case a subclass needs it.
	protected CpBlob() {
		super();
	}
	
	/**
	 * @param connection
	 * @param wrapped
	 */
	public CpBlob(CpConnection connection, Blob wrapped, String objId) {
		super();
		i_connection = connection;
		i_wrapped = wrapped;
		i_logger = connection.cpLogger();
		i_objId = objId;
	}
	
	/**
	 * Return the wrapped blob object.
	 */
	public Blob cpWrapped() {
		return i_wrapped;
	}

	public String cpObjectId() {
		return i_objId;
	}

	////////////////////////////////////////////////////////////////////////////
	///{AUTOGEN:FRAME_BEGIN}

	//{AUTOGEN:BLOB_free:BEGIN}
	public void free() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.BLOB_free);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.free();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.BLOB_free, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.BLOB_free, null);
	}
	//{AUTOGEN:BLOB_free:END}
	//{AUTOGEN:BLOB_getBinaryStream:BEGIN}
	public InputStream getBinaryStream() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.BLOB_getBinaryStream);
		InputStream l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getBinaryStream();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.BLOB_getBinaryStream, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.BLOB_getBinaryStream, l_result);
			return l_result;
	}
	//{AUTOGEN:BLOB_getBinaryStream:END}
	//{AUTOGEN:BLOB_getBinaryStreamLL:BEGIN}
	public InputStream getBinaryStream(long a_pos, long a_length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.BLOB_getBinaryStreamLL,a_pos, a_length);
		InputStream l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getBinaryStream(a_pos, a_length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.BLOB_getBinaryStreamLL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.BLOB_getBinaryStreamLL, l_result);
			return l_result;
	}
	//{AUTOGEN:BLOB_getBinaryStreamLL:END}
	//{AUTOGEN:BLOB_getBytesLI:BEGIN}
	public byte[] getBytes(long a_pos, int a_length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.BLOB_getBytesLI,a_pos, a_length);
		byte[] l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getBytes(a_pos, a_length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.BLOB_getBytesLI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.BLOB_getBytesLI, l_result);
			return l_result;
	}
	//{AUTOGEN:BLOB_getBytesLI:END}
	//{AUTOGEN:BLOB_length:BEGIN}
	public long length() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.BLOB_length);
		long l_result = 0L;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.length();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.BLOB_length, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.BLOB_length, l_result);
			return l_result;
	}
	//{AUTOGEN:BLOB_length:END}
	//{AUTOGEN:BLOB_positionBlL:BEGIN}
	public long position(Blob a_pattern, long a_start) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.BLOB_positionBlL,a_pattern, a_start);
		long l_result = 0L;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.position(a_pattern, a_start);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.BLOB_positionBlL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.BLOB_positionBlL, l_result);
			return l_result;
	}
	//{AUTOGEN:BLOB_positionBlL:END}
	//{AUTOGEN:BLOB_positionByaL:BEGIN}
	public long position(byte[] a_pattern, long a_start) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.BLOB_positionByaL,a_pattern, a_start);
		long l_result = 0L;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.position(a_pattern, a_start);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.BLOB_positionByaL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.BLOB_positionByaL, l_result);
			return l_result;
	}
	//{AUTOGEN:BLOB_positionByaL:END}
	//{AUTOGEN:BLOB_setBinaryStreamL:BEGIN}
	public OutputStream setBinaryStream(long a_pos) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.BLOB_setBinaryStreamL,a_pos);
		OutputStream l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.setBinaryStream(a_pos);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.BLOB_setBinaryStreamL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.BLOB_setBinaryStreamL, l_result);
			return l_result;
	}
	//{AUTOGEN:BLOB_setBinaryStreamL:END}
	//{AUTOGEN:BLOB_setBytesLByaII:BEGIN}
	public int setBytes(long a_pos, byte[] a_bytes, int a_offset, int a_len) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.BLOB_setBytesLByaII,a_pos, a_bytes, a_offset, a_len);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.setBytes(a_pos, a_bytes, a_offset, a_len);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.BLOB_setBytesLByaII, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.BLOB_setBytesLByaII, l_result);
			return l_result;
	}
	//{AUTOGEN:BLOB_setBytesLByaII:END}
	//{AUTOGEN:BLOB_setBytesLBya:BEGIN}
	public int setBytes(long a_pos, byte[] a_bytes) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.BLOB_setBytesLBya,a_pos, a_bytes);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.setBytes(a_pos, a_bytes);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.BLOB_setBytesLBya, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.BLOB_setBytesLBya, l_result);
			return l_result;
	}
	//{AUTOGEN:BLOB_setBytesLBya:END}
	//{AUTOGEN:BLOB_truncateL:BEGIN}
	public void truncate(long a_len) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.BLOB_truncateL,a_len);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.truncate(a_len);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.BLOB_truncateL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.BLOB_truncateL, null);
	}
	//{AUTOGEN:BLOB_truncateL:END}
	///{AUTOGEN:FRAME_END}
	////////////////////////////////////////////////////////////////////////////

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "CpBlob:" + i_objId;
	}

}
