/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.impl;

import java.io.InputStream;
import java.io.Reader;
import java.math.BigDecimal;
import java.net.URL;
import java.sql.*;
import java.util.Calendar;
import java.util.Map;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.CpWrapper;
import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.log.ConnectionLogger;

/**
 * Base Proxy/Decorator for the Statement/PreparedStatement/CallableStatement interfaces.
 * Just works as a filter for the wrapped statement (wrapping generated objects if applies).
 * It is expected to be extended to provide some functionality.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class CpCallableStatement extends CpPreparedStatement implements CallableStatement, CpWrapper {

	// Default constructor, Just in case a subclass doesn't fit the informed constructor
//	protected CpCallableStatement() {
//		super();
//	}

	/**
	 * @param a_connection
	 * @param a_wrapped
	 */
	public CpCallableStatement(CpConnection connection, CallableStatement wrapped,
			String objId) {
		super(connection, wrapped, objId);
	}


	///////////////////////////////////////////////////////
	// BOILERPLATE
	//


	///////////////////////////////////
	// FIELD ACCESORS
	//
	/**
	 * @return the wrapped CallableStatement
	 */
	public CallableStatement cpWrappedCS() {
		return (CallableStatement)i_wrapped;
	}

	////////////////////////////////////////////////////////////////////////////
	///{AUTOGEN:FRAME_BEGIN}

	//{AUTOGEN:CLST_getArrayI:BEGIN}
	public Array getArray(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getArrayI,parameterIndex);
		Array l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getArray(parameterIndex);
			l_result = cpConnection().cpFactory().wrapArray(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getArrayI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getArrayI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getArrayI:END}
	//{AUTOGEN:CLST_getArrayS:BEGIN}
	public Array getArray(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getArrayS,parameterName);
		Array l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getArray(parameterName);
			l_result = cpConnection().cpFactory().wrapArray(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getArrayS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getArrayS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getArrayS:END}
	//{AUTOGEN:CLST_getBigDecimalII:BEGIN}
	public BigDecimal getBigDecimal(int parameterIndex, int scale) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getBigDecimalII,parameterIndex, scale);
		BigDecimal l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getBigDecimal(parameterIndex, scale);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getBigDecimalII, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getBigDecimalII, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getBigDecimalII:END}
	//{AUTOGEN:CLST_getBigDecimalI:BEGIN}
	public BigDecimal getBigDecimal(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getBigDecimalI,parameterIndex);
		BigDecimal l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getBigDecimal(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getBigDecimalI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getBigDecimalI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getBigDecimalI:END}
	//{AUTOGEN:CLST_getBigDecimalS:BEGIN}
	public BigDecimal getBigDecimal(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getBigDecimalS,parameterName);
		BigDecimal l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getBigDecimal(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getBigDecimalS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getBigDecimalS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getBigDecimalS:END}
	//{AUTOGEN:CLST_getBlobI:BEGIN}
	public Blob getBlob(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getBlobI,parameterIndex);
		Blob l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getBlob(parameterIndex);
			l_result = cpConnection().cpFactory().wrapBlob(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getBlobI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getBlobI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getBlobI:END}
	//{AUTOGEN:CLST_getBlobS:BEGIN}
	public Blob getBlob(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getBlobS,parameterName);
		Blob l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getBlob(parameterName);
			l_result = cpConnection().cpFactory().wrapBlob(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getBlobS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getBlobS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getBlobS:END}
	//{AUTOGEN:CLST_getBooleanI:BEGIN}
	public boolean getBoolean(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getBooleanI,parameterIndex);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getBoolean(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getBooleanI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getBooleanI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getBooleanI:END}
	//{AUTOGEN:CLST_getBooleanS:BEGIN}
	public boolean getBoolean(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getBooleanS,parameterName);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getBoolean(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getBooleanS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getBooleanS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getBooleanS:END}
	//{AUTOGEN:CLST_getByteI:BEGIN}
	public byte getByte(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getByteI,parameterIndex);
		byte l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getByte(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getByteI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getByteI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getByteI:END}
	//{AUTOGEN:CLST_getByteS:BEGIN}
	public byte getByte(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getByteS,parameterName);
		byte l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getByte(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getByteS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getByteS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getByteS:END}
	//{AUTOGEN:CLST_getBytesI:BEGIN}
	public byte[] getBytes(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getBytesI,parameterIndex);
		byte[] l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getBytes(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getBytesI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getBytesI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getBytesI:END}
	//{AUTOGEN:CLST_getBytesS:BEGIN}
	public byte[] getBytes(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getBytesS,parameterName);
		byte[] l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getBytes(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getBytesS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getBytesS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getBytesS:END}
	//{AUTOGEN:CLST_getCharacterStreamI:BEGIN}
	public Reader getCharacterStream(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getCharacterStreamI,parameterIndex);
		Reader l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getCharacterStream(parameterIndex);
			// TODO Wrap streams
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getCharacterStreamI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getCharacterStreamI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getCharacterStreamI:END}
	//{AUTOGEN:CLST_getCharacterStreamS:BEGIN}
	public Reader getCharacterStream(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getCharacterStreamS,parameterName);
		Reader l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getCharacterStream(parameterName);
			// TODO Wrap Streams
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getCharacterStreamS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getCharacterStreamS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getCharacterStreamS:END}
	//{AUTOGEN:CLST_getClobI:BEGIN}
	public Clob getClob(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getClobI,parameterIndex);
		Clob l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getClob(parameterIndex);
			l_result = cpConnection().cpFactory().wrapClob(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getClobI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getClobI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getClobI:END}
	//{AUTOGEN:CLST_getClobS:BEGIN}
	public Clob getClob(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getClobS,parameterName);
		Clob l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getClob(parameterName);
			l_result = cpConnection().cpFactory().wrapClob(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getClobS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getClobS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getClobS:END}
	//{AUTOGEN:CLST_getDateICa:BEGIN}
	public Date getDate(int parameterIndex, Calendar cal) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getDateICa,parameterIndex, cal);
		Date l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getDate(parameterIndex, cal);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getDateICa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getDateICa, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getDateICa:END}
	//{AUTOGEN:CLST_getDateI:BEGIN}
	public Date getDate(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getDateI,parameterIndex);
		Date l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getDate(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getDateI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getDateI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getDateI:END}
	//{AUTOGEN:CLST_getDateSCa:BEGIN}
	public Date getDate(String parameterName, Calendar cal) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getDateSCa,parameterName, cal);
		Date l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getDate(parameterName, cal);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getDateSCa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getDateSCa, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getDateSCa:END}
	//{AUTOGEN:CLST_getDateS:BEGIN}
	public Date getDate(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getDateS,parameterName);
		Date l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getDate(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getDateS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getDateS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getDateS:END}
	//{AUTOGEN:CLST_getDoubleI:BEGIN}
	public double getDouble(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getDoubleI,parameterIndex);
		double l_result = 0.0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getDouble(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getDoubleI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getDoubleI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getDoubleI:END}
	//{AUTOGEN:CLST_getDoubleS:BEGIN}
	public double getDouble(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getDoubleS,parameterName);
		double l_result = 0.0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getDouble(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getDoubleS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getDoubleS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getDoubleS:END}
	//{AUTOGEN:CLST_getFloatI:BEGIN}
	public float getFloat(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getFloatI,parameterIndex);
		float l_result = 0.0f;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getFloat(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getFloatI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getFloatI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getFloatI:END}
	//{AUTOGEN:CLST_getFloatS:BEGIN}
	public float getFloat(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getFloatS,parameterName);
		float l_result = 0.0f;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getFloat(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getFloatS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getFloatS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getFloatS:END}
	//{AUTOGEN:CLST_getIntI:BEGIN}
	public int getInt(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getIntI,parameterIndex);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getInt(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getIntI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getIntI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getIntI:END}
	//{AUTOGEN:CLST_getIntS:BEGIN}
	public int getInt(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getIntS,parameterName);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getInt(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getIntS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getIntS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getIntS:END}
	//{AUTOGEN:CLST_getLongI:BEGIN}
	public long getLong(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getLongI,parameterIndex);
		long l_result = 0L;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getLong(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getLongI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getLongI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getLongI:END}
	//{AUTOGEN:CLST_getLongS:BEGIN}
	public long getLong(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getLongS,parameterName);
		long l_result = 0L;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getLong(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getLongS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getLongS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getLongS:END}
	//{AUTOGEN:CLST_getNCharacterStreamI:BEGIN}
	public Reader getNCharacterStream(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getNCharacterStreamI,parameterIndex);
		Reader l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getNCharacterStream(parameterIndex);
			// TODO Wrap streams
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getNCharacterStreamI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getNCharacterStreamI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getNCharacterStreamI:END}
	//{AUTOGEN:CLST_getNCharacterStreamS:BEGIN}
	public Reader getNCharacterStream(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getNCharacterStreamS,parameterName);
		Reader l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getNCharacterStream(parameterName);
			// TODO Wrap streams
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getNCharacterStreamS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getNCharacterStreamS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getNCharacterStreamS:END}
	//{AUTOGEN:CLST_getNClobI:BEGIN}
	public NClob getNClob(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getNClobI,parameterIndex);
		NClob l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getNClob(parameterIndex);
			l_result = cpConnection().cpFactory().wrapNClob(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getNClobI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getNClobI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getNClobI:END}
	//{AUTOGEN:CLST_getNClobS:BEGIN}
	public NClob getNClob(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getNClobS,parameterName);
		NClob l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getNClob(parameterName);
			l_result = cpConnection().cpFactory().wrapNClob(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getNClobS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getNClobS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getNClobS:END}
	//{AUTOGEN:CLST_getNStringI:BEGIN}
	public String getNString(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getNStringI,parameterIndex);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getNString(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getNStringI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getNStringI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getNStringI:END}
	//{AUTOGEN:CLST_getNStringS:BEGIN}
	public String getNString(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getNStringS,parameterName);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getNString(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getNStringS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getNStringS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getNStringS:END}
	//{AUTOGEN:CLST_getObjectIMp:BEGIN}
	public Object getObject(int parameterIndex, Map<String, Class<?>> map) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getObjectIMp,parameterIndex, map);
		Object l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getObject(parameterIndex, map);
			// TT_LOW Consider a type-sensitive wrapper method.
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getObjectIMp, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getObjectIMp, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getObjectIMp:END}
	//{AUTOGEN:CLST_getObjectI:BEGIN}
	public Object getObject(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getObjectI,parameterIndex);
		Object l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getObject(parameterIndex);
			// TT_LOW Type sensitive wrapper?
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getObjectI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getObjectI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getObjectI:END}
	//{AUTOGEN:CLST_getObjectSMp:BEGIN}
	public Object getObject(String parameterName, Map<String, Class<?>> map) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getObjectSMp,parameterName, map);
		Object l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getObject(parameterName, map);
			// TT_LOW Type sensitive wrapper ?
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getObjectSMp, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getObjectSMp, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getObjectSMp:END}
	//{AUTOGEN:CLST_getObjectS:BEGIN}
	public Object getObject(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getObjectS,parameterName);
		Object l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getObject(parameterName);
			// TT_LOW Type sensitive wrapper ?
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getObjectS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getObjectS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getObjectS:END}
	//{AUTOGEN:CLST_getRefI:BEGIN}
	public Ref getRef(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getRefI,parameterIndex);
		Ref l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getRef(parameterIndex);
			l_result = cpConnection().cpFactory().wrapRef(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getRefI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getRefI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getRefI:END}
	//{AUTOGEN:CLST_getRefS:BEGIN}
	public Ref getRef(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getRefS,parameterName);
		Ref l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getRef(parameterName);
			l_result = cpConnection().cpFactory().wrapRef(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getRefS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getRefS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getRefS:END}
	//{AUTOGEN:CLST_getRowIdI:BEGIN}
	public RowId getRowId(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getRowIdI,parameterIndex);
		RowId l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getRowId(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getRowIdI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getRowIdI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getRowIdI:END}
	//{AUTOGEN:CLST_getRowIdS:BEGIN}
	public RowId getRowId(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getRowIdS,parameterName);
		RowId l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getRowId(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getRowIdS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getRowIdS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getRowIdS:END}
	//{AUTOGEN:CLST_getShortI:BEGIN}
	public short getShort(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getShortI,parameterIndex);
		short l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getShort(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getShortI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getShortI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getShortI:END}
	//{AUTOGEN:CLST_getShortS:BEGIN}
	public short getShort(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getShortS,parameterName);
		short l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getShort(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getShortS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getShortS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getShortS:END}
	//{AUTOGEN:CLST_getSQLXMLI:BEGIN}
	public SQLXML getSQLXML(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getSQLXMLI,parameterIndex);
		SQLXML l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getSQLXML(parameterIndex);
			l_result = cpConnection().cpFactory().wrapSqlXml(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getSQLXMLI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getSQLXMLI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getSQLXMLI:END}
	//{AUTOGEN:CLST_getSQLXMLS:BEGIN}
	public SQLXML getSQLXML(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getSQLXMLS,parameterName);
		SQLXML l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getSQLXML(parameterName);
			l_result = cpConnection().cpFactory().wrapSqlXml(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getSQLXMLS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getSQLXMLS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getSQLXMLS:END}
	//{AUTOGEN:CLST_getStringI:BEGIN}
	public String getString(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getStringI,parameterIndex);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getString(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getStringI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getStringI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getStringI:END}
	//{AUTOGEN:CLST_getStringS:BEGIN}
	public String getString(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getStringS,parameterName);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getString(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getStringS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getStringS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getStringS:END}
	//{AUTOGEN:CLST_getTimeICa:BEGIN}
	public Time getTime(int parameterIndex, Calendar cal) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getTimeICa,parameterIndex, cal);
		Time l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getTime(parameterIndex, cal);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getTimeICa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getTimeICa, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getTimeICa:END}
	//{AUTOGEN:CLST_getTimeI:BEGIN}
	public Time getTime(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getTimeI,parameterIndex);
		Time l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getTime(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getTimeI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getTimeI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getTimeI:END}
	//{AUTOGEN:CLST_getTimeSCa:BEGIN}
	public Time getTime(String parameterName, Calendar cal) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getTimeSCa,parameterName, cal);
		Time l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getTime(parameterName, cal);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getTimeSCa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getTimeSCa, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getTimeSCa:END}
	//{AUTOGEN:CLST_getTimeS:BEGIN}
	public Time getTime(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getTimeS,parameterName);
		Time l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getTime(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getTimeS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getTimeS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getTimeS:END}
	//{AUTOGEN:CLST_getTimestampICa:BEGIN}
	public Timestamp getTimestamp(int parameterIndex, Calendar cal) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getTimestampICa,parameterIndex, cal);
		Timestamp l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getTimestamp(parameterIndex, cal);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getTimestampICa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getTimestampICa, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getTimestampICa:END}
	//{AUTOGEN:CLST_getTimestampI:BEGIN}
	public Timestamp getTimestamp(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getTimestampI,parameterIndex);
		Timestamp l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getTimestamp(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getTimestampI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getTimestampI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getTimestampI:END}
	//{AUTOGEN:CLST_getTimestampSCa:BEGIN}
	public Timestamp getTimestamp(String parameterName, Calendar cal) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getTimestampSCa,parameterName, cal);
		Timestamp l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getTimestamp(parameterName, cal);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getTimestampSCa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getTimestampSCa, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getTimestampSCa:END}
	//{AUTOGEN:CLST_getTimestampS:BEGIN}
	public Timestamp getTimestamp(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getTimestampS,parameterName);
		Timestamp l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getTimestamp(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getTimestampS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getTimestampS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getTimestampS:END}
	//{AUTOGEN:CLST_getURLI:BEGIN}
	public URL getURL(int parameterIndex) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getURLI,parameterIndex);
		URL l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getURL(parameterIndex);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getURLI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getURLI, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getURLI:END}
	//{AUTOGEN:CLST_getURLS:BEGIN}
	public URL getURL(String parameterName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_getURLS,parameterName);
		URL l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().getURL(parameterName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_getURLS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_getURLS, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_getURLS:END}
	//{AUTOGEN:CLST_registerOutParameterIII:BEGIN}
	public void registerOutParameter(int parameterIndex, int sqlType, int scale) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_registerOutParameterIII,parameterIndex, sqlType, scale);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().registerOutParameter(parameterIndex, sqlType, scale);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_registerOutParameterIII, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_registerOutParameterIII, null);
	}
	//{AUTOGEN:CLST_registerOutParameterIII:END}
	//{AUTOGEN:CLST_registerOutParameterIIS:BEGIN}
	public void registerOutParameter(int parameterIndex, int sqlType, String typeName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_registerOutParameterIIS,parameterIndex, sqlType, typeName);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().registerOutParameter(parameterIndex, sqlType, typeName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_registerOutParameterIIS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_registerOutParameterIIS, null);
	}
	//{AUTOGEN:CLST_registerOutParameterIIS:END}
	//{AUTOGEN:CLST_registerOutParameterII:BEGIN}
	public void registerOutParameter(int parameterIndex, int sqlType) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_registerOutParameterII,parameterIndex, sqlType);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().registerOutParameter(parameterIndex, sqlType);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_registerOutParameterII, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_registerOutParameterII, null);
	}
	//{AUTOGEN:CLST_registerOutParameterII:END}
	//{AUTOGEN:CLST_registerOutParameterSII:BEGIN}
	public void registerOutParameter(String parameterName, int sqlType, int scale) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_registerOutParameterSII,parameterName, sqlType, scale);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().registerOutParameter(parameterName, sqlType, scale);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_registerOutParameterSII, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_registerOutParameterSII, null);
	}
	//{AUTOGEN:CLST_registerOutParameterSII:END}
	//{AUTOGEN:CLST_registerOutParameterSIS:BEGIN}
	public void registerOutParameter(String parameterName, int sqlType, String typeName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_registerOutParameterSIS,parameterName, sqlType, typeName);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().registerOutParameter(parameterName, sqlType, typeName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_registerOutParameterSIS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_registerOutParameterSIS, null);
	}
	//{AUTOGEN:CLST_registerOutParameterSIS:END}
	//{AUTOGEN:CLST_registerOutParameterSI:BEGIN}
	public void registerOutParameter(String parameterName, int sqlType) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_registerOutParameterSI,parameterName, sqlType);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().registerOutParameter(parameterName, sqlType);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_registerOutParameterSI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_registerOutParameterSI, null);
	}
	//{AUTOGEN:CLST_registerOutParameterSI:END}
	//{AUTOGEN:CLST_setAsciiStreamSIsI:BEGIN}
	public void setAsciiStream(String parameterName, InputStream x, int length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setAsciiStreamSIsI,parameterName, x, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setAsciiStream(parameterName, x, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setAsciiStreamSIsI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setAsciiStreamSIsI, null);
	}
	//{AUTOGEN:CLST_setAsciiStreamSIsI:END}
	//{AUTOGEN:CLST_setAsciiStreamSIsL:BEGIN}
	public void setAsciiStream(String parameterName, InputStream x, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setAsciiStreamSIsL,parameterName, x, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setAsciiStream(parameterName, x, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setAsciiStreamSIsL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setAsciiStreamSIsL, null);
	}
	//{AUTOGEN:CLST_setAsciiStreamSIsL:END}
	//{AUTOGEN:CLST_setAsciiStreamSIs:BEGIN}
	public void setAsciiStream(String parameterName, InputStream x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setAsciiStreamSIs,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setAsciiStream(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setAsciiStreamSIs, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setAsciiStreamSIs, null);
	}
	//{AUTOGEN:CLST_setAsciiStreamSIs:END}
	//{AUTOGEN:CLST_setBigDecimalSBd:BEGIN}
	public void setBigDecimal(String parameterName, BigDecimal x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setBigDecimalSBd,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setBigDecimal(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setBigDecimalSBd, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setBigDecimalSBd, null);
	}
	//{AUTOGEN:CLST_setBigDecimalSBd:END}
	//{AUTOGEN:CLST_setBinaryStreamSIsI:BEGIN}
	public void setBinaryStream(String parameterName, InputStream x, int length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setBinaryStreamSIsI,parameterName, x, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setBinaryStream(parameterName, x, length);
			// TODO Wrap streams
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setBinaryStreamSIsI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setBinaryStreamSIsI, null);
	}
	//{AUTOGEN:CLST_setBinaryStreamSIsI:END}
	//{AUTOGEN:CLST_setBinaryStreamSIsL:BEGIN}
	public void setBinaryStream(String parameterName, InputStream x, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setBinaryStreamSIsL,parameterName, x, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setBinaryStream(parameterName, x, length);
			// TODO Wrap streams
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setBinaryStreamSIsL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setBinaryStreamSIsL, null);
	}
	//{AUTOGEN:CLST_setBinaryStreamSIsL:END}
	//{AUTOGEN:CLST_setBinaryStreamSIs:BEGIN}
	public void setBinaryStream(String parameterName, InputStream x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setBinaryStreamSIs,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setBinaryStream(parameterName, x);
			// TODO Wrap Streams
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setBinaryStreamSIs, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setBinaryStreamSIs, null);
	}
	//{AUTOGEN:CLST_setBinaryStreamSIs:END}
	//{AUTOGEN:CLST_setBlobSBl:BEGIN}
	public void setBlob(String parameterName, Blob x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setBlobSBl,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Is it our wrapper?
			cpWrappedCS().setBlob(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setBlobSBl, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setBlobSBl, null);
	}
	//{AUTOGEN:CLST_setBlobSBl:END}
	//{AUTOGEN:CLST_setBlobSIsL:BEGIN}
	public void setBlob(String parameterName, InputStream inputStream, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setBlobSIsL,parameterName, inputStream, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Is it out wrapper?
			cpWrappedCS().setBlob(parameterName, inputStream, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setBlobSIsL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setBlobSIsL, null);
	}
	//{AUTOGEN:CLST_setBlobSIsL:END}
	//{AUTOGEN:CLST_setBlobSIs:BEGIN}
	public void setBlob(String parameterName, InputStream inputStream) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setBlobSIs,parameterName, inputStream);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TODO Wrap streams
			cpWrappedCS().setBlob(parameterName, inputStream);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setBlobSIs, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setBlobSIs, null);
	}
	//{AUTOGEN:CLST_setBlobSIs:END}
	//{AUTOGEN:CLST_setBooleanSB:BEGIN}
	public void setBoolean(String parameterName, boolean x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setBooleanSB,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setBoolean(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setBooleanSB, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setBooleanSB, null);
	}
	//{AUTOGEN:CLST_setBooleanSB:END}
	//{AUTOGEN:CLST_setByteSBy:BEGIN}
	public void setByte(String parameterName, byte x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setByteSBy,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setByte(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setByteSBy, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setByteSBy, null);
	}
	//{AUTOGEN:CLST_setByteSBy:END}
	//{AUTOGEN:CLST_setBytesSBya:BEGIN}
	public void setBytes(String parameterName, byte[] x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setBytesSBya,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setBytes(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setBytesSBya, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setBytesSBya, null);
	}
	//{AUTOGEN:CLST_setBytesSBya:END}
	//{AUTOGEN:CLST_setCharacterStreamSRdI:BEGIN}
	public void setCharacterStream(String parameterName, Reader reader, int length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setCharacterStreamSRdI,parameterName, reader, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TODO Wrap streams
			cpWrappedCS().setCharacterStream(parameterName, reader, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setCharacterStreamSRdI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setCharacterStreamSRdI, null);
	}
	//{AUTOGEN:CLST_setCharacterStreamSRdI:END}
	//{AUTOGEN:CLST_setCharacterStreamSRdL:BEGIN}
	public void setCharacterStream(String parameterName, Reader reader, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setCharacterStreamSRdL,parameterName, reader, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TODO Wrap Streams
			cpWrappedCS().setCharacterStream(parameterName, reader, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setCharacterStreamSRdL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setCharacterStreamSRdL, null);
	}
	//{AUTOGEN:CLST_setCharacterStreamSRdL:END}
	//{AUTOGEN:CLST_setCharacterStreamSRd:BEGIN}
	public void setCharacterStream(String parameterName, Reader reader) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setCharacterStreamSRd,parameterName, reader);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TODO Wrap Streams
			cpWrappedCS().setCharacterStream(parameterName, reader);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setCharacterStreamSRd, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setCharacterStreamSRd, null);
	}
	//{AUTOGEN:CLST_setCharacterStreamSRd:END}
	//{AUTOGEN:CLST_setClobSCl:BEGIN}
	public void setClob(String parameterName, Clob x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setClobSCl,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Is it out wrapper?
			cpWrappedCS().setClob(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setClobSCl, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setClobSCl, null);
	}
	//{AUTOGEN:CLST_setClobSCl:END}
	//{AUTOGEN:CLST_setClobSRdL:BEGIN}
	public void setClob(String parameterName, Reader reader, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setClobSRdL,parameterName, reader, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Is it out wrapper?
			cpWrappedCS().setClob(parameterName, reader, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setClobSRdL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setClobSRdL, null);
	}
	//{AUTOGEN:CLST_setClobSRdL:END}
	//{AUTOGEN:CLST_setClobSRd:BEGIN}
	public void setClob(String parameterName, Reader reader) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setClobSRd,parameterName, reader);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Is it out wrapper?
			cpWrappedCS().setClob(parameterName, reader);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setClobSRd, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setClobSRd, null);
	}
	//{AUTOGEN:CLST_setClobSRd:END}
	//{AUTOGEN:CLST_setDateSDaCa:BEGIN}
	public void setDate(String parameterName, Date x, Calendar cal) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setDateSDaCa,parameterName, x, cal);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setDate(parameterName, x, cal);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setDateSDaCa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setDateSDaCa, null);
	}
	//{AUTOGEN:CLST_setDateSDaCa:END}
	//{AUTOGEN:CLST_setDateSDa:BEGIN}
	public void setDate(String parameterName, Date x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setDateSDa,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setDate(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setDateSDa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setDateSDa, null);
	}
	//{AUTOGEN:CLST_setDateSDa:END}
	//{AUTOGEN:CLST_setDoubleSD:BEGIN}
	public void setDouble(String parameterName, double x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setDoubleSD,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setDouble(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setDoubleSD, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setDoubleSD, null);
	}
	//{AUTOGEN:CLST_setDoubleSD:END}
	//{AUTOGEN:CLST_setFloatSF:BEGIN}
	public void setFloat(String parameterName, float x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setFloatSF,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setFloat(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setFloatSF, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setFloatSF, null);
	}
	//{AUTOGEN:CLST_setFloatSF:END}
	//{AUTOGEN:CLST_setIntSI:BEGIN}
	public void setInt(String parameterName, int x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setIntSI,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setInt(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setIntSI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setIntSI, null);
	}
	//{AUTOGEN:CLST_setIntSI:END}
	//{AUTOGEN:CLST_setLongSL:BEGIN}
	public void setLong(String parameterName, long x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setLongSL,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setLong(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setLongSL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setLongSL, null);
	}
	//{AUTOGEN:CLST_setLongSL:END}
	//{AUTOGEN:CLST_setNCharacterStreamSRdL:BEGIN}
	public void setNCharacterStream(String parameterName, Reader value, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setNCharacterStreamSRdL,parameterName, value, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TODO Wrap streams
			cpWrappedCS().setNCharacterStream(parameterName, value, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setNCharacterStreamSRdL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setNCharacterStreamSRdL, null);
	}
	//{AUTOGEN:CLST_setNCharacterStreamSRdL:END}
	//{AUTOGEN:CLST_setNCharacterStreamSRd:BEGIN}
	public void setNCharacterStream(String parameterName, Reader value) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setNCharacterStreamSRd,parameterName, value);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TODO Wrap Streams
			cpWrappedCS().setNCharacterStream(parameterName, value);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setNCharacterStreamSRd, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setNCharacterStreamSRd, null);
	}
	//{AUTOGEN:CLST_setNCharacterStreamSRd:END}
	//{AUTOGEN:CLST_setNClobSNc:BEGIN}
	public void setNClob(String parameterName, NClob value) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setNClobSNc,parameterName, value);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Is it out wrapper?
			cpWrappedCS().setNClob(parameterName, value);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setNClobSNc, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setNClobSNc, null);
	}
	//{AUTOGEN:CLST_setNClobSNc:END}
	//{AUTOGEN:CLST_setNClobSRdL:BEGIN}
	public void setNClob(String parameterName, Reader reader, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setNClobSRdL,parameterName, reader, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TODO Wrap streams
			cpWrappedCS().setNClob(parameterName, reader, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setNClobSRdL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setNClobSRdL, null);
	}
	//{AUTOGEN:CLST_setNClobSRdL:END}
	//{AUTOGEN:CLST_setNClobSRd:BEGIN}
	public void setNClob(String parameterName, Reader reader) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setNClobSRd,parameterName, reader);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TODO Wrap streams
			cpWrappedCS().setNClob(parameterName, reader);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setNClobSRd, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setNClobSRd, null);
	}
	//{AUTOGEN:CLST_setNClobSRd:END}
	//{AUTOGEN:CLST_setNStringSS:BEGIN}
	public void setNString(String parameterName, String value) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setNStringSS,parameterName, value);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setNString(parameterName, value);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setNStringSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setNStringSS, null);
	}
	//{AUTOGEN:CLST_setNStringSS:END}
	//{AUTOGEN:CLST_setNullSIS:BEGIN}
	public void setNull(String parameterName, int sqlType, String typeName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setNullSIS,parameterName, sqlType, typeName);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setNull(parameterName, sqlType, typeName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setNullSIS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setNullSIS, null);
	}
	//{AUTOGEN:CLST_setNullSIS:END}
	//{AUTOGEN:CLST_setNullSI:BEGIN}
	public void setNull(String parameterName, int sqlType) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setNullSI,parameterName, sqlType);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setNull(parameterName, sqlType);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setNullSI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setNullSI, null);
	}
	//{AUTOGEN:CLST_setNullSI:END}
	//{AUTOGEN:CLST_setObjectSOII:BEGIN}
	public void setObject(String parameterName, Object x, int targetSqlType, int scale) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setObjectSOII,parameterName, x, targetSqlType, scale);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setObject(parameterName, x, targetSqlType, scale);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setObjectSOII, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setObjectSOII, null);
	}
	//{AUTOGEN:CLST_setObjectSOII:END}
	//{AUTOGEN:CLST_setObjectSOI:BEGIN}
	public void setObject(String parameterName, Object x, int targetSqlType) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setObjectSOI,parameterName, x, targetSqlType);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setObject(parameterName, x, targetSqlType);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setObjectSOI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setObjectSOI, null);
	}
	//{AUTOGEN:CLST_setObjectSOI:END}
	//{AUTOGEN:CLST_setObjectSO:BEGIN}
	public void setObject(String parameterName, Object x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setObjectSO,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setObject(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setObjectSO, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setObjectSO, null);
	}
	//{AUTOGEN:CLST_setObjectSO:END}
	//{AUTOGEN:CLST_setRowIdSRi:BEGIN}
	public void setRowId(String parameterName, RowId x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setRowIdSRi,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setRowId(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setRowIdSRi, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setRowIdSRi, null);
	}
	//{AUTOGEN:CLST_setRowIdSRi:END}
	//{AUTOGEN:CLST_setShortSSh:BEGIN}
	public void setShort(String parameterName, short x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setShortSSh,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setShort(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setShortSSh, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setShortSSh, null);
	}
	//{AUTOGEN:CLST_setShortSSh:END}
	//{AUTOGEN:CLST_setSQLXMLSSx:BEGIN}
	public void setSQLXML(String parameterName, SQLXML xmlObject) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setSQLXMLSSx,parameterName, xmlObject);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Is it our wrapper?
			cpWrappedCS().setSQLXML(parameterName, xmlObject);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setSQLXMLSSx, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setSQLXMLSSx, null);
	}
	//{AUTOGEN:CLST_setSQLXMLSSx:END}
	//{AUTOGEN:CLST_setStringSS:BEGIN}
	public void setString(String parameterName, String x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setStringSS,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setString(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setStringSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setStringSS, null);
	}
	//{AUTOGEN:CLST_setStringSS:END}
	//{AUTOGEN:CLST_setTimeSTiCa:BEGIN}
	public void setTime(String parameterName, Time x, Calendar cal) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setTimeSTiCa,parameterName, x, cal);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setTime(parameterName, x, cal);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setTimeSTiCa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setTimeSTiCa, null);
	}
	//{AUTOGEN:CLST_setTimeSTiCa:END}
	//{AUTOGEN:CLST_setTimeSTi:BEGIN}
	public void setTime(String parameterName, Time x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setTimeSTi,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setTime(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setTimeSTi, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setTimeSTi, null);
	}
	//{AUTOGEN:CLST_setTimeSTi:END}
	//{AUTOGEN:CLST_setTimestampSTmCa:BEGIN}
	public void setTimestamp(String parameterName, Timestamp x, Calendar cal) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setTimestampSTmCa,parameterName, x, cal);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setTimestamp(parameterName, x, cal);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setTimestampSTmCa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setTimestampSTmCa, null);
	}
	//{AUTOGEN:CLST_setTimestampSTmCa:END}
	//{AUTOGEN:CLST_setTimestampSTm:BEGIN}
	public void setTimestamp(String parameterName, Timestamp x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setTimestampSTm,parameterName, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setTimestamp(parameterName, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setTimestampSTm, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setTimestampSTm, null);
	}
	//{AUTOGEN:CLST_setTimestampSTm:END}
	//{AUTOGEN:CLST_setURLSUr:BEGIN}
	public void setURL(String parameterName, URL val) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_setURLSUr,parameterName, val);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpWrappedCS().setURL(parameterName, val);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_setURLSUr, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_setURLSUr, null);
	}
	//{AUTOGEN:CLST_setURLSUr:END}
	//{AUTOGEN:CLST_wasNull:BEGIN}
	public boolean wasNull() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.CLST_wasNull);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpWrappedCS().wasNull();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.CLST_wasNull, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.CLST_wasNull, l_result);
			return l_result;
	}
	//{AUTOGEN:CLST_wasNull:END}
	///{AUTOGEN:FRAME_END}

///////////////////////////////////////////////////////////
/// BOILERPLATE SECTION (END)
///

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "CpCallableStatement:" + i_objId;
	}


}
