/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.impl;

import java.sql.*;

import ddbc.cpn2.*;
import ddbc.cpn2.log.ConnectionLogger;

/**
 * Decorator for sql.DatabaseMetaData.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 *
 */
public class CpDatabaseMetaData implements DatabaseMetaData, CpWrapper {
	private DatabaseMetaData i_wrapped;
	private CpConnection i_cpConnection;
	private ConnectionLogger i_logger;
	private String i_objId;

	// TODO Parameters are in diferent order than in other siblings.
	public CpDatabaseMetaData(CpConnection cpConnection,
			DatabaseMetaData wrapped, String objId) {
		super();
		i_wrapped = wrapped;
		i_cpConnection = cpConnection;
		i_logger = cpConnection.cpLogger();
		i_objId = objId;
	}

	/**
	 * @return the wrapped
	 */
	public DatabaseMetaData cpWrapped() {
		return i_wrapped;
	}
	
	public CpConnection cpConnection() {
		return (CpConnection)i_cpConnection;
	}
	
	public String cpObjectId() {
		return i_objId;
	}

	public CpFactory cpFactory() {
		return cpConnection().cpFactory();
	}
	
	////////////////////////////////////////////////////////////////////////////
	///{AUTOGEN:FRAME_BEGIN}
	//{AUTOGEN:DBMD_allProceduresAreCallable:BEGIN}
	public boolean allProceduresAreCallable() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_allProceduresAreCallable);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.allProceduresAreCallable();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_allProceduresAreCallable, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_allProceduresAreCallable, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_allProceduresAreCallable:END}
	//{AUTOGEN:DBMD_allTablesAreSelectable:BEGIN}
	public boolean allTablesAreSelectable() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_allTablesAreSelectable);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.allTablesAreSelectable();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_allTablesAreSelectable, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_allTablesAreSelectable, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_allTablesAreSelectable:END}
	//{AUTOGEN:DBMD_autoCommitFailureClosesAllResultSets:BEGIN}
	public boolean autoCommitFailureClosesAllResultSets() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_autoCommitFailureClosesAllResultSets);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.autoCommitFailureClosesAllResultSets();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_autoCommitFailureClosesAllResultSets, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_autoCommitFailureClosesAllResultSets, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_autoCommitFailureClosesAllResultSets:END}
	//{AUTOGEN:DBMD_dataDefinitionCausesTransactionCommit:BEGIN}
	public boolean dataDefinitionCausesTransactionCommit() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_dataDefinitionCausesTransactionCommit);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.dataDefinitionCausesTransactionCommit();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_dataDefinitionCausesTransactionCommit, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_dataDefinitionCausesTransactionCommit, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_dataDefinitionCausesTransactionCommit:END}
	//{AUTOGEN:DBMD_dataDefinitionIgnoredInTransactions:BEGIN}
	public boolean dataDefinitionIgnoredInTransactions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_dataDefinitionIgnoredInTransactions);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.dataDefinitionIgnoredInTransactions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_dataDefinitionIgnoredInTransactions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_dataDefinitionIgnoredInTransactions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_dataDefinitionIgnoredInTransactions:END}
	//{AUTOGEN:DBMD_deletesAreDetectedI:BEGIN}
	public boolean deletesAreDetected(int type) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_deletesAreDetectedI,type);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.deletesAreDetected(type);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_deletesAreDetectedI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_deletesAreDetectedI, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_deletesAreDetectedI:END}
	//{AUTOGEN:DBMD_doesMaxRowSizeIncludeBlobs:BEGIN}
	public boolean doesMaxRowSizeIncludeBlobs() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_doesMaxRowSizeIncludeBlobs);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.doesMaxRowSizeIncludeBlobs();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_doesMaxRowSizeIncludeBlobs, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_doesMaxRowSizeIncludeBlobs, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_doesMaxRowSizeIncludeBlobs:END}
	//{AUTOGEN:DBMD_getAttributesSSSS:BEGIN}
	public ResultSet getAttributes(String catalog, String schemaPattern, String typeNamePattern, String attributeNamePattern) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getAttributesSSSS,catalog, schemaPattern, typeNamePattern, attributeNamePattern);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getAttributes(catalog, schemaPattern, typeNamePattern, attributeNamePattern);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getAttributesSSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getAttributesSSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getAttributesSSSS:END}
	//{AUTOGEN:DBMD_getBestRowIdentifierSSSIB:BEGIN}
	public ResultSet getBestRowIdentifier(String catalog, String schema, String table, int scope, boolean nullable) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getBestRowIdentifierSSSIB,catalog, schema, table, scope, nullable);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getBestRowIdentifier(catalog, schema, table, scope, nullable);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getBestRowIdentifierSSSIB, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getBestRowIdentifierSSSIB, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getBestRowIdentifierSSSIB:END}
	//{AUTOGEN:DBMD_getCatalogs:BEGIN}
	public ResultSet getCatalogs() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getCatalogs);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getCatalogs();
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getCatalogs, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getCatalogs, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getCatalogs:END}
	//{AUTOGEN:DBMD_getCatalogSeparator:BEGIN}
	public String getCatalogSeparator() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getCatalogSeparator);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getCatalogSeparator();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getCatalogSeparator, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getCatalogSeparator, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getCatalogSeparator:END}
	//{AUTOGEN:DBMD_getCatalogTerm:BEGIN}
	public String getCatalogTerm() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getCatalogTerm);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getCatalogTerm();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getCatalogTerm, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getCatalogTerm, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getCatalogTerm:END}
	//{AUTOGEN:DBMD_getClientInfoProperties:BEGIN}
	public ResultSet getClientInfoProperties() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getClientInfoProperties);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getClientInfoProperties();
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getClientInfoProperties, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getClientInfoProperties, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getClientInfoProperties:END}
	//{AUTOGEN:DBMD_getColumnPrivilegesSSSS:BEGIN}
	public ResultSet getColumnPrivileges(String catalog, String schema, String table, String columnNamePattern) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getColumnPrivilegesSSSS,catalog, schema, table, columnNamePattern);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getColumnPrivileges(catalog, schema, table, columnNamePattern);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getColumnPrivilegesSSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getColumnPrivilegesSSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getColumnPrivilegesSSSS:END}
	//{AUTOGEN:DBMD_getColumnsSSSS:BEGIN}
	public ResultSet getColumns(String catalog, String schemaPattern, String tableNamePattern, String columnNamePattern) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getColumnsSSSS,catalog, schemaPattern, tableNamePattern, columnNamePattern);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getColumns(catalog, schemaPattern, tableNamePattern, columnNamePattern);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getColumnsSSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getColumnsSSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getColumnsSSSS:END}
	//{AUTOGEN:DBMD_getConnection:BEGIN}
	public Connection getConnection() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getConnection);
		Connection l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getConnection();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getConnection, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getConnection, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getConnection:END}
	//{AUTOGEN:DBMD_getCrossReferenceSSSSSS:BEGIN}
	public ResultSet getCrossReference(String parentCatalog, String parentSchema, String parentTable, String foreignCatalog, String foreignSchema, String foreignTable) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getCrossReferenceSSSSSS,parentCatalog, parentSchema, parentTable, foreignCatalog, foreignSchema, foreignTable);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getCrossReference(parentCatalog, parentSchema, parentTable, foreignCatalog, foreignSchema, foreignTable);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getCrossReferenceSSSSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getCrossReferenceSSSSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getCrossReferenceSSSSSS:END}
	//{AUTOGEN:DBMD_getDatabaseMajorVersion:BEGIN}
	public int getDatabaseMajorVersion() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getDatabaseMajorVersion);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getDatabaseMajorVersion();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getDatabaseMajorVersion, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getDatabaseMajorVersion, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getDatabaseMajorVersion:END}
	//{AUTOGEN:DBMD_getDatabaseMinorVersion:BEGIN}
	public int getDatabaseMinorVersion() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getDatabaseMinorVersion);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getDatabaseMinorVersion();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getDatabaseMinorVersion, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getDatabaseMinorVersion, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getDatabaseMinorVersion:END}
	//{AUTOGEN:DBMD_getDatabaseProductName:BEGIN}
	public String getDatabaseProductName() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getDatabaseProductName);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getDatabaseProductName();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getDatabaseProductName, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getDatabaseProductName, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getDatabaseProductName:END}
	//{AUTOGEN:DBMD_getDatabaseProductVersion:BEGIN}
	public String getDatabaseProductVersion() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getDatabaseProductVersion);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getDatabaseProductVersion();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getDatabaseProductVersion, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getDatabaseProductVersion, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getDatabaseProductVersion:END}
	//{AUTOGEN:DBMD_getDefaultTransactionIsolation:BEGIN}
	public int getDefaultTransactionIsolation() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getDefaultTransactionIsolation);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getDefaultTransactionIsolation();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getDefaultTransactionIsolation, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getDefaultTransactionIsolation, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getDefaultTransactionIsolation:END}
	//{AUTOGEN:DBMD_getDriverMajorVersion:BEGIN}
	public int getDriverMajorVersion() {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getDriverMajorVersion);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getDriverMajorVersion();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchUnchecked(i_logger, i_objId, JdbcMethod.DBMD_getDriverMajorVersion, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getDriverMajorVersion, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getDriverMajorVersion:END}
	//{AUTOGEN:DBMD_getDriverMinorVersion:BEGIN}
	public int getDriverMinorVersion() {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getDriverMinorVersion);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getDriverMinorVersion();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchUnchecked(i_logger, i_objId, JdbcMethod.DBMD_getDriverMinorVersion, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getDriverMinorVersion, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getDriverMinorVersion:END}
	//{AUTOGEN:DBMD_getDriverName:BEGIN}
	public String getDriverName() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getDriverName);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getDriverName();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getDriverName, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getDriverName, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getDriverName:END}
	//{AUTOGEN:DBMD_getDriverVersion:BEGIN}
	public String getDriverVersion() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getDriverVersion);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getDriverVersion();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getDriverVersion, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getDriverVersion, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getDriverVersion:END}
	//{AUTOGEN:DBMD_getExportedKeysSSS:BEGIN}
	public ResultSet getExportedKeys(String catalog, String schema, String table) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getExportedKeysSSS,catalog, schema, table);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getExportedKeys(catalog, schema, table);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getExportedKeysSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getExportedKeysSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getExportedKeysSSS:END}
	//{AUTOGEN:DBMD_getExtraNameCharacters:BEGIN}
	public String getExtraNameCharacters() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getExtraNameCharacters);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getExtraNameCharacters();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getExtraNameCharacters, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getExtraNameCharacters, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getExtraNameCharacters:END}
	//{AUTOGEN:DBMD_getFunctionColumnsSSSS:BEGIN}
	public ResultSet getFunctionColumns(String arg0, String arg1, String arg2, String arg3) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getFunctionColumnsSSSS,arg0, arg1, arg2, arg3);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getFunctionColumns(arg0, arg1, arg2, arg3);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getFunctionColumnsSSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getFunctionColumnsSSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getFunctionColumnsSSSS:END}
	//{AUTOGEN:DBMD_getFunctionsSSS:BEGIN}
	public ResultSet getFunctions(String arg0, String arg1, String arg2) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getFunctionsSSS,arg0, arg1, arg2);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getFunctions(arg0, arg1, arg2);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getFunctionsSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getFunctionsSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getFunctionsSSS:END}
	//{AUTOGEN:DBMD_getIdentifierQuoteString:BEGIN}
	public String getIdentifierQuoteString() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getIdentifierQuoteString);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getIdentifierQuoteString();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getIdentifierQuoteString, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getIdentifierQuoteString, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getIdentifierQuoteString:END}
	//{AUTOGEN:DBMD_getImportedKeysSSS:BEGIN}
	public ResultSet getImportedKeys(String catalog, String schema, String table) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getImportedKeysSSS,catalog, schema, table);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getImportedKeys(catalog, schema, table);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getImportedKeysSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getImportedKeysSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getImportedKeysSSS:END}
	//{AUTOGEN:DBMD_getIndexInfoSSSBB:BEGIN}
	public ResultSet getIndexInfo(String catalog, String schema, String table, boolean unique, boolean approximate) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getIndexInfoSSSBB,catalog, schema, table, unique, approximate);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getIndexInfo(catalog, schema, table, unique, approximate);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getIndexInfoSSSBB, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getIndexInfoSSSBB, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getIndexInfoSSSBB:END}
	//{AUTOGEN:DBMD_getJDBCMajorVersion:BEGIN}
	public int getJDBCMajorVersion() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getJDBCMajorVersion);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getJDBCMajorVersion();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getJDBCMajorVersion, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getJDBCMajorVersion, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getJDBCMajorVersion:END}
	//{AUTOGEN:DBMD_getJDBCMinorVersion:BEGIN}
	public int getJDBCMinorVersion() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getJDBCMinorVersion);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getJDBCMinorVersion();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getJDBCMinorVersion, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getJDBCMinorVersion, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getJDBCMinorVersion:END}
	//{AUTOGEN:DBMD_getMaxBinaryLiteralLength:BEGIN}
	public int getMaxBinaryLiteralLength() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxBinaryLiteralLength);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxBinaryLiteralLength();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxBinaryLiteralLength, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxBinaryLiteralLength, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxBinaryLiteralLength:END}
	//{AUTOGEN:DBMD_getMaxCatalogNameLength:BEGIN}
	public int getMaxCatalogNameLength() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxCatalogNameLength);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxCatalogNameLength();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxCatalogNameLength, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxCatalogNameLength, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxCatalogNameLength:END}
	//{AUTOGEN:DBMD_getMaxCharLiteralLength:BEGIN}
	public int getMaxCharLiteralLength() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxCharLiteralLength);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxCharLiteralLength();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxCharLiteralLength, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxCharLiteralLength, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxCharLiteralLength:END}
	//{AUTOGEN:DBMD_getMaxColumnNameLength:BEGIN}
	public int getMaxColumnNameLength() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxColumnNameLength);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxColumnNameLength();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxColumnNameLength, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxColumnNameLength, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxColumnNameLength:END}
	//{AUTOGEN:DBMD_getMaxColumnsInGroupBy:BEGIN}
	public int getMaxColumnsInGroupBy() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxColumnsInGroupBy);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxColumnsInGroupBy();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxColumnsInGroupBy, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxColumnsInGroupBy, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxColumnsInGroupBy:END}
	//{AUTOGEN:DBMD_getMaxColumnsInIndex:BEGIN}
	public int getMaxColumnsInIndex() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxColumnsInIndex);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxColumnsInIndex();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxColumnsInIndex, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxColumnsInIndex, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxColumnsInIndex:END}
	//{AUTOGEN:DBMD_getMaxColumnsInOrderBy:BEGIN}
	public int getMaxColumnsInOrderBy() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxColumnsInOrderBy);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxColumnsInOrderBy();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxColumnsInOrderBy, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxColumnsInOrderBy, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxColumnsInOrderBy:END}
	//{AUTOGEN:DBMD_getMaxColumnsInSelect:BEGIN}
	public int getMaxColumnsInSelect() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxColumnsInSelect);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxColumnsInSelect();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxColumnsInSelect, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxColumnsInSelect, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxColumnsInSelect:END}
	//{AUTOGEN:DBMD_getMaxColumnsInTable:BEGIN}
	public int getMaxColumnsInTable() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxColumnsInTable);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxColumnsInTable();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxColumnsInTable, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxColumnsInTable, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxColumnsInTable:END}
	//{AUTOGEN:DBMD_getMaxConnections:BEGIN}
	public int getMaxConnections() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxConnections);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxConnections();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxConnections, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxConnections, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxConnections:END}
	//{AUTOGEN:DBMD_getMaxCursorNameLength:BEGIN}
	public int getMaxCursorNameLength() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxCursorNameLength);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxCursorNameLength();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxCursorNameLength, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxCursorNameLength, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxCursorNameLength:END}
	//{AUTOGEN:DBMD_getMaxIndexLength:BEGIN}
	public int getMaxIndexLength() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxIndexLength);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxIndexLength();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxIndexLength, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxIndexLength, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxIndexLength:END}
	//{AUTOGEN:DBMD_getMaxProcedureNameLength:BEGIN}
	public int getMaxProcedureNameLength() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxProcedureNameLength);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxProcedureNameLength();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxProcedureNameLength, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxProcedureNameLength, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxProcedureNameLength:END}
	//{AUTOGEN:DBMD_getMaxRowSize:BEGIN}
	public int getMaxRowSize() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxRowSize);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxRowSize();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxRowSize, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxRowSize, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxRowSize:END}
	//{AUTOGEN:DBMD_getMaxSchemaNameLength:BEGIN}
	public int getMaxSchemaNameLength() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxSchemaNameLength);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxSchemaNameLength();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxSchemaNameLength, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxSchemaNameLength, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxSchemaNameLength:END}
	//{AUTOGEN:DBMD_getMaxStatementLength:BEGIN}
	public int getMaxStatementLength() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxStatementLength);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxStatementLength();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxStatementLength, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxStatementLength, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxStatementLength:END}
	//{AUTOGEN:DBMD_getMaxStatements:BEGIN}
	public int getMaxStatements() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxStatements);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxStatements();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxStatements, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxStatements, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxStatements:END}
	//{AUTOGEN:DBMD_getMaxTableNameLength:BEGIN}
	public int getMaxTableNameLength() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxTableNameLength);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxTableNameLength();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxTableNameLength, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxTableNameLength, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxTableNameLength:END}
	//{AUTOGEN:DBMD_getMaxTablesInSelect:BEGIN}
	public int getMaxTablesInSelect() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxTablesInSelect);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxTablesInSelect();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxTablesInSelect, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxTablesInSelect, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxTablesInSelect:END}
	//{AUTOGEN:DBMD_getMaxUserNameLength:BEGIN}
	public int getMaxUserNameLength() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getMaxUserNameLength);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxUserNameLength();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getMaxUserNameLength, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getMaxUserNameLength, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getMaxUserNameLength:END}
	//{AUTOGEN:DBMD_getNumericFunctions:BEGIN}
	public String getNumericFunctions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getNumericFunctions);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getNumericFunctions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getNumericFunctions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getNumericFunctions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getNumericFunctions:END}
	//{AUTOGEN:DBMD_getPrimaryKeysSSS:BEGIN}
	public ResultSet getPrimaryKeys(String catalog, String schema, String table) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getPrimaryKeysSSS,catalog, schema, table);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getPrimaryKeys(catalog, schema, table);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getPrimaryKeysSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getPrimaryKeysSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getPrimaryKeysSSS:END}
	//{AUTOGEN:DBMD_getProcedureColumnsSSSS:BEGIN}
	public ResultSet getProcedureColumns(String catalog, String schemaPattern, String procedureNamePattern, String columnNamePattern) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getProcedureColumnsSSSS,catalog, schemaPattern, procedureNamePattern, columnNamePattern);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getProcedureColumns(catalog, schemaPattern, procedureNamePattern, columnNamePattern);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getProcedureColumnsSSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getProcedureColumnsSSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getProcedureColumnsSSSS:END}
	//{AUTOGEN:DBMD_getProceduresSSS:BEGIN}
	public ResultSet getProcedures(String catalog, String schemaPattern, String procedureNamePattern) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getProceduresSSS,catalog, schemaPattern, procedureNamePattern);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getProcedures(catalog, schemaPattern, procedureNamePattern);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getProceduresSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getProceduresSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getProceduresSSS:END}
	//{AUTOGEN:DBMD_getProcedureTerm:BEGIN}
	public String getProcedureTerm() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getProcedureTerm);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getProcedureTerm();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getProcedureTerm, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getProcedureTerm, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getProcedureTerm:END}
	//{AUTOGEN:DBMD_getResultSetHoldability:BEGIN}
	public int getResultSetHoldability() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getResultSetHoldability);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getResultSetHoldability();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getResultSetHoldability, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getResultSetHoldability, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getResultSetHoldability:END}
	//{AUTOGEN:DBMD_getRowIdLifetime:BEGIN}
	public RowIdLifetime getRowIdLifetime() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getRowIdLifetime);
		RowIdLifetime l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getRowIdLifetime();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getRowIdLifetime, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getRowIdLifetime, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getRowIdLifetime:END}
	//{AUTOGEN:DBMD_getSchemas:BEGIN}
	public ResultSet getSchemas() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getSchemas);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSchemas();
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getSchemas, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getSchemas, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getSchemas:END}
	//{AUTOGEN:DBMD_getSchemasSS:BEGIN}
	public ResultSet getSchemas(String catalog, String schemaPattern) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getSchemasSS,catalog, schemaPattern);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSchemas(catalog, schemaPattern);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getSchemasSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getSchemasSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getSchemasSS:END}
	//{AUTOGEN:DBMD_getSchemaTerm:BEGIN}
	public String getSchemaTerm() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getSchemaTerm);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSchemaTerm();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getSchemaTerm, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getSchemaTerm, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getSchemaTerm:END}
	//{AUTOGEN:DBMD_getSearchStringEscape:BEGIN}
	public String getSearchStringEscape() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getSearchStringEscape);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSearchStringEscape();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getSearchStringEscape, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getSearchStringEscape, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getSearchStringEscape:END}
	//{AUTOGEN:DBMD_getSQLKeywords:BEGIN}
	public String getSQLKeywords() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getSQLKeywords);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSQLKeywords();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getSQLKeywords, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getSQLKeywords, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getSQLKeywords:END}
	//{AUTOGEN:DBMD_getSQLStateType:BEGIN}
	public int getSQLStateType() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getSQLStateType);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSQLStateType();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getSQLStateType, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getSQLStateType, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getSQLStateType:END}
	//{AUTOGEN:DBMD_getStringFunctions:BEGIN}
	public String getStringFunctions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getStringFunctions);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getStringFunctions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getStringFunctions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getStringFunctions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getStringFunctions:END}
	//{AUTOGEN:DBMD_getSuperTablesSSS:BEGIN}
	public ResultSet getSuperTables(String catalog, String schemaPattern, String tableNamePattern) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getSuperTablesSSS,catalog, schemaPattern, tableNamePattern);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSuperTables(catalog, schemaPattern, tableNamePattern);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getSuperTablesSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getSuperTablesSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getSuperTablesSSS:END}
	//{AUTOGEN:DBMD_getSuperTypesSSS:BEGIN}
	public ResultSet getSuperTypes(String catalog, String schemaPattern, String typeNamePattern) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getSuperTypesSSS,catalog, schemaPattern, typeNamePattern);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSuperTypes(catalog, schemaPattern, typeNamePattern);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getSuperTypesSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getSuperTypesSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getSuperTypesSSS:END}
	//{AUTOGEN:DBMD_getSystemFunctions:BEGIN}
	public String getSystemFunctions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getSystemFunctions);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSystemFunctions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getSystemFunctions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getSystemFunctions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getSystemFunctions:END}
	//{AUTOGEN:DBMD_getTablePrivilegesSSS:BEGIN}
	public ResultSet getTablePrivileges(String catalog, String schemaPattern, String tableNamePattern) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getTablePrivilegesSSS,catalog, schemaPattern, tableNamePattern);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getTablePrivileges(catalog, schemaPattern, tableNamePattern);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getTablePrivilegesSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getTablePrivilegesSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getTablePrivilegesSSS:END}
	//{AUTOGEN:DBMD_getTablesSSSSa:BEGIN}
	public ResultSet getTables(String catalog, String schemaPattern, String tableNamePattern, String[] types) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getTablesSSSSa,catalog, schemaPattern, tableNamePattern, types);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getTables(catalog, schemaPattern, tableNamePattern, types);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getTablesSSSSa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getTablesSSSSa, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getTablesSSSSa:END}
	//{AUTOGEN:DBMD_getTableTypes:BEGIN}
	public ResultSet getTableTypes() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getTableTypes);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getTableTypes();
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getTableTypes, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getTableTypes, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getTableTypes:END}
	//{AUTOGEN:DBMD_getTimeDateFunctions:BEGIN}
	public String getTimeDateFunctions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getTimeDateFunctions);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getTimeDateFunctions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getTimeDateFunctions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getTimeDateFunctions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getTimeDateFunctions:END}
	//{AUTOGEN:DBMD_getTypeInfo:BEGIN}
	public ResultSet getTypeInfo() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getTypeInfo);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getTypeInfo();
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getTypeInfo, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getTypeInfo, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getTypeInfo:END}
	//{AUTOGEN:DBMD_getUDTsSSSIa:BEGIN}
	public ResultSet getUDTs(String catalog, String schemaPattern, String typeNamePattern, int[] types) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getUDTsSSSIa,catalog, schemaPattern, typeNamePattern, types);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getUDTs(catalog, schemaPattern, typeNamePattern, types);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getUDTsSSSIa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getUDTsSSSIa, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getUDTsSSSIa:END}
	//{AUTOGEN:DBMD_getURL:BEGIN}
	public String getURL() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getURL);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getURL();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getURL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getURL, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getURL:END}
	//{AUTOGEN:DBMD_getUserName:BEGIN}
	public String getUserName() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getUserName);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getUserName();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getUserName, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getUserName, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getUserName:END}
	//{AUTOGEN:DBMD_getVersionColumnsSSS:BEGIN}
	public ResultSet getVersionColumns(String catalog, String schema, String table) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_getVersionColumnsSSS,catalog, schema, table);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getVersionColumns(catalog, schema, table);
			l_result = cpFactory().wrapResultSet(l_result, cpConnection());
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_getVersionColumnsSSS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_getVersionColumnsSSS, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_getVersionColumnsSSS:END}
	//{AUTOGEN:DBMD_insertsAreDetectedI:BEGIN}
	public boolean insertsAreDetected(int type) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_insertsAreDetectedI,type);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.insertsAreDetected(type);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_insertsAreDetectedI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_insertsAreDetectedI, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_insertsAreDetectedI:END}
	//{AUTOGEN:DBMD_isCatalogAtStart:BEGIN}
	public boolean isCatalogAtStart() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_isCatalogAtStart);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isCatalogAtStart();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_isCatalogAtStart, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_isCatalogAtStart, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_isCatalogAtStart:END}
	//{AUTOGEN:DBMD_isReadOnly:BEGIN}
	public boolean isReadOnly() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_isReadOnly);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isReadOnly();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_isReadOnly, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_isReadOnly, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_isReadOnly:END}
	//{AUTOGEN:DBMD_locatorsUpdateCopy:BEGIN}
	public boolean locatorsUpdateCopy() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_locatorsUpdateCopy);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.locatorsUpdateCopy();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_locatorsUpdateCopy, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_locatorsUpdateCopy, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_locatorsUpdateCopy:END}
	//{AUTOGEN:DBMD_nullPlusNonNullIsNull:BEGIN}
	public boolean nullPlusNonNullIsNull() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_nullPlusNonNullIsNull);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.nullPlusNonNullIsNull();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_nullPlusNonNullIsNull, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_nullPlusNonNullIsNull, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_nullPlusNonNullIsNull:END}
	//{AUTOGEN:DBMD_nullsAreSortedAtEnd:BEGIN}
	public boolean nullsAreSortedAtEnd() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_nullsAreSortedAtEnd);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.nullsAreSortedAtEnd();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_nullsAreSortedAtEnd, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_nullsAreSortedAtEnd, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_nullsAreSortedAtEnd:END}
	//{AUTOGEN:DBMD_nullsAreSortedAtStart:BEGIN}
	public boolean nullsAreSortedAtStart() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_nullsAreSortedAtStart);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.nullsAreSortedAtStart();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_nullsAreSortedAtStart, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_nullsAreSortedAtStart, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_nullsAreSortedAtStart:END}
	//{AUTOGEN:DBMD_nullsAreSortedHigh:BEGIN}
	public boolean nullsAreSortedHigh() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_nullsAreSortedHigh);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.nullsAreSortedHigh();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_nullsAreSortedHigh, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_nullsAreSortedHigh, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_nullsAreSortedHigh:END}
	//{AUTOGEN:DBMD_nullsAreSortedLow:BEGIN}
	public boolean nullsAreSortedLow() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_nullsAreSortedLow);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.nullsAreSortedLow();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_nullsAreSortedLow, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_nullsAreSortedLow, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_nullsAreSortedLow:END}
	//{AUTOGEN:DBMD_othersDeletesAreVisibleI:BEGIN}
	public boolean othersDeletesAreVisible(int type) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_othersDeletesAreVisibleI,type);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.othersDeletesAreVisible(type);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_othersDeletesAreVisibleI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_othersDeletesAreVisibleI, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_othersDeletesAreVisibleI:END}
	//{AUTOGEN:DBMD_othersInsertsAreVisibleI:BEGIN}
	public boolean othersInsertsAreVisible(int type) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_othersInsertsAreVisibleI,type);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.othersInsertsAreVisible(type);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_othersInsertsAreVisibleI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_othersInsertsAreVisibleI, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_othersInsertsAreVisibleI:END}
	//{AUTOGEN:DBMD_othersUpdatesAreVisibleI:BEGIN}
	public boolean othersUpdatesAreVisible(int type) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_othersUpdatesAreVisibleI,type);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.othersUpdatesAreVisible(type);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_othersUpdatesAreVisibleI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_othersUpdatesAreVisibleI, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_othersUpdatesAreVisibleI:END}
	//{AUTOGEN:DBMD_ownDeletesAreVisibleI:BEGIN}
	public boolean ownDeletesAreVisible(int type) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_ownDeletesAreVisibleI,type);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.ownDeletesAreVisible(type);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_ownDeletesAreVisibleI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_ownDeletesAreVisibleI, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_ownDeletesAreVisibleI:END}
	//{AUTOGEN:DBMD_ownInsertsAreVisibleI:BEGIN}
	public boolean ownInsertsAreVisible(int type) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_ownInsertsAreVisibleI,type);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.ownInsertsAreVisible(type);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_ownInsertsAreVisibleI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_ownInsertsAreVisibleI, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_ownInsertsAreVisibleI:END}
	//{AUTOGEN:DBMD_ownUpdatesAreVisibleI:BEGIN}
	public boolean ownUpdatesAreVisible(int type) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_ownUpdatesAreVisibleI,type);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.ownUpdatesAreVisible(type);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_ownUpdatesAreVisibleI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_ownUpdatesAreVisibleI, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_ownUpdatesAreVisibleI:END}
	//{AUTOGEN:DBMD_storesLowerCaseIdentifiers:BEGIN}
	public boolean storesLowerCaseIdentifiers() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_storesLowerCaseIdentifiers);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.storesLowerCaseIdentifiers();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_storesLowerCaseIdentifiers, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_storesLowerCaseIdentifiers, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_storesLowerCaseIdentifiers:END}
	//{AUTOGEN:DBMD_storesLowerCaseQuotedIdentifiers:BEGIN}
	public boolean storesLowerCaseQuotedIdentifiers() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_storesLowerCaseQuotedIdentifiers);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.storesLowerCaseQuotedIdentifiers();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_storesLowerCaseQuotedIdentifiers, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_storesLowerCaseQuotedIdentifiers, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_storesLowerCaseQuotedIdentifiers:END}
	//{AUTOGEN:DBMD_storesMixedCaseIdentifiers:BEGIN}
	public boolean storesMixedCaseIdentifiers() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_storesMixedCaseIdentifiers);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.storesMixedCaseIdentifiers();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_storesMixedCaseIdentifiers, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_storesMixedCaseIdentifiers, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_storesMixedCaseIdentifiers:END}
	//{AUTOGEN:DBMD_storesMixedCaseQuotedIdentifiers:BEGIN}
	public boolean storesMixedCaseQuotedIdentifiers() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_storesMixedCaseQuotedIdentifiers);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.storesMixedCaseQuotedIdentifiers();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_storesMixedCaseQuotedIdentifiers, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_storesMixedCaseQuotedIdentifiers, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_storesMixedCaseQuotedIdentifiers:END}
	//{AUTOGEN:DBMD_storesUpperCaseIdentifiers:BEGIN}
	public boolean storesUpperCaseIdentifiers() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_storesUpperCaseIdentifiers);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.storesUpperCaseIdentifiers();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_storesUpperCaseIdentifiers, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_storesUpperCaseIdentifiers, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_storesUpperCaseIdentifiers:END}
	//{AUTOGEN:DBMD_storesUpperCaseQuotedIdentifiers:BEGIN}
	public boolean storesUpperCaseQuotedIdentifiers() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_storesUpperCaseQuotedIdentifiers);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.storesUpperCaseQuotedIdentifiers();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_storesUpperCaseQuotedIdentifiers, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_storesUpperCaseQuotedIdentifiers, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_storesUpperCaseQuotedIdentifiers:END}
	//{AUTOGEN:DBMD_supportsAlterTableWithAddColumn:BEGIN}
	public boolean supportsAlterTableWithAddColumn() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsAlterTableWithAddColumn);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsAlterTableWithAddColumn();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsAlterTableWithAddColumn, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsAlterTableWithAddColumn, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsAlterTableWithAddColumn:END}
	//{AUTOGEN:DBMD_supportsAlterTableWithDropColumn:BEGIN}
	public boolean supportsAlterTableWithDropColumn() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsAlterTableWithDropColumn);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsAlterTableWithDropColumn();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsAlterTableWithDropColumn, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsAlterTableWithDropColumn, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsAlterTableWithDropColumn:END}
	//{AUTOGEN:DBMD_supportsANSI92EntryLevelSQL:BEGIN}
	public boolean supportsANSI92EntryLevelSQL() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsANSI92EntryLevelSQL);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsANSI92EntryLevelSQL();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsANSI92EntryLevelSQL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsANSI92EntryLevelSQL, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsANSI92EntryLevelSQL:END}
	//{AUTOGEN:DBMD_supportsANSI92FullSQL:BEGIN}
	public boolean supportsANSI92FullSQL() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsANSI92FullSQL);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsANSI92FullSQL();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsANSI92FullSQL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsANSI92FullSQL, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsANSI92FullSQL:END}
	//{AUTOGEN:DBMD_supportsANSI92IntermediateSQL:BEGIN}
	public boolean supportsANSI92IntermediateSQL() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsANSI92IntermediateSQL);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsANSI92IntermediateSQL();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsANSI92IntermediateSQL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsANSI92IntermediateSQL, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsANSI92IntermediateSQL:END}
	//{AUTOGEN:DBMD_supportsBatchUpdates:BEGIN}
	public boolean supportsBatchUpdates() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsBatchUpdates);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsBatchUpdates();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsBatchUpdates, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsBatchUpdates, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsBatchUpdates:END}
	//{AUTOGEN:DBMD_supportsCatalogsInDataManipulation:BEGIN}
	public boolean supportsCatalogsInDataManipulation() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsCatalogsInDataManipulation);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsCatalogsInDataManipulation();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsCatalogsInDataManipulation, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsCatalogsInDataManipulation, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsCatalogsInDataManipulation:END}
	//{AUTOGEN:DBMD_supportsCatalogsInIndexDefinitions:BEGIN}
	public boolean supportsCatalogsInIndexDefinitions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsCatalogsInIndexDefinitions);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsCatalogsInIndexDefinitions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsCatalogsInIndexDefinitions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsCatalogsInIndexDefinitions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsCatalogsInIndexDefinitions:END}
	//{AUTOGEN:DBMD_supportsCatalogsInPrivilegeDefinitions:BEGIN}
	public boolean supportsCatalogsInPrivilegeDefinitions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsCatalogsInPrivilegeDefinitions);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsCatalogsInPrivilegeDefinitions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsCatalogsInPrivilegeDefinitions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsCatalogsInPrivilegeDefinitions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsCatalogsInPrivilegeDefinitions:END}
	//{AUTOGEN:DBMD_supportsCatalogsInProcedureCalls:BEGIN}
	public boolean supportsCatalogsInProcedureCalls() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsCatalogsInProcedureCalls);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsCatalogsInProcedureCalls();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsCatalogsInProcedureCalls, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsCatalogsInProcedureCalls, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsCatalogsInProcedureCalls:END}
	//{AUTOGEN:DBMD_supportsCatalogsInTableDefinitions:BEGIN}
	public boolean supportsCatalogsInTableDefinitions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsCatalogsInTableDefinitions);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsCatalogsInTableDefinitions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsCatalogsInTableDefinitions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsCatalogsInTableDefinitions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsCatalogsInTableDefinitions:END}
	//{AUTOGEN:DBMD_supportsColumnAliasing:BEGIN}
	public boolean supportsColumnAliasing() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsColumnAliasing);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsColumnAliasing();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsColumnAliasing, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsColumnAliasing, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsColumnAliasing:END}
	//{AUTOGEN:DBMD_supportsConvert:BEGIN}
	public boolean supportsConvert() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsConvert);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsConvert();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsConvert, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsConvert, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsConvert:END}
	//{AUTOGEN:DBMD_supportsConvertII:BEGIN}
	public boolean supportsConvert(int fromType, int toType) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsConvertII,fromType, toType);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsConvert(fromType, toType);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsConvertII, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsConvertII, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsConvertII:END}
	//{AUTOGEN:DBMD_supportsCoreSQLGrammar:BEGIN}
	public boolean supportsCoreSQLGrammar() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsCoreSQLGrammar);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsCoreSQLGrammar();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsCoreSQLGrammar, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsCoreSQLGrammar, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsCoreSQLGrammar:END}
	//{AUTOGEN:DBMD_supportsCorrelatedSubqueries:BEGIN}
	public boolean supportsCorrelatedSubqueries() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsCorrelatedSubqueries);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsCorrelatedSubqueries();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsCorrelatedSubqueries, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsCorrelatedSubqueries, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsCorrelatedSubqueries:END}
	//{AUTOGEN:DBMD_supportsDataDefinitionAndDataManipulationTransactions:BEGIN}
	public boolean supportsDataDefinitionAndDataManipulationTransactions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsDataDefinitionAndDataManipulationTransactions);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsDataDefinitionAndDataManipulationTransactions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsDataDefinitionAndDataManipulationTransactions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsDataDefinitionAndDataManipulationTransactions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsDataDefinitionAndDataManipulationTransactions:END}
	//{AUTOGEN:DBMD_supportsDataManipulationTransactionsOnly:BEGIN}
	public boolean supportsDataManipulationTransactionsOnly() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsDataManipulationTransactionsOnly);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsDataManipulationTransactionsOnly();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsDataManipulationTransactionsOnly, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsDataManipulationTransactionsOnly, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsDataManipulationTransactionsOnly:END}
	//{AUTOGEN:DBMD_supportsDifferentTableCorrelationNames:BEGIN}
	public boolean supportsDifferentTableCorrelationNames() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsDifferentTableCorrelationNames);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsDifferentTableCorrelationNames();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsDifferentTableCorrelationNames, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsDifferentTableCorrelationNames, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsDifferentTableCorrelationNames:END}
	//{AUTOGEN:DBMD_supportsExpressionsInOrderBy:BEGIN}
	public boolean supportsExpressionsInOrderBy() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsExpressionsInOrderBy);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsExpressionsInOrderBy();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsExpressionsInOrderBy, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsExpressionsInOrderBy, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsExpressionsInOrderBy:END}
	//{AUTOGEN:DBMD_supportsExtendedSQLGrammar:BEGIN}
	public boolean supportsExtendedSQLGrammar() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsExtendedSQLGrammar);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsExtendedSQLGrammar();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsExtendedSQLGrammar, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsExtendedSQLGrammar, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsExtendedSQLGrammar:END}
	//{AUTOGEN:DBMD_supportsFullOuterJoins:BEGIN}
	public boolean supportsFullOuterJoins() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsFullOuterJoins);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsFullOuterJoins();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsFullOuterJoins, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsFullOuterJoins, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsFullOuterJoins:END}
	//{AUTOGEN:DBMD_supportsGetGeneratedKeys:BEGIN}
	public boolean supportsGetGeneratedKeys() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsGetGeneratedKeys);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsGetGeneratedKeys();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsGetGeneratedKeys, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsGetGeneratedKeys, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsGetGeneratedKeys:END}
	//{AUTOGEN:DBMD_supportsGroupBy:BEGIN}
	public boolean supportsGroupBy() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsGroupBy);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsGroupBy();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsGroupBy, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsGroupBy, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsGroupBy:END}
	//{AUTOGEN:DBMD_supportsGroupByBeyondSelect:BEGIN}
	public boolean supportsGroupByBeyondSelect() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsGroupByBeyondSelect);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsGroupByBeyondSelect();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsGroupByBeyondSelect, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsGroupByBeyondSelect, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsGroupByBeyondSelect:END}
	//{AUTOGEN:DBMD_supportsGroupByUnrelated:BEGIN}
	public boolean supportsGroupByUnrelated() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsGroupByUnrelated);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsGroupByUnrelated();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsGroupByUnrelated, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsGroupByUnrelated, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsGroupByUnrelated:END}
	//{AUTOGEN:DBMD_supportsIntegrityEnhancementFacility:BEGIN}
	public boolean supportsIntegrityEnhancementFacility() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsIntegrityEnhancementFacility);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsIntegrityEnhancementFacility();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsIntegrityEnhancementFacility, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsIntegrityEnhancementFacility, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsIntegrityEnhancementFacility:END}
	//{AUTOGEN:DBMD_supportsLikeEscapeClause:BEGIN}
	public boolean supportsLikeEscapeClause() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsLikeEscapeClause);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsLikeEscapeClause();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsLikeEscapeClause, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsLikeEscapeClause, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsLikeEscapeClause:END}
	//{AUTOGEN:DBMD_supportsLimitedOuterJoins:BEGIN}
	public boolean supportsLimitedOuterJoins() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsLimitedOuterJoins);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsLimitedOuterJoins();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsLimitedOuterJoins, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsLimitedOuterJoins, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsLimitedOuterJoins:END}
	//{AUTOGEN:DBMD_supportsMinimumSQLGrammar:BEGIN}
	public boolean supportsMinimumSQLGrammar() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsMinimumSQLGrammar);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsMinimumSQLGrammar();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsMinimumSQLGrammar, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsMinimumSQLGrammar, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsMinimumSQLGrammar:END}
	//{AUTOGEN:DBMD_supportsMixedCaseIdentifiers:BEGIN}
	public boolean supportsMixedCaseIdentifiers() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsMixedCaseIdentifiers);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsMixedCaseIdentifiers();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsMixedCaseIdentifiers, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsMixedCaseIdentifiers, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsMixedCaseIdentifiers:END}
	//{AUTOGEN:DBMD_supportsMixedCaseQuotedIdentifiers:BEGIN}
	public boolean supportsMixedCaseQuotedIdentifiers() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsMixedCaseQuotedIdentifiers);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsMixedCaseQuotedIdentifiers();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsMixedCaseQuotedIdentifiers, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsMixedCaseQuotedIdentifiers, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsMixedCaseQuotedIdentifiers:END}
	//{AUTOGEN:DBMD_supportsMultipleOpenResults:BEGIN}
	public boolean supportsMultipleOpenResults() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsMultipleOpenResults);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsMultipleOpenResults();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsMultipleOpenResults, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsMultipleOpenResults, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsMultipleOpenResults:END}
	//{AUTOGEN:DBMD_supportsMultipleResultSets:BEGIN}
	public boolean supportsMultipleResultSets() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsMultipleResultSets);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsMultipleResultSets();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsMultipleResultSets, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsMultipleResultSets, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsMultipleResultSets:END}
	//{AUTOGEN:DBMD_supportsMultipleTransactions:BEGIN}
	public boolean supportsMultipleTransactions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsMultipleTransactions);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsMultipleTransactions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsMultipleTransactions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsMultipleTransactions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsMultipleTransactions:END}
	//{AUTOGEN:DBMD_supportsNamedParameters:BEGIN}
	public boolean supportsNamedParameters() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsNamedParameters);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsNamedParameters();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsNamedParameters, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsNamedParameters, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsNamedParameters:END}
	//{AUTOGEN:DBMD_supportsNonNullableColumns:BEGIN}
	public boolean supportsNonNullableColumns() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsNonNullableColumns);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsNonNullableColumns();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsNonNullableColumns, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsNonNullableColumns, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsNonNullableColumns:END}
	//{AUTOGEN:DBMD_supportsOpenCursorsAcrossCommit:BEGIN}
	public boolean supportsOpenCursorsAcrossCommit() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsOpenCursorsAcrossCommit);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsOpenCursorsAcrossCommit();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsOpenCursorsAcrossCommit, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsOpenCursorsAcrossCommit, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsOpenCursorsAcrossCommit:END}
	//{AUTOGEN:DBMD_supportsOpenCursorsAcrossRollback:BEGIN}
	public boolean supportsOpenCursorsAcrossRollback() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsOpenCursorsAcrossRollback);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsOpenCursorsAcrossRollback();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsOpenCursorsAcrossRollback, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsOpenCursorsAcrossRollback, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsOpenCursorsAcrossRollback:END}
	//{AUTOGEN:DBMD_supportsOpenStatementsAcrossCommit:BEGIN}
	public boolean supportsOpenStatementsAcrossCommit() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsOpenStatementsAcrossCommit);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsOpenStatementsAcrossCommit();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsOpenStatementsAcrossCommit, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsOpenStatementsAcrossCommit, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsOpenStatementsAcrossCommit:END}
	//{AUTOGEN:DBMD_supportsOpenStatementsAcrossRollback:BEGIN}
	public boolean supportsOpenStatementsAcrossRollback() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsOpenStatementsAcrossRollback);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsOpenStatementsAcrossRollback();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsOpenStatementsAcrossRollback, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsOpenStatementsAcrossRollback, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsOpenStatementsAcrossRollback:END}
	//{AUTOGEN:DBMD_supportsOrderByUnrelated:BEGIN}
	public boolean supportsOrderByUnrelated() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsOrderByUnrelated);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsOrderByUnrelated();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsOrderByUnrelated, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsOrderByUnrelated, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsOrderByUnrelated:END}
	//{AUTOGEN:DBMD_supportsOuterJoins:BEGIN}
	public boolean supportsOuterJoins() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsOuterJoins);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsOuterJoins();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsOuterJoins, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsOuterJoins, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsOuterJoins:END}
	//{AUTOGEN:DBMD_supportsPositionedDelete:BEGIN}
	public boolean supportsPositionedDelete() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsPositionedDelete);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsPositionedDelete();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsPositionedDelete, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsPositionedDelete, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsPositionedDelete:END}
	//{AUTOGEN:DBMD_supportsPositionedUpdate:BEGIN}
	public boolean supportsPositionedUpdate() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsPositionedUpdate);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsPositionedUpdate();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsPositionedUpdate, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsPositionedUpdate, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsPositionedUpdate:END}
	//{AUTOGEN:DBMD_supportsResultSetConcurrencyII:BEGIN}
	public boolean supportsResultSetConcurrency(int type, int concurrency) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsResultSetConcurrencyII,type, concurrency);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsResultSetConcurrency(type, concurrency);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsResultSetConcurrencyII, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsResultSetConcurrencyII, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsResultSetConcurrencyII:END}
	//{AUTOGEN:DBMD_supportsResultSetHoldabilityI:BEGIN}
	public boolean supportsResultSetHoldability(int holdability) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsResultSetHoldabilityI,holdability);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsResultSetHoldability(holdability);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsResultSetHoldabilityI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsResultSetHoldabilityI, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsResultSetHoldabilityI:END}
	//{AUTOGEN:DBMD_supportsResultSetTypeI:BEGIN}
	public boolean supportsResultSetType(int type) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsResultSetTypeI,type);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsResultSetType(type);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsResultSetTypeI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsResultSetTypeI, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsResultSetTypeI:END}
	//{AUTOGEN:DBMD_supportsSavepoints:BEGIN}
	public boolean supportsSavepoints() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsSavepoints);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsSavepoints();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsSavepoints, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsSavepoints, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsSavepoints:END}
	//{AUTOGEN:DBMD_supportsSchemasInDataManipulation:BEGIN}
	public boolean supportsSchemasInDataManipulation() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsSchemasInDataManipulation);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsSchemasInDataManipulation();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsSchemasInDataManipulation, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsSchemasInDataManipulation, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsSchemasInDataManipulation:END}
	//{AUTOGEN:DBMD_supportsSchemasInIndexDefinitions:BEGIN}
	public boolean supportsSchemasInIndexDefinitions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsSchemasInIndexDefinitions);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsSchemasInIndexDefinitions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsSchemasInIndexDefinitions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsSchemasInIndexDefinitions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsSchemasInIndexDefinitions:END}
	//{AUTOGEN:DBMD_supportsSchemasInPrivilegeDefinitions:BEGIN}
	public boolean supportsSchemasInPrivilegeDefinitions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsSchemasInPrivilegeDefinitions);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsSchemasInPrivilegeDefinitions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsSchemasInPrivilegeDefinitions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsSchemasInPrivilegeDefinitions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsSchemasInPrivilegeDefinitions:END}
	//{AUTOGEN:DBMD_supportsSchemasInProcedureCalls:BEGIN}
	public boolean supportsSchemasInProcedureCalls() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsSchemasInProcedureCalls);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsSchemasInProcedureCalls();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsSchemasInProcedureCalls, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsSchemasInProcedureCalls, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsSchemasInProcedureCalls:END}
	//{AUTOGEN:DBMD_supportsSchemasInTableDefinitions:BEGIN}
	public boolean supportsSchemasInTableDefinitions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsSchemasInTableDefinitions);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsSchemasInTableDefinitions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsSchemasInTableDefinitions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsSchemasInTableDefinitions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsSchemasInTableDefinitions:END}
	//{AUTOGEN:DBMD_supportsSelectForUpdate:BEGIN}
	public boolean supportsSelectForUpdate() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsSelectForUpdate);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsSelectForUpdate();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsSelectForUpdate, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsSelectForUpdate, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsSelectForUpdate:END}
	//{AUTOGEN:DBMD_supportsStatementPooling:BEGIN}
	public boolean supportsStatementPooling() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsStatementPooling);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsStatementPooling();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsStatementPooling, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsStatementPooling, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsStatementPooling:END}
	//{AUTOGEN:DBMD_supportsStoredFunctionsUsingCallSyntax:BEGIN}
	public boolean supportsStoredFunctionsUsingCallSyntax() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsStoredFunctionsUsingCallSyntax);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsStoredFunctionsUsingCallSyntax();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsStoredFunctionsUsingCallSyntax, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsStoredFunctionsUsingCallSyntax, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsStoredFunctionsUsingCallSyntax:END}
	//{AUTOGEN:DBMD_supportsStoredProcedures:BEGIN}
	public boolean supportsStoredProcedures() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsStoredProcedures);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsStoredProcedures();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsStoredProcedures, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsStoredProcedures, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsStoredProcedures:END}
	//{AUTOGEN:DBMD_supportsSubqueriesInComparisons:BEGIN}
	public boolean supportsSubqueriesInComparisons() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsSubqueriesInComparisons);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsSubqueriesInComparisons();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsSubqueriesInComparisons, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsSubqueriesInComparisons, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsSubqueriesInComparisons:END}
	//{AUTOGEN:DBMD_supportsSubqueriesInExists:BEGIN}
	public boolean supportsSubqueriesInExists() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsSubqueriesInExists);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsSubqueriesInExists();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsSubqueriesInExists, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsSubqueriesInExists, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsSubqueriesInExists:END}
	//{AUTOGEN:DBMD_supportsSubqueriesInIns:BEGIN}
	public boolean supportsSubqueriesInIns() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsSubqueriesInIns);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsSubqueriesInIns();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsSubqueriesInIns, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsSubqueriesInIns, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsSubqueriesInIns:END}
	//{AUTOGEN:DBMD_supportsSubqueriesInQuantifieds:BEGIN}
	public boolean supportsSubqueriesInQuantifieds() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsSubqueriesInQuantifieds);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsSubqueriesInQuantifieds();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsSubqueriesInQuantifieds, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsSubqueriesInQuantifieds, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsSubqueriesInQuantifieds:END}
	//{AUTOGEN:DBMD_supportsTableCorrelationNames:BEGIN}
	public boolean supportsTableCorrelationNames() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsTableCorrelationNames);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsTableCorrelationNames();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsTableCorrelationNames, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsTableCorrelationNames, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsTableCorrelationNames:END}
	//{AUTOGEN:DBMD_supportsTransactionIsolationLevelI:BEGIN}
	public boolean supportsTransactionIsolationLevel(int level) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsTransactionIsolationLevelI,level);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsTransactionIsolationLevel(level);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsTransactionIsolationLevelI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsTransactionIsolationLevelI, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsTransactionIsolationLevelI:END}
	//{AUTOGEN:DBMD_supportsTransactions:BEGIN}
	public boolean supportsTransactions() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsTransactions);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsTransactions();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsTransactions, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsTransactions, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsTransactions:END}
	//{AUTOGEN:DBMD_supportsUnion:BEGIN}
	public boolean supportsUnion() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsUnion);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsUnion();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsUnion, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsUnion, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsUnion:END}
	//{AUTOGEN:DBMD_supportsUnionAll:BEGIN}
	public boolean supportsUnionAll() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_supportsUnionAll);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.supportsUnionAll();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_supportsUnionAll, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_supportsUnionAll, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_supportsUnionAll:END}
	//{AUTOGEN:DBMD_updatesAreDetectedI:BEGIN}
	public boolean updatesAreDetected(int type) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_updatesAreDetectedI,type);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.updatesAreDetected(type);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_updatesAreDetectedI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_updatesAreDetectedI, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_updatesAreDetectedI:END}
	//{AUTOGEN:DBMD_usesLocalFilePerTable:BEGIN}
	public boolean usesLocalFilePerTable() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_usesLocalFilePerTable);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.usesLocalFilePerTable();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_usesLocalFilePerTable, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_usesLocalFilePerTable, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_usesLocalFilePerTable:END}
	//{AUTOGEN:DBMD_usesLocalFiles:BEGIN}
	public boolean usesLocalFiles() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.DBMD_usesLocalFiles);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.usesLocalFiles();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.DBMD_usesLocalFiles, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.DBMD_usesLocalFiles, l_result);
			return l_result;
	}
	//{AUTOGEN:DBMD_usesLocalFiles:END}
	///{AUTOGEN:FRAME_END}
	////////////////////////////////////////////////////////////////////////////

	public boolean isWrapperFor(Class<?> iface) throws SQLException {
		// TODO
		return false;
	}
	@Override
	public <T> T unwrap(Class<T> a_iface) throws SQLException {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "CpDatabaseMetaData:" + i_objId;
	}

}
