/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.impl;

import java.sql.ParameterMetaData;
import java.sql.SQLException;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.CpWrapper;
import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.log.ConnectionLogger;

/**
 * Decorator for ParameterMetaData
 * @author F.Javier Aranda (fjarandag@gmail.com)
 *
 */
public class CpParameterMetaData implements ParameterMetaData, CpWrapper {
	private CpPreparedStatement i_ps;
	private ParameterMetaData i_wrapped;
	private ConnectionLogger i_logger;
	private String i_objId;

	// Default constructor, just in case a subclass needs it.
	protected CpParameterMetaData() {
		super();
	}

	/**
	 * @param connection
	 * @param wrapped
	 */
	public CpParameterMetaData(CpPreparedStatement ps, ParameterMetaData wrapped, String objId) {
		super();
		i_ps = ps;
		i_wrapped = wrapped;
		i_logger = ps.cpConnection().cpLogger();
		i_objId = objId;
	}

	/**
	 * Return the wrapped clob object.
	 */
	public ParameterMetaData cpWrapped() {
		return i_wrapped;
	}

	public CpPreparedStatement cpPreparedStatement() {
		return i_ps;
	}
	
	public String cpObjectId() {
		return i_objId;
	}


	////////////////////////////////////////////////////////////////////////////
	///{AUTOGEN:FRAME_BEGIN}
	//{AUTOGEN:PMMD_getParameterClassNameI:BEGIN}
	public String getParameterClassName(int param) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PMMD_getParameterClassNameI,param);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getParameterClassName(param);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PMMD_getParameterClassNameI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PMMD_getParameterClassNameI, l_result);
			return l_result;
	}
	//{AUTOGEN:PMMD_getParameterClassNameI:END}
	//{AUTOGEN:PMMD_getParameterCount:BEGIN}
	public int getParameterCount() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PMMD_getParameterCount);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getParameterCount();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PMMD_getParameterCount, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PMMD_getParameterCount, l_result);
			return l_result;
	}
	//{AUTOGEN:PMMD_getParameterCount:END}
	//{AUTOGEN:PMMD_getParameterModeI:BEGIN}
	public int getParameterMode(int param) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PMMD_getParameterModeI,param);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getParameterMode(param);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PMMD_getParameterModeI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PMMD_getParameterModeI, l_result);
			return l_result;
	}
	//{AUTOGEN:PMMD_getParameterModeI:END}
	//{AUTOGEN:PMMD_getParameterTypeI:BEGIN}
	public int getParameterType(int param) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PMMD_getParameterTypeI,param);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getParameterType(param);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PMMD_getParameterTypeI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PMMD_getParameterTypeI, l_result);
			return l_result;
	}
	//{AUTOGEN:PMMD_getParameterTypeI:END}
	//{AUTOGEN:PMMD_getParameterTypeNameI:BEGIN}
	public String getParameterTypeName(int param) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PMMD_getParameterTypeNameI,param);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getParameterTypeName(param);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PMMD_getParameterTypeNameI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PMMD_getParameterTypeNameI, l_result);
			return l_result;
	}
	//{AUTOGEN:PMMD_getParameterTypeNameI:END}
	//{AUTOGEN:PMMD_getPrecisionI:BEGIN}
	public int getPrecision(int param) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PMMD_getPrecisionI,param);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getPrecision(param);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PMMD_getPrecisionI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PMMD_getPrecisionI, l_result);
			return l_result;
	}
	//{AUTOGEN:PMMD_getPrecisionI:END}
	//{AUTOGEN:PMMD_getScaleI:BEGIN}
	public int getScale(int param) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PMMD_getScaleI,param);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getScale(param);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PMMD_getScaleI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PMMD_getScaleI, l_result);
			return l_result;
	}
	//{AUTOGEN:PMMD_getScaleI:END}
	//{AUTOGEN:PMMD_isNullableI:BEGIN}
	public int isNullable(int param) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PMMD_isNullableI,param);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isNullable(param);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PMMD_isNullableI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PMMD_isNullableI, l_result);
			return l_result;
	}
	//{AUTOGEN:PMMD_isNullableI:END}
	//{AUTOGEN:PMMD_isSignedI:BEGIN}
	public boolean isSigned(int param) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PMMD_isSignedI,param);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isSigned(param);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PMMD_isSignedI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PMMD_isSignedI, l_result);
			return l_result;
	}
	//{AUTOGEN:PMMD_isSignedI:END}
	///{AUTOGEN:FRAME_END}
	////////////////////////////////////////////////////////////////////////////

	@Override
	public boolean isWrapperFor(Class<?> iface) throws SQLException {
		// TODO Auto-generated method stub
		return false;
	}
	@Override
	public <T> T unwrap(Class<T> iface) throws SQLException {
		// TODO Auto-generated method stub
		return null;
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "CpParameterMetaData:" + i_objId;
	}

}
