/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.impl;

import java.io.InputStream;
import java.io.Reader;
import java.math.BigDecimal;
import java.net.URL;
import java.sql.*;
import java.util.Calendar;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.CpWrapper;
import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.log.ConnectionLogger;

public class CpPreparedStatement extends CpStatement implements PreparedStatement, CpWrapper {
	/**
	 * @param connection
	 * @param wrapped
	 */
	public CpPreparedStatement(CpConnection connection, PreparedStatement wrapped,
			String objId) {
		super(connection, wrapped, objId);
	}
	
	/* (non-Javadoc)
	 * @see fjarandag.jdbcproxy.JPStatement#getWrapped()
	 */
	public PreparedStatement cpWrappedPS() {
		return (PreparedStatement)i_wrapped;
	}
	
	////////////////////////////////////////////////////////////////////////////
	///{AUTOGEN:FRAME_BEGIN}
	//{AUTOGEN:PRST_addBatch:BEGIN}
	public void addBatch() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_addBatch);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// Seems like an execute statement, as a handler and a delegate must be set.
			cpConnection().cpMapper().executePrepared(this, JdbcMethod.PRST_addBatch);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_addBatch, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_addBatch, null);
	}
	//{AUTOGEN:PRST_addBatch:END}
	//{AUTOGEN:PRST_clearParameters:BEGIN}
	public void clearParameters() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_clearParameters);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TODO Apply to the context and handler.
			cpWrappedPS().clearParameters();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_clearParameters, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_clearParameters, null);
	}
	//{AUTOGEN:PRST_clearParameters:END}
	//{AUTOGEN:PRST_execute:BEGIN}
	public boolean execute() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_execute);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = (Boolean)cpConnection().cpMapper().executePrepared(this, JdbcMethod.PRST_execute);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_execute, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_execute, l_result);
			return l_result;
	}
	//{AUTOGEN:PRST_execute:END}
	//{AUTOGEN:PRST_executeQuery:BEGIN}
	public ResultSet executeQuery() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_executeQuery);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = (ResultSet)cpConnection().cpMapper().executePrepared(this, JdbcMethod.PRST_executeQuery);
			l_result = cpConnection().cpFactory().wrapResultSet(l_result, this);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_executeQuery, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_executeQuery, l_result);
			return l_result;
	}
	//{AUTOGEN:PRST_executeQuery:END}
	//{AUTOGEN:PRST_executeUpdate:BEGIN}
	public int executeUpdate() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_executeUpdate);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = (Integer)cpConnection().cpMapper().executePrepared(this, JdbcMethod.PRST_executeUpdate);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_executeUpdate, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_executeUpdate, l_result);
			return l_result;
	}
	//{AUTOGEN:PRST_executeUpdate:END}
	//{AUTOGEN:PRST_getMetaData:BEGIN}
	public ResultSetMetaData getMetaData() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_getMetaData);
		ResultSetMetaData l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Maybe the handler has something to say?
			l_result = cpWrappedPS().getMetaData();
			l_result = cpConnection().cpFactory().wrapResultSetMetaData(l_result, this);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_getMetaData, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_getMetaData, l_result);
			return l_result;
	}
	//{AUTOGEN:PRST_getMetaData:END}
	//{AUTOGEN:PRST_getParameterMetaData:BEGIN}
	public ParameterMetaData getParameterMetaData() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_getParameterMetaData);
		ParameterMetaData l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Maybe the handler has something to say?
			l_result = cpWrappedPS().getParameterMetaData();
			l_result = cpConnection().cpFactory().wrapParameterMetaData(l_result, this);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_getParameterMetaData, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_getParameterMetaData, l_result);
			return l_result;
	}
	//{AUTOGEN:PRST_getParameterMetaData:END}
	//{AUTOGEN:PRST_setAsciiStreamIIsI:BEGIN}
	public void setAsciiStream(int parameterIndex, InputStream x, int length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setAsciiStreamIIsI,parameterIndex, x, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setAsciiStreamIIsI, parameterIndex, x, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setAsciiStreamIIsI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setAsciiStreamIIsI, null);
	}
	//{AUTOGEN:PRST_setAsciiStreamIIsI:END}
	//{AUTOGEN:PRST_setAsciiStreamIIsL:BEGIN}
	public void setAsciiStream(int parameterIndex, InputStream x, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setAsciiStreamIIsL,parameterIndex, x, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setAsciiStreamIIsL, parameterIndex, x, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setAsciiStreamIIsL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setAsciiStreamIIsL, null);
	}
	//{AUTOGEN:PRST_setAsciiStreamIIsL:END}
	//{AUTOGEN:PRST_setAsciiStreamIIs:BEGIN}
	public void setAsciiStream(int parameterIndex, InputStream x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setAsciiStreamIIs,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setAsciiStreamIIs,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setAsciiStreamIIs, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setAsciiStreamIIs, null);
	}
	//{AUTOGEN:PRST_setAsciiStreamIIs:END}
	//{AUTOGEN:PRST_setBigDecimalIBd:BEGIN}
	public void setBigDecimal(int parameterIndex, BigDecimal x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setBigDecimalIBd,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setBigDecimalIBd,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setBigDecimalIBd, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setBigDecimalIBd, null);
	}
	//{AUTOGEN:PRST_setBigDecimalIBd:END}
	//{AUTOGEN:PRST_setBinaryStreamIIsI:BEGIN}
	public void setBinaryStream(int parameterIndex, InputStream x, int length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setBinaryStreamIIsI,parameterIndex, x, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setBinaryStreamIIsI,parameterIndex, x, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setBinaryStreamIIsI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setBinaryStreamIIsI, null);
	}
	//{AUTOGEN:PRST_setBinaryStreamIIsI:END}
	//{AUTOGEN:PRST_setBinaryStreamIIsL:BEGIN}
	public void setBinaryStream(int parameterIndex, InputStream x, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setBinaryStreamIIsL,parameterIndex, x, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setBinaryStreamIIsL,parameterIndex, x, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setBinaryStreamIIsL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setBinaryStreamIIsL, null);
	}
	//{AUTOGEN:PRST_setBinaryStreamIIsL:END}
	//{AUTOGEN:PRST_setBinaryStreamIIs:BEGIN}
	public void setBinaryStream(int parameterIndex, InputStream x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setBinaryStreamIIs,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setBinaryStreamIIs,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setBinaryStreamIIs, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setBinaryStreamIIs, null);
	}
	//{AUTOGEN:PRST_setBinaryStreamIIs:END}
	//{AUTOGEN:PRST_setBlobIBl:BEGIN}
	public void setBlob(int parameterIndex, Blob x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setBlobIBl,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setBlobIBl, parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setBlobIBl, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setBlobIBl, null);
	}
	//{AUTOGEN:PRST_setBlobIBl:END}
	//{AUTOGEN:PRST_setBlobIIsL:BEGIN}
	public void setBlob(int parameterIndex, InputStream inputStream, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setBlobIIsL,parameterIndex, inputStream, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setBlobIIsL, parameterIndex, inputStream, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setBlobIIsL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setBlobIIsL, null);
	}
	//{AUTOGEN:PRST_setBlobIIsL:END}
	//{AUTOGEN:PRST_setBlobIIs:BEGIN}
	public void setBlob(int parameterIndex, InputStream inputStream) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setBlobIIs,parameterIndex, inputStream);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setBlobIIs,parameterIndex, inputStream);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setBlobIIs, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setBlobIIs, null);
	}
	//{AUTOGEN:PRST_setBlobIIs:END}
	//{AUTOGEN:PRST_setBooleanIB:BEGIN}
	public void setBoolean(int parameterIndex, boolean x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setBooleanIB,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setBooleanIB,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setBooleanIB, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setBooleanIB, null);
	}
	//{AUTOGEN:PRST_setBooleanIB:END}
	//{AUTOGEN:PRST_setByteIBy:BEGIN}
	public void setByte(int parameterIndex, byte x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setByteIBy,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setByteIBy,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setByteIBy, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setByteIBy, null);
	}
	//{AUTOGEN:PRST_setByteIBy:END}
	//{AUTOGEN:PRST_setBytesIBya:BEGIN}
	public void setBytes(int parameterIndex, byte[] x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setBytesIBya,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setBytesIBya,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setBytesIBya, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setBytesIBya, null);
	}
	//{AUTOGEN:PRST_setBytesIBya:END}
	//{AUTOGEN:PRST_setCharacterStreamIRdI:BEGIN}
	public void setCharacterStream(int parameterIndex, Reader reader, int length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setCharacterStreamIRdI,parameterIndex, reader, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setCharacterStreamIRdI,parameterIndex, reader, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setCharacterStreamIRdI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setCharacterStreamIRdI, null);
	}
	//{AUTOGEN:PRST_setCharacterStreamIRdI:END}
	//{AUTOGEN:PRST_setCharacterStreamIRdL:BEGIN}
	public void setCharacterStream(int parameterIndex, Reader reader, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setCharacterStreamIRdL,parameterIndex, reader, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setCharacterStreamIRdL,parameterIndex, reader, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setCharacterStreamIRdL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setCharacterStreamIRdL, null);
	}
	//{AUTOGEN:PRST_setCharacterStreamIRdL:END}
	//{AUTOGEN:PRST_setCharacterStreamIRd:BEGIN}
	public void setCharacterStream(int parameterIndex, Reader reader) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setCharacterStreamIRd,parameterIndex, reader);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setCharacterStreamIRd,parameterIndex, reader);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setCharacterStreamIRd, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setCharacterStreamIRd, null);
	}
	//{AUTOGEN:PRST_setCharacterStreamIRd:END}
	//{AUTOGEN:PRST_setClobICl:BEGIN}
	public void setClob(int parameterIndex, Clob x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setClobICl,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setClobICl,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setClobICl, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setClobICl, null);
	}
	//{AUTOGEN:PRST_setClobICl:END}
	//{AUTOGEN:PRST_setClobIRdL:BEGIN}
	public void setClob(int parameterIndex, Reader reader, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setClobIRdL,parameterIndex, reader, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setClobIRdL,parameterIndex, reader, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setClobIRdL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setClobIRdL, null);
	}
	//{AUTOGEN:PRST_setClobIRdL:END}
	//{AUTOGEN:PRST_setClobIRd:BEGIN}
	public void setClob(int parameterIndex, Reader reader) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setClobIRd,parameterIndex, reader);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setClobIRd,parameterIndex, reader);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setClobIRd, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setClobIRd, null);
	}
	//{AUTOGEN:PRST_setClobIRd:END}
	//{AUTOGEN:PRST_setDateIDaCa:BEGIN}
	public void setDate(int parameterIndex, Date x, Calendar cal) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setDateIDaCa,parameterIndex, x, cal);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setDateIDaCa,parameterIndex, x, cal);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setDateIDaCa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setDateIDaCa, null);
	}
	//{AUTOGEN:PRST_setDateIDaCa:END}
	//{AUTOGEN:PRST_setDateIDa:BEGIN}
	public void setDate(int parameterIndex, Date x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setDateIDa,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setDateIDa,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setDateIDa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setDateIDa, null);
	}
	//{AUTOGEN:PRST_setDateIDa:END}
	//{AUTOGEN:PRST_setDoubleID:BEGIN}
	public void setDouble(int parameterIndex, double x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setDoubleID,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setDoubleID,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setDoubleID, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setDoubleID, null);
	}
	//{AUTOGEN:PRST_setDoubleID:END}
	//{AUTOGEN:PRST_setFloatIF:BEGIN}
	public void setFloat(int parameterIndex, float x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setFloatIF,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setFloatIF,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setFloatIF, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setFloatIF, null);
	}
	//{AUTOGEN:PRST_setFloatIF:END}
	//{AUTOGEN:PRST_setIntII:BEGIN}
	public void setInt(int parameterIndex, int x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setIntII,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setIntII,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setIntII, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setIntII, null);
	}
	//{AUTOGEN:PRST_setIntII:END}
	//{AUTOGEN:PRST_setLongIL:BEGIN}
	public void setLong(int parameterIndex, long x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setLongIL,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setLongIL,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setLongIL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setLongIL, null);
	}
	//{AUTOGEN:PRST_setLongIL:END}
	//{AUTOGEN:PRST_setNCharacterStreamIRdL:BEGIN}
	public void setNCharacterStream(int parameterIndex, Reader value, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setNCharacterStreamIRdL,parameterIndex, value, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setNCharacterStreamIRdL,parameterIndex, value, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setNCharacterStreamIRdL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setNCharacterStreamIRdL, null);
	}
	//{AUTOGEN:PRST_setNCharacterStreamIRdL:END}
	//{AUTOGEN:PRST_setNCharacterStreamIRd:BEGIN}
	public void setNCharacterStream(int parameterIndex, Reader value) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setNCharacterStreamIRd,parameterIndex, value);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setNCharacterStreamIRd,parameterIndex, value);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setNCharacterStreamIRd, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setNCharacterStreamIRd, null);
	}
	//{AUTOGEN:PRST_setNCharacterStreamIRd:END}
	//{AUTOGEN:PRST_setNClobINc:BEGIN}
	public void setNClob(int parameterIndex, NClob value) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setNClobINc,parameterIndex, value);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setNClobINc,parameterIndex, value);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setNClobINc, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setNClobINc, null);
	}
	//{AUTOGEN:PRST_setNClobINc:END}
	//{AUTOGEN:PRST_setNClobIRdL:BEGIN}
	public void setNClob(int parameterIndex, Reader reader, long length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setNClobIRdL,parameterIndex, reader, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setNClobIRdL,parameterIndex, reader, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setNClobIRdL, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setNClobIRdL, null);
	}
	//{AUTOGEN:PRST_setNClobIRdL:END}
	//{AUTOGEN:PRST_setNClobIRd:BEGIN}
	public void setNClob(int parameterIndex, Reader reader) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setNClobIRd,parameterIndex, reader);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setNClobIRd,parameterIndex, reader);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setNClobIRd, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setNClobIRd, null);
	}
	//{AUTOGEN:PRST_setNClobIRd:END}
	//{AUTOGEN:PRST_setNStringIS:BEGIN}
	public void setNString(int parameterIndex, String value) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setNStringIS,parameterIndex, value);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setNStringIS,parameterIndex, value);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setNStringIS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setNStringIS, null);
	}
	//{AUTOGEN:PRST_setNStringIS:END}
	//{AUTOGEN:PRST_setNullIIS:BEGIN}
	public void setNull(int parameterIndex, int sqlType, String typeName) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setNullIIS,parameterIndex, sqlType, typeName);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setNullIIS,parameterIndex, sqlType, typeName);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setNullIIS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setNullIIS, null);
	}
	//{AUTOGEN:PRST_setNullIIS:END}
	//{AUTOGEN:PRST_setNullII:BEGIN}
	public void setNull(int parameterIndex, int sqlType) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setNullII,parameterIndex, sqlType);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setNullII,parameterIndex, sqlType);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setNullII, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setNullII, null);
	}
	//{AUTOGEN:PRST_setNullII:END}
	//{AUTOGEN:PRST_setObjectIOII:BEGIN}
	public void setObject(int parameterIndex, Object x, int targetSqlType, int scaleOrLength) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setObjectIOII,parameterIndex, x, targetSqlType, scaleOrLength);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setObjectIOII,parameterIndex, x, targetSqlType, scaleOrLength);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setObjectIOII, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setObjectIOII, null);
	}
	//{AUTOGEN:PRST_setObjectIOII:END}
	//{AUTOGEN:PRST_setObjectIOI:BEGIN}
	public void setObject(int parameterIndex, Object x, int targetSqlType) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setObjectIOI,parameterIndex, x, targetSqlType);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setObjectIOI,parameterIndex, x, targetSqlType);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setObjectIOI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setObjectIOI, null);
	}
	//{AUTOGEN:PRST_setObjectIOI:END}
	//{AUTOGEN:PRST_setObjectIO:BEGIN}
	public void setObject(int parameterIndex, Object x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setObjectIO,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setObjectIO,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setObjectIO, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setObjectIO, null);
	}
	//{AUTOGEN:PRST_setObjectIO:END}
	//{AUTOGEN:PRST_setRefIRf:BEGIN}
	public void setRef(int parameterIndex, Ref x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setRefIRf,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setRefIRf,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setRefIRf, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setRefIRf, null);
	}
	//{AUTOGEN:PRST_setRefIRf:END}
	//{AUTOGEN:PRST_setRowIdIRi:BEGIN}
	public void setRowId(int parameterIndex, RowId x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setRowIdIRi,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setRowIdIRi,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setRowIdIRi, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setRowIdIRi, null);
	}
	//{AUTOGEN:PRST_setRowIdIRi:END}
	//{AUTOGEN:PRST_setShortISh:BEGIN}
	public void setShort(int parameterIndex, short x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setShortISh,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setShortISh,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setShortISh, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setShortISh, null);
	}
	//{AUTOGEN:PRST_setShortISh:END}
	//{AUTOGEN:PRST_setSQLXMLISx:BEGIN}
	public void setSQLXML(int parameterIndex, SQLXML xmlObject) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setSQLXMLISx,parameterIndex, xmlObject);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setSQLXMLISx,parameterIndex, xmlObject);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setSQLXMLISx, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setSQLXMLISx, null);
	}
	//{AUTOGEN:PRST_setSQLXMLISx:END}
	//{AUTOGEN:PRST_setStringIS:BEGIN}
	public void setString(int parameterIndex, String x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setStringIS,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setStringIS,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setStringIS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setStringIS, null);
	}
	//{AUTOGEN:PRST_setStringIS:END}
	//{AUTOGEN:PRST_setTimeITiCa:BEGIN}
	public void setTime(int parameterIndex, Time x, Calendar cal) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setTimeITiCa,parameterIndex, x, cal);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setTimeITiCa,parameterIndex, x, cal);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setTimeITiCa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setTimeITiCa, null);
	}
	//{AUTOGEN:PRST_setTimeITiCa:END}
	//{AUTOGEN:PRST_setTimeITi:BEGIN}
	public void setTime(int parameterIndex, Time x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setTimeITi,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setTimeITi,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setTimeITi, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setTimeITi, null);
	}
	//{AUTOGEN:PRST_setTimeITi:END}
	//{AUTOGEN:PRST_setTimestampITmCa:BEGIN}
	public void setTimestamp(int parameterIndex, Timestamp x, Calendar cal) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setTimestampITmCa,parameterIndex, x, cal);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setTimestampITmCa,parameterIndex, x, cal);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setTimestampITmCa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setTimestampITmCa, null);
	}
	//{AUTOGEN:PRST_setTimestampITmCa:END}
	//{AUTOGEN:PRST_setTimestampITm:BEGIN}
	public void setTimestamp(int parameterIndex, Timestamp x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setTimestampITm,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setTimestampITm,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setTimestampITm, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setTimestampITm, null);
	}
	//{AUTOGEN:PRST_setTimestampITm:END}
	//{AUTOGEN:PRST_setUnicodeStreamIIsI:BEGIN}
	public void setUnicodeStream(int parameterIndex, InputStream x, int length) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setUnicodeStreamIIsI,parameterIndex, x, length);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setUnicodeStreamIIsI,parameterIndex, x, length);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setUnicodeStreamIIsI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setUnicodeStreamIIsI, null);
	}
	//{AUTOGEN:PRST_setUnicodeStreamIIsI:END}
	//{AUTOGEN:PRST_setArrayIAr:BEGIN}
	public void setArray(int parameterIndex, Array x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setArrayIAr,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setArrayIAr,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setArrayIAr, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setArrayIAr, null);
	}
	//{AUTOGEN:PRST_setArrayIAr:END}
	//{AUTOGEN:PRST_setURLIUr:BEGIN}
	public void setURL(int parameterIndex, URL x) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.PRST_setURLIUr,parameterIndex, x);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			cpConnection().cpMapper().setParameter(this, JdbcMethod.PRST_setURLIUr,parameterIndex, x);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.PRST_setURLIUr, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.PRST_setURLIUr, null);
	}
	//{AUTOGEN:PRST_setURLIUr:END}
	///{AUTOGEN:FRAME_END}
	////////////////////////////////////////////////////////////////////////////

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "CpPreparedStatement:" + i_objId;
	}

}
