/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.impl;

import java.sql.Ref;
import java.sql.SQLException;
import java.util.Map;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.CpWrapper;
import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.log.ConnectionLogger;

/**
 * Decorator for sql.Ref.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 *
 */
public class CpRef implements Ref, CpWrapper {
	private CpConnection i_conn;
	private Ref i_wrapped;
	private ConnectionLogger i_logger;
	private String i_objId;

	// Default constructor, just in case a subclass needs it.
	protected CpRef() {
		super();
	}

	/**
	 * @param connection
	 * @param wrapped
	 */
	public CpRef(CpConnection conn, Ref wrapped, String objId) {
		super();
		i_conn = conn;
		i_wrapped = wrapped;
		i_logger = conn.cpLogger();
		i_objId = objId;
	}

	/**
	 * Return the wrapped clob object.
	 */
	public Ref cpWrapped() {
		return i_wrapped;
	}

	public CpConnection cpConnection() {
		return i_conn;
	}
	
	public String cpObjectId() {
		return i_objId;
	}

	////////////////////////////////////////////////////////////////////////////
	///{AUTOGEN:FRAME_BEGIN}

	//{AUTOGEN:REF__getBaseTypeName:BEGIN}
	public String getBaseTypeName() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.REF__getBaseTypeName);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getBaseTypeName();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.REF__getBaseTypeName, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.REF__getBaseTypeName, l_result);
			return l_result;
	}
	//{AUTOGEN:REF__getBaseTypeName:END}
	//{AUTOGEN:REF__getObject:BEGIN}
	public Object getObject() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.REF__getObject);
		Object l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getObject();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.REF__getObject, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.REF__getObject, l_result);
			return l_result;
	}
	//{AUTOGEN:REF__getObject:END}
	//{AUTOGEN:REF__getObjectMp:BEGIN}
	public Object getObject(Map<String, Class<?>> a_map) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.REF__getObjectMp,a_map);
		Object l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getObject(a_map);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.REF__getObjectMp, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.REF__getObjectMp, l_result);
			return l_result;
	}
	//{AUTOGEN:REF__getObjectMp:END}
	//{AUTOGEN:REF__setObjectO:BEGIN}
	public void setObject(Object a_value) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.REF__setObjectO,a_value);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.setObject(a_value);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.REF__setObjectO, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.REF__setObjectO, null);
	}
	//{AUTOGEN:REF__setObjectO:END}
	///{AUTOGEN:FRAME_END}
	////////////////////////////////////////////////////////////////////////////

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "CpRef:" + i_objId;
	}


}
