/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.impl;

import java.sql.ResultSetMetaData;
import java.sql.SQLException;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.CpWrapper;
import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.log.ConnectionLogger;

/**
 * Base Decorator for ResultSetMetaData.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 *
 */
public class CpResultSetMetaData implements ResultSetMetaData, CpWrapper {
//	private CpResultSet i_refResultSet;
	private ResultSetMetaData i_wrapped;
	private ConnectionLogger i_logger;
	private String i_objId;

	// Default constructor, just in case a subclass needs it.
	protected CpResultSetMetaData() {
		super();
	}

	/**
	 * @param connection
	 * @param wrapped
	 */
	public CpResultSetMetaData(CpResultSet rs, ResultSetMetaData wrapped, String objId) {
		super();
//		i_refResultSet = refResultSet;
		i_wrapped = wrapped;
		i_logger = rs.cpStatement().cpConnection().cpLogger();
		i_objId = objId;
	}

	/**
	 * @param connection
	 * @param wrapped
	 */
	public CpResultSetMetaData(CpPreparedStatement ps, ResultSetMetaData wrapped, String objId) {
		super();
		i_wrapped = wrapped;
		i_logger = ps.cpConnection().cpLogger();
		i_objId = objId;
	}

	/**
	 * Return the wrapped clob object.
	 */
	public ResultSetMetaData cpWrapped() {
		return i_wrapped;
	}

//	public CpResultSet cpRefResultSet() {
//		return (CpResultSet)i_refResultSet;
//	}
//	
	public String cpObjectId() {
		return i_objId;
	}

	////////////////////////////////////////////////////////////////////////////
	///{AUTOGEN:FRAME_BEGIN}

	//{AUTOGEN:RSMD_getCatalogNameI:BEGIN}
	public String getCatalogName(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_getCatalogNameI,column);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getCatalogName(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_getCatalogNameI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_getCatalogNameI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_getCatalogNameI:END}
	//{AUTOGEN:RSMD_getColumnClassNameI:BEGIN}
	public String getColumnClassName(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_getColumnClassNameI,column);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getColumnClassName(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_getColumnClassNameI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_getColumnClassNameI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_getColumnClassNameI:END}
	//{AUTOGEN:RSMD_getColumnCount:BEGIN}
	public int getColumnCount() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_getColumnCount);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getColumnCount();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_getColumnCount, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_getColumnCount, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_getColumnCount:END}
	//{AUTOGEN:RSMD_getColumnDisplaySizeI:BEGIN}
	public int getColumnDisplaySize(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_getColumnDisplaySizeI,column);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getColumnDisplaySize(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_getColumnDisplaySizeI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_getColumnDisplaySizeI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_getColumnDisplaySizeI:END}
	//{AUTOGEN:RSMD_getColumnLabelI:BEGIN}
	public String getColumnLabel(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_getColumnLabelI,column);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getColumnLabel(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_getColumnLabelI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_getColumnLabelI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_getColumnLabelI:END}
	//{AUTOGEN:RSMD_getColumnNameI:BEGIN}
	public String getColumnName(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_getColumnNameI,column);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getColumnName(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_getColumnNameI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_getColumnNameI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_getColumnNameI:END}
	//{AUTOGEN:RSMD_getColumnTypeI:BEGIN}
	public int getColumnType(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_getColumnTypeI,column);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getColumnType(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_getColumnTypeI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_getColumnTypeI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_getColumnTypeI:END}
	//{AUTOGEN:RSMD_getColumnTypeNameI:BEGIN}
	public String getColumnTypeName(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_getColumnTypeNameI,column);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getColumnTypeName(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_getColumnTypeNameI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_getColumnTypeNameI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_getColumnTypeNameI:END}
	//{AUTOGEN:RSMD_getPrecisionI:BEGIN}
	public int getPrecision(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_getPrecisionI,column);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getPrecision(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_getPrecisionI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_getPrecisionI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_getPrecisionI:END}
	//{AUTOGEN:RSMD_getScaleI:BEGIN}
	public int getScale(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_getScaleI,column);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getScale(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_getScaleI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_getScaleI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_getScaleI:END}
	//{AUTOGEN:RSMD_getSchemaNameI:BEGIN}
	public String getSchemaName(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_getSchemaNameI,column);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSchemaName(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_getSchemaNameI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_getSchemaNameI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_getSchemaNameI:END}
	//{AUTOGEN:RSMD_getTableNameI:BEGIN}
	public String getTableName(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_getTableNameI,column);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getTableName(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_getTableNameI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_getTableNameI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_getTableNameI:END}
	//{AUTOGEN:RSMD_isAutoIncrementI:BEGIN}
	public boolean isAutoIncrement(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_isAutoIncrementI,column);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isAutoIncrement(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_isAutoIncrementI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_isAutoIncrementI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_isAutoIncrementI:END}
	//{AUTOGEN:RSMD_isCaseSensitiveI:BEGIN}
	public boolean isCaseSensitive(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_isCaseSensitiveI,column);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isCaseSensitive(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_isCaseSensitiveI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_isCaseSensitiveI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_isCaseSensitiveI:END}
	//{AUTOGEN:RSMD_isCurrencyI:BEGIN}
	public boolean isCurrency(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_isCurrencyI,column);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isCurrency(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_isCurrencyI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_isCurrencyI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_isCurrencyI:END}
	//{AUTOGEN:RSMD_isDefinitelyWritableI:BEGIN}
	public boolean isDefinitelyWritable(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_isDefinitelyWritableI,column);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isDefinitelyWritable(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_isDefinitelyWritableI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_isDefinitelyWritableI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_isDefinitelyWritableI:END}
	//{AUTOGEN:RSMD_isNullableI:BEGIN}
	public int isNullable(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_isNullableI,column);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isNullable(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_isNullableI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_isNullableI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_isNullableI:END}
	//{AUTOGEN:RSMD_isReadOnlyI:BEGIN}
	public boolean isReadOnly(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_isReadOnlyI,column);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isReadOnly(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_isReadOnlyI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_isReadOnlyI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_isReadOnlyI:END}
	//{AUTOGEN:RSMD_isSearchableI:BEGIN}
	public boolean isSearchable(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_isSearchableI,column);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isSearchable(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_isSearchableI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_isSearchableI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_isSearchableI:END}
	//{AUTOGEN:RSMD_isSignedI:BEGIN}
	public boolean isSigned(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_isSignedI,column);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isSigned(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_isSignedI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_isSignedI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_isSignedI:END}
	//{AUTOGEN:RSMD_isWritableI:BEGIN}
	public boolean isWritable(int column) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.RSMD_isWritableI,column);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isWritable(column);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.RSMD_isWritableI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.RSMD_isWritableI, l_result);
			return l_result;
	}
	//{AUTOGEN:RSMD_isWritableI:END}
	///{AUTOGEN:FRAME_END}
	////////////////////////////////////////////////////////////////////////////
	@Override
	public boolean isWrapperFor(Class<?> a_iface) throws SQLException {
		// TODO Auto-generated method stub
		return false;
	}
	@Override
	public <T> T unwrap(Class<T> a_iface) throws SQLException {
		// TODO Auto-generated method stub
		return null;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "CpResultSetMetaData:" + i_objId;
	}

}
