/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.impl;

import java.io.*;
import java.sql.SQLException;
import java.sql.SQLXML;

import javax.xml.transform.Result;
import javax.xml.transform.Source;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.CpWrapper;
import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.log.ConnectionLogger;

public class CpSQLXML implements SQLXML, CpWrapper {
	private SQLXML i_wrapped;
	private CpConnection i_cpConnection;
	private ConnectionLogger i_logger;
	private String i_objId;

	// Default constructor, just in case a subclass needs it.
	protected CpSQLXML() {
		super();
	}

	/**
	 * @param connection
	 * @param wrapped
	 */
	public CpSQLXML(CpConnection connection, SQLXML wrapped, ConnectionLogger logger, String objId) {
		super();
		i_cpConnection = connection;
		i_wrapped = wrapped;
		i_logger = logger;
		i_objId = objId;
	}

	/**
	 * Return the wrapped clob object.
	 */
	public SQLXML cpWrapped() {
		return i_wrapped;
	}

	public CpConnection cpConnection() {
		return (CpConnection)i_cpConnection;
	}
	
	public String cpObjectId() {
		return i_objId;
	}

	////////////////////////////////////////////////////////////////////////////
	///{AUTOGEN:FRAME_BEGIN}

	//{AUTOGEN:SXML_free:BEGIN}
	public void free() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.SXML_free);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.free();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.SXML_free, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.SXML_free, null);
	}
	//{AUTOGEN:SXML_free:END}
	//{AUTOGEN:SXML_getBinaryStream:BEGIN}
	public InputStream getBinaryStream() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.SXML_getBinaryStream);
		InputStream l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getBinaryStream();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.SXML_getBinaryStream, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.SXML_getBinaryStream, l_result);
			return l_result;
	}
	//{AUTOGEN:SXML_getBinaryStream:END}
	//{AUTOGEN:SXML_getCharacterStream:BEGIN}
	public Reader getCharacterStream() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.SXML_getCharacterStream);
		Reader l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getCharacterStream();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.SXML_getCharacterStream, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.SXML_getCharacterStream, l_result);
			return l_result;
	}
	//{AUTOGEN:SXML_getCharacterStream:END}
	//{AUTOGEN:SXML_getSourceCs:BEGIN}
	public <T extends Source>  T getSource(Class<T> a_sourceClass) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.SXML_getSourceCs,a_sourceClass);
		T l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSource(a_sourceClass);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.SXML_getSourceCs, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.SXML_getSourceCs, l_result);
			return l_result;
	}
	//{AUTOGEN:SXML_getSourceCs:END}
	//{AUTOGEN:SXML_getString:BEGIN}
	public String getString() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.SXML_getString);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getString();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.SXML_getString, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.SXML_getString, l_result);
			return l_result;
	}
	//{AUTOGEN:SXML_getString:END}
	//{AUTOGEN:SXML_setBinaryStream:BEGIN}
	public OutputStream setBinaryStream() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.SXML_setBinaryStream);
		OutputStream l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.setBinaryStream();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.SXML_setBinaryStream, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.SXML_setBinaryStream, l_result);
			return l_result;
	}
	//{AUTOGEN:SXML_setBinaryStream:END}
	//{AUTOGEN:SXML_setCharacterStream:BEGIN}
	public Writer setCharacterStream() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.SXML_setCharacterStream);
		Writer l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.setCharacterStream();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.SXML_setCharacterStream, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.SXML_setCharacterStream, l_result);
			return l_result;
	}
	//{AUTOGEN:SXML_setCharacterStream:END}
	//{AUTOGEN:SXML_setResultCs:BEGIN}
	public <T extends Result>  T setResult(Class<T> a_resultClass) {
		i_logger.logStart(i_objId, JdbcMethod.SXML_setResultCs,a_resultClass);
		T l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.setResult(a_resultClass);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchUnchecked(i_logger, i_objId, JdbcMethod.SXML_setResultCs, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.SXML_setResultCs, l_result);
			return l_result;
	}
	//{AUTOGEN:SXML_setResultCs:END}
	//{AUTOGEN:SXML_setStringS:BEGIN}
	public void setString(String a_str) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.SXML_setStringS,a_str);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.setString(a_str);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.SXML_setStringS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.SXML_setStringS, null);
	}
	//{AUTOGEN:SXML_setStringS:END}
	///{AUTOGEN:FRAME_END}
	////////////////////////////////////////////////////////////////////////////

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "CpSQLXML:" + i_objId;
	}

}
