/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.impl;

import java.sql.SQLException;
import java.sql.Savepoint;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.CpWrapper;
import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.log.ConnectionLogger;

/**
 * Decorator for sql.Savepoint.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class CpSavepoint implements Savepoint, CpWrapper {
	private Savepoint i_wrapped;
	private CpConnection i_cpConnection;
	private ConnectionLogger i_logger;
	private String i_objId;

	// Default constructor, just in case a subclass needs it.
	protected CpSavepoint() {
		super();
	}

	/**
	 * @param connection
	 * @param wrapped
	 */
	public CpSavepoint(CpConnection connection, Savepoint wrapped, String objId) {
		super();
		i_cpConnection = connection;
		i_wrapped = wrapped;
		i_logger = connection.cpLogger();
		i_objId = objId;
	}

	/**
	 * Return the wrapped clob object.
	 */
	public Savepoint cpWrapped() {
		return i_wrapped;
	}

	public CpConnection cpConnection() {
		return (CpConnection)i_cpConnection;
	}
	
	public String cpObjectId() {
		return i_objId;
	}

	////////////////////////////////////////////////////////////////////////////
	///{AUTOGEN:FRAME_BEGIN}

	//{AUTOGEN:SVPT_getSavepointId:BEGIN}
	public int getSavepointId() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.SVPT_getSavepointId);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSavepointId();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.SVPT_getSavepointId, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.SVPT_getSavepointId, l_result);
			return l_result;
	}
	//{AUTOGEN:SVPT_getSavepointId:END}
	//{AUTOGEN:SVPT_getSavepointName:BEGIN}
	public String getSavepointName() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.SVPT_getSavepointName);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSavepointName();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.SVPT_getSavepointName, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.SVPT_getSavepointName, l_result);
			return l_result;
	}
	//{AUTOGEN:SVPT_getSavepointName:END}
	///{AUTOGEN:FRAME_END}
	////////////////////////////////////////////////////////////////////////////

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "CpSavepoint:" + i_objId;
	}

}
