/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.impl;

import java.sql.*;

import ddbc.cpn2.*;
import ddbc.cpn2.log.ConnectionLogger;
import ddbc.cpn2.st.StatementHandler;

public class CpStatement implements Statement, CpWrapper {
	protected CpConnection i_cpConnection;
	protected Statement i_wrapped;
	protected ConnectionLogger i_logger;
	protected String i_objId;
	private StatementAdaptorContext i_adaptContext;
	private StatementHandler i_handler;

	/**
	 * @param connection
	 * @param wrapped
	 */
	public CpStatement(CpConnection connection, Statement wrapped, String objId) {
		super();
		i_cpConnection = connection;
		i_wrapped = wrapped;
		i_logger = connection.cpLogger();
		i_objId = objId;
		i_adaptContext = new StatementAdaptorContext();
	}
	
	/**
	 * @return the wrapped
	 */
	public Statement cpWrapped() {
		return i_wrapped;
	}
	
	/**
	 * @param stmt
	 */
	public void cpSetWrapped(Statement stmt) {
		i_wrapped = stmt;
	}
	
	public CpConnection cpConnection() {
		return (CpConnection)i_cpConnection;
	}
	
	public String cpObjectId() {
		return i_objId;
	}
	
	public StatementAdaptorContext cpContext() {
		return i_adaptContext;
	}
	
	public StatementHandler cpHandler() {
		return i_handler;
	}
	
	public void cpSetHandler(StatementHandler handler) {
		i_handler = handler;
	}
	
	////////////////////////////////////////////////////////////////////////////
	///{AUTOGEN:FRAME_BEGIN}
	//{AUTOGEN:STMT_addBatchS:BEGIN}
	public void addBatch(String sql) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_addBatchS,sql);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Should decompose in statements and translate them.
			i_wrapped.addBatch(sql);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_addBatchS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_addBatchS, null);
	}
	//{AUTOGEN:STMT_addBatchS:END}
	//{AUTOGEN:STMT_cancel:BEGIN}
	public void cancel() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_cancel);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.cancel();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_cancel, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_cancel, null);
	}
	//{AUTOGEN:STMT_cancel:END}
	//{AUTOGEN:STMT_clearBatch:BEGIN}
	public void clearBatch() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_clearBatch);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.clearBatch();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_clearBatch, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_clearBatch, null);
	}
	//{AUTOGEN:STMT_clearBatch:END}
	//{AUTOGEN:STMT_clearWarnings:BEGIN}
	public void clearWarnings() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_clearWarnings);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.clearWarnings();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_clearWarnings, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_clearWarnings, null);
	}
	//{AUTOGEN:STMT_clearWarnings:END}
	//{AUTOGEN:STMT_close:BEGIN}
	public void close() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_close);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			if (i_wrapped != null) i_wrapped.close();
			// TODO exceptional handling mechanism. Work out a more consistent one.
			// Whether to check for null everywhere, or set a dummy statement/object as required.
			// TODO finalization for context information.
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_close, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_close, null);
	}
	//{AUTOGEN:STMT_close:END}
	//{AUTOGEN:STMT_executeSI:BEGIN}
	public boolean execute(String sql, int autoGeneratedKeys) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_executeSI,sql, autoGeneratedKeys);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = (Boolean)cpConnection().cpMapper().executeStatement(
					this, JdbcMethod.STMT_executeSI, sql, autoGeneratedKeys);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_executeSI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_executeSI, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_executeSI:END}
	//{AUTOGEN:STMT_executeSIa:BEGIN}
	public boolean execute(String sql, int[] columnIndexes) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_executeSIa,sql, columnIndexes);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = (Boolean)cpConnection().cpMapper().executeStatement(
					this, JdbcMethod.STMT_executeSIa, sql, columnIndexes);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_executeSIa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_executeSIa, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_executeSIa:END}
	//{AUTOGEN:STMT_executeSSa:BEGIN}
	public boolean execute(String sql, String[] columnNames) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_executeSSa,sql, columnNames);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = (Boolean)cpConnection().cpMapper().executeStatement(
					this, JdbcMethod.STMT_executeSSa, sql, (Object)columnNames);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_executeSSa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_executeSSa, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_executeSSa:END}
	//{AUTOGEN:STMT_executeS:BEGIN}
	public boolean execute(String sql) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_executeS,sql);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = (Boolean)cpConnection().cpMapper().executeStatement(
					this, JdbcMethod.STMT_executeS, sql);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_executeS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_executeS, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_executeS:END}
	//{AUTOGEN:STMT_executeBatch:BEGIN}
	public int[] executeBatch() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_executeBatch);
		int[] l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Try to handle batch
			l_result = i_wrapped.executeBatch();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_executeBatch, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_executeBatch, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_executeBatch:END}
	//{AUTOGEN:STMT_executeQueryS:BEGIN}
	public ResultSet executeQuery(String sql) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_executeQueryS,sql);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = (ResultSet)cpConnection().cpMapper().executeStatement(
					this, JdbcMethod.STMT_executeQueryS,sql);
			l_result = cpConnection().cpFactory().wrapResultSet(l_result, this);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_executeQueryS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_executeQueryS, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_executeQueryS:END}
	//{AUTOGEN:STMT_executeUpdateSI:BEGIN}
	public int executeUpdate(String sql, int autoGeneratedKeys) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_executeUpdateSI,sql, autoGeneratedKeys);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = (Integer)cpConnection().cpMapper().executeStatement(
					this, JdbcMethod.STMT_executeUpdateSI,sql, autoGeneratedKeys);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_executeUpdateSI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_executeUpdateSI, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_executeUpdateSI:END}
	//{AUTOGEN:STMT_executeUpdateSIa:BEGIN}
	public int executeUpdate(String sql, int[] columnIndexes) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_executeUpdateSIa,sql, columnIndexes);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = (Integer)cpConnection().cpMapper().executeStatement(
					this, JdbcMethod.STMT_executeUpdateSIa, sql, (Object)columnIndexes);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_executeUpdateSIa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_executeUpdateSIa, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_executeUpdateSIa:END}
	//{AUTOGEN:STMT_executeUpdateSSa:BEGIN}
	public int executeUpdate(String sql, String[] columnNames) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_executeUpdateSSa,sql, columnNames);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = (Integer)cpConnection().cpMapper().executeStatement(
					this, JdbcMethod.STMT_executeUpdateSSa, sql, (Object)columnNames);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_executeUpdateSSa, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_executeUpdateSSa, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_executeUpdateSSa:END}
	//{AUTOGEN:STMT_executeUpdateS:BEGIN}
	public int executeUpdate(String sql) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_executeUpdateS,sql);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = (Integer)cpConnection().cpMapper().executeStatement(
					this, JdbcMethod.STMT_executeUpdateS, sql);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_executeUpdateS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_executeUpdateS, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_executeUpdateS:END}
	//{AUTOGEN:STMT_getConnection:BEGIN}
	public Connection getConnection() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getConnection);
		Connection l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// return self connection, not wrapped.
			l_result = i_cpConnection;
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getConnection, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getConnection, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getConnection:END}
	//{AUTOGEN:STMT_getFetchDirection:BEGIN}
	public int getFetchDirection() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getFetchDirection);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getFetchDirection();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getFetchDirection, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getFetchDirection, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getFetchDirection:END}
	//{AUTOGEN:STMT_getFetchSize:BEGIN}
	public int getFetchSize() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getFetchSize);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getFetchSize();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getFetchSize, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getFetchSize, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getFetchSize:END}
	//{AUTOGEN:STMT_getGeneratedKeys:BEGIN}
	public ResultSet getGeneratedKeys() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getGeneratedKeys);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpHandler().getGeneratedKeys(this);
			l_result = cpConnection().cpFactory().wrapResultSet(l_result, this);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getGeneratedKeys, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getGeneratedKeys, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getGeneratedKeys:END}
	//{AUTOGEN:STMT_getMaxFieldSize:BEGIN}
	public int getMaxFieldSize() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getMaxFieldSize);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxFieldSize();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getMaxFieldSize, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getMaxFieldSize, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getMaxFieldSize:END}
	//{AUTOGEN:STMT_getMaxRows:BEGIN}
	public int getMaxRows() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getMaxRows);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getMaxRows();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getMaxRows, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getMaxRows, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getMaxRows:END}
	//{AUTOGEN:STMT_getMoreResults:BEGIN}
	public boolean getMoreResults() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getMoreResults);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Try to handle this rare use.
			l_result = i_wrapped.getMoreResults();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getMoreResults, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getMoreResults, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getMoreResults:END}
	//{AUTOGEN:STMT_getMoreResultsI:BEGIN}
	public boolean getMoreResults(int current) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getMoreResultsI,current);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Try to handle this rare use.
			l_result = i_wrapped.getMoreResults(current);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getMoreResultsI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getMoreResultsI, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getMoreResultsI:END}
	//{AUTOGEN:STMT_getQueryTimeout:BEGIN}
	public int getQueryTimeout() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getQueryTimeout);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getQueryTimeout();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getQueryTimeout, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getQueryTimeout, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getQueryTimeout:END}
	//{AUTOGEN:STMT_getResultSet:BEGIN}
	public ResultSet getResultSet() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getResultSet);
		ResultSet l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = cpHandler().getResultSet(this);
			l_result = cpConnection().cpFactory().wrapResultSet(l_result, this);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getResultSet, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getResultSet, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getResultSet:END}
	//{AUTOGEN:STMT_getResultSetConcurrency:BEGIN}
	public int getResultSetConcurrency() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getResultSetConcurrency);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getResultSetConcurrency();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getResultSetConcurrency, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getResultSetConcurrency, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getResultSetConcurrency:END}
	//{AUTOGEN:STMT_getResultSetHoldability:BEGIN}
	public int getResultSetHoldability() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getResultSetHoldability);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getResultSetHoldability();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getResultSetHoldability, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getResultSetHoldability, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getResultSetHoldability:END}
	//{AUTOGEN:STMT_getResultSetType:BEGIN}
	public int getResultSetType() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getResultSetType);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getResultSetType();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getResultSetType, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getResultSetType, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getResultSetType:END}
	//{AUTOGEN:STMT_getUpdateCount:BEGIN}
	public int getUpdateCount() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getUpdateCount);
		int l_result = 0;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getUpdateCount();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getUpdateCount, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getUpdateCount, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getUpdateCount:END}
	//{AUTOGEN:STMT_getWarnings:BEGIN}
	public SQLWarning getWarnings() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_getWarnings);
		SQLWarning l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getWarnings();
			// TT_LOW Wrap SQLWarning
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_getWarnings, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_getWarnings, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_getWarnings:END}
	//{AUTOGEN:STMT_isClosed:BEGIN}
	public boolean isClosed() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_isClosed);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.isClosed();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_isClosed, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_isClosed, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_isClosed:END}
	//{AUTOGEN:STMT_isPoolable:BEGIN}
	public boolean isPoolable() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_isPoolable);
		boolean l_result = false;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			// TT_LOW Not apearing in my javadoc. What can we do about it?
			l_result = i_wrapped.isPoolable();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_isPoolable, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_isPoolable, l_result);
			return l_result;
	}
	//{AUTOGEN:STMT_isPoolable:END}
	//{AUTOGEN:STMT_setCursorNameS:BEGIN}
	public void setCursorName(String name) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_setCursorNameS,name);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.setCursorName(name);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_setCursorNameS, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_setCursorNameS, null);
	}
	//{AUTOGEN:STMT_setCursorNameS:END}
	//{AUTOGEN:STMT_setEscapeProcessingB:BEGIN}
	public void setEscapeProcessing(boolean enable) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_setEscapeProcessingB,enable);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.setEscapeProcessing(enable);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_setEscapeProcessingB, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_setEscapeProcessingB, null);
	}
	//{AUTOGEN:STMT_setEscapeProcessingB:END}
	//{AUTOGEN:STMT_setFetchDirectionI:BEGIN}
	public void setFetchDirection(int direction) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_setFetchDirectionI,direction);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.setFetchDirection(direction);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_setFetchDirectionI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_setFetchDirectionI, null);
	}
	//{AUTOGEN:STMT_setFetchDirectionI:END}
	//{AUTOGEN:STMT_setFetchSizeI:BEGIN}
	public void setFetchSize(int rows) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_setFetchSizeI,rows);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.setFetchSize(rows);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_setFetchSizeI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_setFetchSizeI, null);
	}
	//{AUTOGEN:STMT_setFetchSizeI:END}
	//{AUTOGEN:STMT_setMaxFieldSizeI:BEGIN}
	public void setMaxFieldSize(int max) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_setMaxFieldSizeI,max);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.setMaxFieldSize(max);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_setMaxFieldSizeI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_setMaxFieldSizeI, null);
	}
	//{AUTOGEN:STMT_setMaxFieldSizeI:END}
	//{AUTOGEN:STMT_setMaxRowsI:BEGIN}
	public void setMaxRows(int max) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_setMaxRowsI,max);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.setMaxRows(max);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_setMaxRowsI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_setMaxRowsI, null);
	}
	//{AUTOGEN:STMT_setMaxRowsI:END}
	//{AUTOGEN:STMT_setPoolableB:BEGIN}
	public void setPoolable(boolean poolable) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_setPoolableB,poolable);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.setPoolable(poolable);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_setPoolableB, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_setPoolableB, null);
	}
	//{AUTOGEN:STMT_setPoolableB:END}
	//{AUTOGEN:STMT_setQueryTimeoutI:BEGIN}
	public void setQueryTimeout(int seconds) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STMT_setQueryTimeoutI,seconds);
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			i_wrapped.setQueryTimeout(seconds);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STMT_setQueryTimeoutI, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STMT_setQueryTimeoutI, null);
	}
	//{AUTOGEN:STMT_setQueryTimeoutI:END}
	///{AUTOGEN:FRAME_END}
	////////////////////////////////////////////////////////////////////////////

	@Override
	public boolean isWrapperFor(Class<?> iface) throws SQLException {
		// TT_LOW Some day will have to find if this is what is expected...
		if (iface.isAssignableFrom(i_wrapped.getClass())) {
			return true;
		} else {
			return i_wrapped.isWrapperFor(iface);
		}
	}

	@Override
	public <T> T unwrap(Class<T> arg0) throws SQLException {
		// TT_LOW Some day will have to find if this is what is expected...
		if (arg0.isAssignableFrom(i_wrapped.getClass())) {
			return (T)i_wrapped;
		} else {
			return i_wrapped.unwrap(arg0);
		}
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "CpStatement:" + i_objId;
	}

}
