/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.impl;

import java.sql.SQLException;
import java.sql.Struct;
import java.util.Map;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.CpWrapper;
import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.log.ConnectionLogger;

/**
 * Base decorator for sql.Struct.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 *
 */
public class CpStruct implements Struct, CpWrapper {
	private Struct i_wrapped;
	private CpConnection i_conn;
	private ConnectionLogger i_logger;
	private String i_objId;

	// Default constructor, just in case a subclass needs it.
	protected CpStruct() {
		super();
	}

	/**
	 * @param connection
	 * @param wrapped
	 */
	public CpStruct(CpResultSet rs, Struct wrapped, String objId) {
		super();
		i_conn = rs.cpConnection();
		i_wrapped = wrapped;
		i_logger = rs.cpStatement().cpConnection().cpLogger();
		i_objId = objId;
	}

	/**
	 * @param connection
	 * @param wrapped
	 */
	public CpStruct(CpConnection conn, Struct wrapped, String objId) {
		super();
		i_conn = conn;
		i_wrapped = wrapped;
		i_logger = conn.cpLogger();
		i_objId = objId;
	}


	/**
	 * Return the wrapped clob object.
	 */
	public Struct cpWrapped() {
		return i_wrapped;
	}

	public CpConnection cpConnection() {
		return i_conn;
	}
	
	public String cpObjectId() {
		return i_objId;
	}

	////////////////////////////////////////////////////////////////////////////
	///{AUTOGEN:FRAME_BEGIN}

	//{AUTOGEN:STRT_getAttributes:BEGIN}
	public Object[] getAttributes() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STRT_getAttributes);
		Object[] l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getAttributes();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STRT_getAttributes, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STRT_getAttributes, l_result);
			return l_result;
	}
	//{AUTOGEN:STRT_getAttributes:END}
	//{AUTOGEN:STRT_getAttributesMp:BEGIN}
	public Object[] getAttributes(Map<String, Class<?>> a_map) throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STRT_getAttributesMp,a_map);
		Object[] l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getAttributes(a_map);
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STRT_getAttributesMp, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STRT_getAttributesMp, l_result);
			return l_result;
	}
	//{AUTOGEN:STRT_getAttributesMp:END}
	//{AUTOGEN:STRT_getSQLTypeName:BEGIN}
	public String getSQLTypeName() throws SQLException {
		i_logger.logStart(i_objId, JdbcMethod.STRT_getSQLTypeName);
		String l_result = null;
		try {
			//{AUTOGEN:CUSTOM_BEGIN}
			l_result = i_wrapped.getSQLTypeName();
			//{AUTOGEN:CUSTOM_END}
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(i_logger, i_objId, JdbcMethod.STRT_getSQLTypeName, t);
		}
		i_logger.logSuccess(i_objId, JdbcMethod.STRT_getSQLTypeName, l_result);
			return l_result;
	}
	//{AUTOGEN:STRT_getSQLTypeName:END}
	///{AUTOGEN:FRAME_END}
	////////////////////////////////////////////////////////////////////////////

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "CpStruct:" + i_objId;
	}

}
