/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.log;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.JdbcMethod;

public class LogEvent {
	public static LogEvent createMethodEnded(CpLogger.Context ctx, DataCallStart dataStart, Object result, StackTraceElement[] stack) {
		return new LogEvent(
				ctx.getConnectionId(),
				dataStart.getCallerId(),
				LogEventType.METHOD_SUCCESS,
				dataStart.getMethod(),
				null,
				dataStart.getStartTime(),
				System.currentTimeMillis() - dataStart.getStartTime(),
				dataStart.getParameters(),
				result,
				stack);
	}
	
	public static LogEvent createMethodFailed(CpLogger.Context ctx, DataCallStart dataStart, Throwable t) {
		return new LogEvent(
				ctx.getConnectionId(),
				dataStart.getCallerId(),
				LogEventType.METHOD_FAIL,
				dataStart.getMethod(),
				null,
				dataStart.getStartTime(),
				System.currentTimeMillis() - dataStart.getStartTime(),
				dataStart.getParameters(),
				t,
				null);
	}

	public static LogEvent createCustom(String connectionId, String srcId,
			String customId, long timeStart, Object[] params, StackTraceElement[] stack) {
		return new LogEvent(
				connectionId,
				srcId,
				LogEventType.CUSTOM,
				null,
				customId,
				timeStart,
				System.currentTimeMillis() - timeStart,
				params,
				null,
				stack);
	}

	
	private String i_connectionId;
	private String i_srcId;
	private LogEventType i_type;
	private JdbcMethod i_method;
	private String i_customTag;
	private long i_timeStart;
	private long i_timeEllapsed;
	private StackTraceElement[] i_stackTrace;
	
	private Object[] i_params;
	private Object i_result;

	public LogEvent(String connectionId, String srcId,
			LogEventType type, JdbcMethod method, String customTag, long timeStart,
			long timeEllapsed, Object[] params, Object result, StackTraceElement[] stackTrace) {
		super();
		i_connectionId = connectionId;
		i_srcId = srcId;
		i_type = type;
		i_method = method;
		i_customTag = customTag;
		i_timeStart = timeStart;
		i_timeEllapsed = timeEllapsed;
		i_params = params;
		i_result = result;
		i_stackTrace = stackTrace;
	}
	
	/**
	 * @return the connectionId
	 */
	public String getConnectionId() {
		return i_connectionId;
	}

	/**
	 * @return the srcId
	 */
	public String getSrcId() {
		return i_srcId;
	}

	/**
	 * @return the type
	 */
	public LogEventType getType() {
		return i_type;
	}

	/**
	 * @return the method
	 */
	public JdbcMethod getMethod() {
		return i_method;
	}

	/**
	 * @return the customTag
	 */
	public String getCustomTag() {
		return i_customTag;
	}

	/**
	 * @return the timestamp
	 */
	public long getTimestamp() {
		return i_timeStart;
	}

	/**
	 * @return the params
	 */
	public Object[] getParams() {
		return i_params;
	}

	/**
	 * @return the timeStart
	 */
	public long getTimeStart() {
		return i_timeStart;
	}

	/**
	 * @return the timeEllapsed
	 */
	public long getTimeEllapsed() {
		return i_timeEllapsed;
	}

	/**
	 * @return the stackTrace
	 */
	public StackTraceElement[] getStackTrace() {
		return i_stackTrace;
	}

	/**
	 * @return the result
	 */
	public Object getResult() {
		return i_result;
	}
	
	@Override
	public String toString() {
		return String.format("LogEvent:%s/%s @ %s w/%s",
				i_connectionId,
				i_srcId,
				(i_method != null ? i_method.name() : i_customTag),
				CpUtils.toString(i_params));
	}
}
