/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.st;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Map;

import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.impl.CpPreparedStatement;
import ddbc.cpn2.impl.CpStatement;
import ddbc.commons.util.Strings;

public class HandlerFail implements StatementHandler {
	private static String DEFAULT_MESSAGE = "Statement not supported by adaptor: %s";
	public static HandlerFail getInstance(Map<String,String> attributes, String cfgText) {
		String l_message;
		if (Strings.isEmptyOrWhiteSpace(cfgText)) {
			l_message = DEFAULT_MESSAGE;
		} else {
			l_message = cfgText.trim();
		}
		// Alternative: Use a pool, but with hundred unique instances it doesn't pay.
		return new HandlerFail(attributes, l_message);
	}
	
	protected Map<String,String> i_attributes;
	protected String i_message = "Unsupported statement %s";
	
	protected HandlerFail() {
		super();
	}

	protected HandlerFail(Map<String,String> attributes, String message) {
		super();
		i_attributes = attributes;
		i_message = message;
	}


	public void disposeBehaviourState(Object a_bhvrState) {
		// nothing to do.
	}

	
	/* (non-Javadoc)
	 * @see ddbc.cpn2.st.StatementHandler#applyStart(ddbc.cpn2.impl.CpPreparedStatement, ddbc.cpn2.JdbcMethod, java.lang.String, java.lang.Object[])
	 */
	@Override
	public void applyStart(CpPreparedStatement ps, JdbcMethod method,
			String a_sql, Object... a_moreParams) throws SQLException {
		String l_strStatement = ps.cpContext().getStrStatement();
		String l_formattedMessage = String.format(i_message, l_strStatement);
		throw new SQLException(l_formattedMessage);
	}
	
	/* (non-Javadoc)
	 * @see ddbc.cpn2.st.StatementHandler#applyParam(ddbc.cpn2.impl.CpPreparedStatement, ddbc.cpn2.JdbcMethod, int, java.lang.Object[])
	 */
	@Override
	public void applyParam(CpPreparedStatement ps, JdbcMethod method,
			int paramIdx, Object... moreParams) throws SQLException {
		String l_strStatement = ps.cpContext().getStrStatement();
		String l_formattedMessage = String.format(i_message, l_strStatement);
		throw new SQLException(l_formattedMessage);
	}

	/* (non-Javadoc)
	 * @see ddbc.cpn2.st.StatementHandler#executePs(ddbc.cpn2.impl.CpPreparedStatement, ddbc.cpn2.JdbcMethod, java.lang.Object[])
	 */
	@Override
	public Object executePs(CpPreparedStatement ps, JdbcMethod method,
			Object... a_moreParams) throws SQLException {
		String l_strStatement = ps.cpContext().getStrStatement();
		String l_formattedMessage = String.format(i_message, l_strStatement);
		throw new SQLException(l_formattedMessage);
	}

	/* (non-Javadoc)
	 * @see ddbc.cpn2.st.StatementHandler#executeStmt(ddbc.cpn2.impl.CpStatement, ddbc.cpn2.JdbcMethod, java.lang.String, java.lang.Object[])
	 */
	@Override
	public Object executeStmt(CpStatement stmt, JdbcMethod method,
			String a_sql, Object... a_moreParams) throws SQLException {
		String l_strStatement = stmt.cpContext().getStrStatement();
		String l_formattedMessage = String.format(i_message, l_strStatement);
		throw new SQLException(l_formattedMessage);
	}

	/* (non-Javadoc)
	 * @see ddbc.cpn2.st.StatementHandler#getResultSet(ddbc.cpn2.impl.CpStatement)
	 */
	@Override
	public ResultSet getResultSet(CpStatement stmt) throws SQLException {
		String l_strStatement = stmt.cpContext().getStrStatement();
		String l_formattedMessage = String.format(i_message, l_strStatement);
		throw new SQLException(l_formattedMessage);
	}
	
	/* (non-Javadoc)
	 * @see ddbc.cpn2.st.StatementHandler#getGeneratedKeys(ddbc.cpn2.impl.CpStatement)
	 */
	@Override
	public ResultSet getGeneratedKeys(CpStatement stmt) throws SQLException {
		String l_strStatement = stmt.cpContext().getStrStatement();
		String l_formattedMessage = String.format(i_message, l_strStatement);
		throw new SQLException(l_formattedMessage);
	}

}
