/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.st;

import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import ddbc.cpn2.CpUtils;
import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.StatementAdaptorContext;
import ddbc.cpn2.StatementAdaptorContext.SetParameter;
import ddbc.cpn2.impl.CpConnection;
import ddbc.cpn2.impl.CpPreparedStatement;
import ddbc.cpn2.impl.CpStatement;
import ddbc.commons.jdbc.JdbcUtils;
import ddbc.commons.util.FCollections;

public class HandlerMapper {
	// TODO Asimilate responsability of changing the connection context state.
	// TODO Append into the connection state a history of the statement contexts
	// TODO Handle the end of a connection/transaction. Freeing the contexts, executing pending operations.
	private static final HandlerMapper s_dumbInstance = new HandlerMapper();
	public static HandlerMapper dumbInstance() {
		return s_dumbInstance;
	}
	

	// fields
	private HashMap<String,MappingElement[]> i_handlersByNormalized = new HashMap<String, MappingElement[]>();
	private ArrayList<MappingElement> i_mappingSeq = new ArrayList<MappingElement>();
	private StatementHandler i_defaultHandler = BaseHandler.INSTANCE_UNEXPECTED;
	
	public HandlerMapper() {
		super();
	}

	// TODO Constructor getters setters
	/**
	 * @return the defaultHandler
	 */
	public StatementHandler getDefaultHandler() {
		return i_defaultHandler;
	}

	/**
	 * @param a_defaultHandler the defaultHandler to set
	 */
	public void setDefaultHandler(StatementHandler a_defaultHandler) {
		i_defaultHandler = a_defaultHandler;
	}

	public void addMapping(MappingElement mapping) {
		// Literal statements
		// TT_LOW feature: Statement mapping.
//		String[] l_normStmts = mapping.getNorms();
//		if (l_normStmts != null) {
//			for (String l_normStmt : l_normStmts) {
//				MappingElement[] l_mappingsForStatement = i_handlersByNormalized.get(l_normStmt);
//				if (l_mappingsForStatement == null) {
//					l_mappingsForStatement = new MappingElement[]{mapping};
//				} else {
//					l_mappingsForStatement = FCollections.appendToArray(l_mappingsForStatement, mapping);
//				}
//			}
//		}
		// Mapping sequence.
		// TT_LOW Introduce a mapping for statement type and tables.
		// TT_LOW Allow the mapping to tell not to be further included.
		i_mappingSeq.add(mapping);
	}
	
	
	/**
	 * @param stmt
	 * @return
	 * @throws SQLException
	 */
	public StatementHandler findStatementHandler(CpStatement stmt) throws SQLException {
		StatementAdaptorContext l_stmtCtx = stmt.cpContext();
		// normalize sql
//		String l_strNormalized = JdbcUtils.normalizeString(l_stmtCtx.getStrStatement());
		StatementHandler l_selectedHandler = null;
		// try direct mapping
		// TT_LOW Introduce feature
//		MappingElement[] l_candidates = i_handlersByNormalized.get(l_strNormalized);
//		if (l_candidates != null) {
//			for (MappingElement l_candidate : l_candidates) {
//				if (l_candidate.getMatcher().matches(stmt)) {
//					l_selectedHandler = l_candidate.getHandler();
//					break;
//				}
//			}
//		}
		
		// try chain of matchers
		if (l_selectedHandler == null) {
			for (MappingElement l_candidate : i_mappingSeq) {
				if (l_candidate.getMatcher().matches(stmt)) {
					l_selectedHandler = l_candidate.getHandler();
					break;
				}
			}
		}
		// If didn't find a handler, return null (let the caller know). 

		return l_selectedHandler;
	}
	
	/**
	 * Apply into the handler the statement data already entered.
	 * At least the Statement sql must be entered. At most all the parameters may be specified.
	 * @param ps
	 * @param handler
	 * @throws SQLException
	 */
	public void applyDeferred(CpPreparedStatement ps, StatementHandler handler) throws SQLException {
		StatementAdaptorContext l_ctx = ps.cpContext();
		handler.applyStart(ps, l_ctx.getCreateMethod(), l_ctx.getStrStatement(), l_ctx.getCreateParameters());
		List<SetParameter> l_parameters = l_ctx.getParameters();
		if (l_parameters != null) {
			for (SetParameter l_set : l_parameters) {
				handler.applyParam(ps, l_set.getSetMethod(), l_set.getParameterIndex(), l_set.getSetParameters());
			}
		}
	}
	
	public CpStatement createStatement(CpConnection conn, JdbcMethod method,
			Object ... moreParams) throws SQLException {
		Statement l_wrapped = null;
		try {
			l_wrapped = (Statement)method.getMethod().invoke(conn.cpWrapped(), moreParams);
		} catch (Throwable t) {
			CpUtils.handleCatchSqle(conn.cpLogger(), conn.cpObjectId(), method, t);
		}
		return conn.cpFactory().wrapStatement(l_wrapped, conn);
	}
	
	public CpPreparedStatement prepareStatement(CpConnection conn, JdbcMethod method,
			String sql, Object ... moreParams) throws SQLException {
		CpPreparedStatement l_ps = conn.cpFactory().wrapPreparedStatement(null, conn);
		l_ps.cpContext().setCreateMethod(method, FCollections.concatArray(Object.class, sql, moreParams));
		StatementHandler l_handler = findStatementHandler(l_ps);
		if (l_handler != null) {
			applyDeferred(l_ps, l_handler);
			l_ps.cpSetHandler(l_handler);
		}
		return l_ps;
	}
	
	public void setParameter(CpPreparedStatement ps, JdbcMethod method,
			int setIdx, Object ... moreParams) throws SQLException {
		ps.cpContext().setParameter(method, setIdx, moreParams);
		StatementHandler l_handler = ps.cpHandler();
		if (l_handler != null) {
			l_handler.applyParam(ps, method, setIdx, moreParams);
		}
	}
	
	public Object executeStatement(CpStatement stmt, JdbcMethod method,
			String sql, Object ... execParams) throws SQLException {
		// In the case of statements, if a handler was previously set, it is overwritten.
		StatementAdaptorContext l_ctx = stmt.cpContext();
		l_ctx.setExecute(method, FCollections.concatArray(Object.class, sql, execParams));
		StatementHandler l_handler = findStatementHandler(stmt);
		if (l_handler == null) { l_handler = getDefaultHandler(); }
		stmt.cpSetHandler(l_handler);
		return l_handler.executeStmt(stmt, method, sql, execParams);
	}
	
	public Object executePrepared(CpPreparedStatement ps, JdbcMethod method,
			Object ... moreParams) throws SQLException {
		// In the case of prepared statements, a valid handler can be previously set.
		StatementAdaptorContext l_ctx = ps.cpContext();
		l_ctx.setExecute(method, moreParams);
		StatementHandler l_handler = ps.cpHandler();
		if (l_handler == null) {
			l_handler = findStatementHandler(ps);
			if (l_handler == null) { l_handler = getDefaultHandler(); }
			ps.cpSetHandler(l_handler);
			applyDeferred(ps, l_handler);
		}
		return l_handler.executePs(ps, method, moreParams);
	}
}
