/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.cpn2.st;

import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import ddbc.cpn2.impl.CpStatement;
import ddbc.commons.util.Strings;

public class HandlerRegex extends BaseHandler {

	private List<Pattern> i_patterns;
	private List<String> i_replacements;
	private List<String> i_exclusions;

	public HandlerRegex(Map<String,String> attributes, List<Pattern> patterns, List<String> replacements, List<String> exclusions) {
		super(attributes, "");
		i_patterns = patterns;
		i_replacements = replacements;
		i_exclusions = exclusions;
	}

	/* (non-Javadoc)
	 * @see ddbc.cpn2.st.BaseHandler#translateSql(ddbc.cpn2.impl.CpStatement, java.lang.String)
	 */
	@Override
	protected String translateSql(CpStatement stmt, String sql) {
		String l_replacementStatement = sql;
		HashSet<String> l_activeExclusions = new HashSet<String>();
		for (int i = 0; i < i_patterns.size(); i++) {
			String l_ruleExclusion = i_exclusions.get(i);
			// Won't apply the rule is an exclussion is defined and is applied.
			if (Strings.isEmpty(l_ruleExclusion) ||
					! l_activeExclusions.contains(l_ruleExclusion)) {
				Pattern l_pattern = i_patterns.get(i);
				String l_patternReplacement = i_replacements.get(i);
				Matcher l_matcher = l_pattern.matcher(l_replacementStatement);
				if (l_matcher.find()) {
					l_replacementStatement = l_matcher.replaceAll(l_patternReplacement);
					l_activeExclusions.add(l_ruleExclusion);
				}
			}
		}
		return l_replacementStatement;
	}
}
