/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.impl;

import java.sql.Array;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Map;

/**
 * Decorator for sql.Array.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class DArray implements Array {
	private Array i_decorated;

	/**
	 * @throws SQLException
	 * @see java.sql.Array#free()
	 */
	public void free() throws SQLException {
		i_decorated.free();
	}

	/**
	 * @return
	 * @throws SQLException
	 * @see java.sql.Array#getArray()
	 */
	public Object getArray() throws SQLException {
		return i_decorated.getArray();
	}

	/**
	 * @param a_index
	 * @param a_count
	 * @param a_map
	 * @return
	 * @throws SQLException
	 * @see java.sql.Array#getArray(long, int, java.util.Map)
	 */
	public Object getArray(long a_index, int a_count,
			Map<String, Class<?>> a_map) throws SQLException {
		return i_decorated.getArray(a_index, a_count, a_map);
	}

	/**
	 * @param a_index
	 * @param a_count
	 * @return
	 * @throws SQLException
	 * @see java.sql.Array#getArray(long, int)
	 */
	public Object getArray(long a_index, int a_count) throws SQLException {
		return i_decorated.getArray(a_index, a_count);
	}

	/**
	 * @param a_map
	 * @return
	 * @throws SQLException
	 * @see java.sql.Array#getArray(java.util.Map)
	 */
	public Object getArray(Map<String, Class<?>> a_map) throws SQLException {
		return i_decorated.getArray(a_map);
	}

	/**
	 * @return
	 * @throws SQLException
	 * @see java.sql.Array#getBaseType()
	 */
	public int getBaseType() throws SQLException {
		return i_decorated.getBaseType();
	}

	/**
	 * @return
	 * @throws SQLException
	 * @see java.sql.Array#getBaseTypeName()
	 */
	public String getBaseTypeName() throws SQLException {
		return i_decorated.getBaseTypeName();
	}

	/**
	 * @return
	 * @throws SQLException
	 * @see java.sql.Array#getResultSet()
	 */
	public ResultSet getResultSet() throws SQLException {
		return i_decorated.getResultSet();
	}

	/**
	 * @param a_index
	 * @param a_count
	 * @param a_map
	 * @return
	 * @throws SQLException
	 * @see java.sql.Array#getResultSet(long, int, java.util.Map)
	 */
	public ResultSet getResultSet(long a_index, int a_count,
			Map<String, Class<?>> a_map) throws SQLException {
		return i_decorated.getResultSet(a_index, a_count, a_map);
	}

	/**
	 * @param a_index
	 * @param a_count
	 * @return
	 * @throws SQLException
	 * @see java.sql.Array#getResultSet(long, int)
	 */
	public ResultSet getResultSet(long a_index, int a_count)
			throws SQLException {
		return i_decorated.getResultSet(a_index, a_count);
	}

	/**
	 * @param a_map
	 * @return
	 * @throws SQLException
	 * @see java.sql.Array#getResultSet(java.util.Map)
	 */
	public ResultSet getResultSet(Map<String, Class<?>> a_map)
			throws SQLException {
		return i_decorated.getResultSet(a_map);
	}
	

}
