package ddbc.impl;

import java.io.InputStream;
import java.io.OutputStream;
import java.sql.Blob;
import java.sql.SQLException;

// TODO Interesaría un proxy del OutputStream para controlar qué valores se introducen.
/**
 * Base Proxy/Decorator class for a java.sql.Blob.
 * It's just a filter-delegate implementation, ready to override in a subclass.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class DBlob implements Blob {
	/** JpConnection used to create the Blob. */
	protected DConnection i_connection = null;
	/** Wrapped Blob object. */
	protected Blob i_wrapped = null;
	
	// Default constructor, just in case a subclass needs it.
	protected DBlob() {
		super();
	}
	
	/**
	 * @param connection
	 * @param wrapped
	 */
	public DBlob(DConnection connection, Blob wrapped) {
		super();
		
		i_connection = connection;
		i_wrapped = wrapped;
	}
	
	/**
	 * Return the wrapped blob object.
	 */
	public Blob getWrapped() {
		return i_wrapped;
	}

	/* (non-Javadoc)
	 * @see java.sql.Blob#free()
	 */
	public void free() throws SQLException {
		i_wrapped.free();
	}

	/* (non-Javadoc)
	 * @see java.sql.Blob#getBinaryStream()
	 */
	public InputStream getBinaryStream() throws SQLException {
		return i_wrapped.getBinaryStream();
	}

	/* (non-Javadoc)
	 * @see java.sql.Blob#getBinaryStream(long, long)
	 */
	public InputStream getBinaryStream(long a_pos, long a_length)
			throws SQLException {
		return i_wrapped.getBinaryStream(a_pos, a_length);
	}

	/* (non-Javadoc)
	 * @see java.sql.Blob#getBytes(long, int)
	 */
	public byte[] getBytes(long a_pos, int a_length) throws SQLException {
		return i_wrapped.getBytes(a_pos, a_length);
	}

	/* (non-Javadoc)
	 * @see java.sql.Blob#length()
	 */
	public long length() throws SQLException {
		return i_wrapped.length();
	}

	/* (non-Javadoc)
	 * @see java.sql.Blob#position(java.sql.Blob, long)
	 */
	public long position(Blob a_pattern, long a_start) throws SQLException {
		return i_wrapped.position(a_pattern, a_start);
	}

	/* (non-Javadoc)
	 * @see java.sql.Blob#position(byte[], long)
	 */
	public long position(byte[] a_pattern, long a_start) throws SQLException {
		return i_wrapped.position(a_pattern, a_start);
	}

	/**
	/* (non-Javadoc)
	 * @see java.sql.Blob#setBinaryStream(long)
	 */
	public OutputStream setBinaryStream(long a_pos) throws SQLException {
		return i_wrapped.setBinaryStream(a_pos);
	}

	/* (non-Javadoc)
	 * @see java.sql.Blob#setBytes(long, byte[], int, int)
	 */
	public int setBytes(long a_pos, byte[] a_bytes, int a_offset, int a_len)
			throws SQLException {
		return i_wrapped.setBytes(a_pos, a_bytes, a_offset, a_len);
	}

	/* (non-Javadoc)
	 * @see java.sql.Blob#setBytes(long, byte[])
	 */
	public int setBytes(long a_pos, byte[] a_bytes) throws SQLException {
		return i_wrapped.setBytes(a_pos, a_bytes);
	}

	/* (non-Javadoc)
	 * @see java.sql.Blob#truncate(long)
	 */
	public void truncate(long a_len) throws SQLException {
		i_wrapped.truncate(a_len);
	}
	
}
