package ddbc.impl;

import java.io.InputStream;
import java.io.Reader;
import java.math.BigDecimal;
import java.net.URL;
import java.sql.*;
import java.util.Calendar;
import java.util.Map;

/**
 * Base Proxy/Decorator for the Statement/PreparedStatement/CallableStatement interfaces.
 * Just works as a filter for the wrapped statement (wrapping generated objects if applies).
 * It is expected to be extended to provide some functionality.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class DCallableStatement implements CallableStatement {
	/** JpConnection on which the statements depends. */
	protected DConnection i_jpConnection;
	/** The wrapped statement. */
	protected Statement i_wrappedStatement;

	// Default constructor, Just in case a subclass doesn't fit the informed constructor
	protected DCallableStatement() {
		super();
	}

	/**
	 * @param a_connection
	 * @param a_wrapped
	 */
	public DCallableStatement(DConnection a_connection, Statement a_wrapped) {
		super();

		i_jpConnection = a_connection;
		i_wrappedStatement = a_wrapped;
	}
	public DCallableStatement(DConnection a_connection,
			PreparedStatement a_wrapped) {
		this(a_connection, (Statement)a_wrapped);
	}

	/**
	 * @param a_connection
	 * @param a_wrapped
	 */
	public DCallableStatement(DConnection a_connection,
			CallableStatement a_wrapped) {
		this(a_connection, (Statement)a_wrapped);
	}



	///////////////////////////////////////////////////////
	// BOILERPLATE
	//


	///////////////////////////////////
	// FIELD ACCESORS
	//
	/**
	 * @return the wrapped Statement
	 */
	public Statement dGetWrappedStmt() {
		return i_wrappedStatement;
	}

	/**
	 * @return the wrapped PreparedStatement
	 */
	public PreparedStatement dGetWrappedPS() {
		return (PreparedStatement)i_wrappedStatement;
	}

	/**
	 * @return the wrapped CallableStatement
	 */
	public CallableStatement dGetWrappedCS() {
		return (CallableStatement)i_wrappedStatement;
	}

	/**
	 * @return the jpConnection
	 */
	public DConnection dGetJpConnection() {
		return i_jpConnection;
	}

	///////////////////////////////////
	// IMPLEMENT/DELEGATE (Statement)
	//
	/* (non-Javadoc)
	 * @see java.sql.Statement#addBatch(java.lang.String)
	 */
	public void addBatch(String a_sql) throws SQLException {
		i_wrappedStatement.addBatch(a_sql);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#cancel()
	 */
	public void cancel() throws SQLException {
		i_wrappedStatement.cancel();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#clearBatch()
	 */
	public void clearBatch() throws SQLException {
		i_wrappedStatement.clearBatch();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#clearWarnings()
	 */
	public void clearWarnings() throws SQLException {
		i_wrappedStatement.clearWarnings();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#close()
	 */
	public void close() throws SQLException {
		i_wrappedStatement.close();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#execute(java.lang.String, int)
	 */
	public boolean execute(String a_sql, int a_autoGeneratedKeys)
			throws SQLException {
		return i_wrappedStatement.execute(a_sql, a_autoGeneratedKeys);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#execute(java.lang.String, int[])
	 */
	public boolean execute(String a_sql, int[] a_columnIndexes)
			throws SQLException {
		return i_wrappedStatement.execute(a_sql, a_columnIndexes);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#execute(java.lang.String, java.lang.String[])
	 */
	public boolean execute(String a_sql, String[] a_columnNames)
			throws SQLException {
		return i_wrappedStatement.execute(a_sql, a_columnNames);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#execute(java.lang.String)
	 */
	public boolean execute(String a_sql) throws SQLException {
		return i_wrappedStatement.execute(a_sql);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#executeBatch()
	 */
	public int[] executeBatch() throws SQLException {
		return i_wrappedStatement.executeBatch();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#executeQuery(java.lang.String)
	 */
	public ResultSet executeQuery(String a_sql) throws SQLException {
		return i_wrappedStatement.executeQuery(a_sql);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#executeUpdate(java.lang.String, int)
	 */
	public int executeUpdate(String a_sql, int a_autoGeneratedKeys)
			throws SQLException {
		return i_wrappedStatement.executeUpdate(a_sql, a_autoGeneratedKeys);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#executeUpdate(java.lang.String, int[])
	 */
	public int executeUpdate(String a_sql, int[] a_columnIndexes)
			throws SQLException {
		return i_wrappedStatement.executeUpdate(a_sql, a_columnIndexes);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#executeUpdate(java.lang.String, java.lang.String[])
	 */
	public int executeUpdate(String a_sql, String[] a_columnNames)
			throws SQLException {
		return i_wrappedStatement.executeUpdate(a_sql, a_columnNames);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#executeUpdate(java.lang.String)
	 */
	public int executeUpdate(String a_sql) throws SQLException {
		return i_wrappedStatement.executeUpdate(a_sql);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getConnection()
	 */
	public Connection getConnection() throws SQLException {
		return i_wrappedStatement.getConnection();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getFetchDirection()
	 */
	public int getFetchDirection() throws SQLException {
		return i_wrappedStatement.getFetchDirection();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getFetchSize()
	 */
	public int getFetchSize() throws SQLException {
		return i_wrappedStatement.getFetchSize();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getGeneratedKeys()
	 */
	public ResultSet getGeneratedKeys() throws SQLException {
		return i_wrappedStatement.getGeneratedKeys();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getMaxFieldSize()
	 */
	public int getMaxFieldSize() throws SQLException {
		return i_wrappedStatement.getMaxFieldSize();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getMaxRows()
	 */
	public int getMaxRows() throws SQLException {
		return i_wrappedStatement.getMaxRows();
	}
	/**
	/* (non-Javadoc)
	 * @see java.sql.Statement#getMoreResults()
	 */
	public boolean getMoreResults() throws SQLException {
		return i_wrappedStatement.getMoreResults();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getMoreResults(int)
	 */
	public boolean getMoreResults(int a_current) throws SQLException {
		return i_wrappedStatement.getMoreResults(a_current);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getQueryTimeout()
	 */
	public int getQueryTimeout() throws SQLException {
		return i_wrappedStatement.getQueryTimeout();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getResultSet()
	 */
	public ResultSet getResultSet() throws SQLException {
		return i_wrappedStatement.getResultSet();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getResultSetConcurrency()
	 */
	public int getResultSetConcurrency() throws SQLException {
		return i_wrappedStatement.getResultSetConcurrency();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getResultSetHoldability()
	 */
	public int getResultSetHoldability() throws SQLException {
		return i_wrappedStatement.getResultSetHoldability();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getResultSetType()
	 */
	public int getResultSetType() throws SQLException {
		return i_wrappedStatement.getResultSetType();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getUpdateCount()
	 */
	public int getUpdateCount() throws SQLException {
		return i_wrappedStatement.getUpdateCount();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#getWarnings()
	 */
	public SQLWarning getWarnings() throws SQLException {
		return i_wrappedStatement.getWarnings();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#isClosed()
	 */
	public boolean isClosed() throws SQLException {
		return i_wrappedStatement.isClosed();
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#isPoolable()
	 */
	public boolean isPoolable() throws SQLException {
		return i_wrappedStatement.isPoolable();
	}
	/* (non-Javadoc)
	 * @see java.sql.Wrapper#isWrapperFor(java.lang.Class)
	 */
	public boolean isWrapperFor(Class<?> a_arg0) throws SQLException {
		return i_wrappedStatement.isWrapperFor(a_arg0);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#setCursorName(java.lang.String)
	 */
	public void setCursorName(String a_name) throws SQLException {
		i_wrappedStatement.setCursorName(a_name);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#setEscapeProcessing(boolean)
	 */
	public void setEscapeProcessing(boolean a_enable) throws SQLException {
		i_wrappedStatement.setEscapeProcessing(a_enable);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#setFetchDirection(int)
	 */
	public void setFetchDirection(int a_direction) throws SQLException {
		i_wrappedStatement.setFetchDirection(a_direction);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#setFetchSize(int)
	 */
	public void setFetchSize(int a_rows) throws SQLException {
		i_wrappedStatement.setFetchSize(a_rows);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#setMaxFieldSize(int)
	 */
	public void setMaxFieldSize(int a_max) throws SQLException {
		i_wrappedStatement.setMaxFieldSize(a_max);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#setMaxRows(int)
	 */
	public void setMaxRows(int a_max) throws SQLException {
		i_wrappedStatement.setMaxRows(a_max);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#setPoolable(boolean)
	 */
	public void setPoolable(boolean a_poolable) throws SQLException {
		i_wrappedStatement.setPoolable(a_poolable);
	}
	/* (non-Javadoc)
	 * @see java.sql.Statement#setQueryTimeout(int)
	 */
	public void setQueryTimeout(int a_seconds) throws SQLException {
		i_wrappedStatement.setQueryTimeout(a_seconds);
	}
	/* (non-Javadoc)
	 * @see java.sql.Wrapper#unwrap(java.lang.Class)
	 */
	public <T> T unwrap(Class<T> a_arg0) throws SQLException {
		return i_wrappedStatement.unwrap(a_arg0);
	}
	
	///////////////////////////////////
	// IMPLEMENT/DELEGATE (PreparedStatement)
	//
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#addBatch()
	 */
	public void addBatch() throws SQLException {
		dGetWrappedPS().addBatch();
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#clearParameters()
	 */
	public void clearParameters() throws SQLException {
		dGetWrappedPS().clearParameters();
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#execute()
	 */
	public boolean execute() throws SQLException {
		return dGetWrappedPS().execute();
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#executeQuery()
	 */
	public ResultSet executeQuery() throws SQLException {
		return dGetWrappedPS().executeQuery();
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#executeUpdate()
	 */
	public int executeUpdate() throws SQLException {
		return dGetWrappedPS().executeUpdate();
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#getMetaData()
	 */
	public ResultSetMetaData getMetaData() throws SQLException {
		return dGetWrappedPS().getMetaData();
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#getParameterMetaData()
	 */
	public ParameterMetaData getParameterMetaData() throws SQLException {
		return dGetWrappedPS().getParameterMetaData();
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setArray(int, java.sql.Array)
	 */
	public void setArray(int a_parameterIndex, Array a_x) throws SQLException {
		dGetWrappedPS().setArray(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setAsciiStream(int, java.io.InputStream, int)
	 */
	public void setAsciiStream(int a_parameterIndex, InputStream a_x,
			int a_length) throws SQLException {
		dGetWrappedPS().setAsciiStream(a_parameterIndex, a_x, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setAsciiStream(int, java.io.InputStream, long)
	 */
	public void setAsciiStream(int a_parameterIndex, InputStream a_x,
			long a_length) throws SQLException {
		dGetWrappedPS().setAsciiStream(a_parameterIndex, a_x, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setAsciiStream(int, java.io.InputStream)
	 */
	public void setAsciiStream(int a_parameterIndex, InputStream a_x)
			throws SQLException {
		dGetWrappedPS().setAsciiStream(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setBigDecimal(int, java.math.BigDecimal)
	 */
	public void setBigDecimal(int a_parameterIndex, BigDecimal a_x)
			throws SQLException {
		dGetWrappedPS().setBigDecimal(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setBinaryStream(int, java.io.InputStream, int)
	 */
	public void setBinaryStream(int a_parameterIndex, InputStream a_x,
			int a_length) throws SQLException {
		dGetWrappedPS().setBinaryStream(a_parameterIndex, a_x, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setBinaryStream(int, java.io.InputStream, long)
	 */
	public void setBinaryStream(int a_parameterIndex, InputStream a_x,
			long a_length) throws SQLException {
		dGetWrappedPS().setBinaryStream(a_parameterIndex, a_x, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setBinaryStream(int, java.io.InputStream)
	 */
	public void setBinaryStream(int a_parameterIndex, InputStream a_x)
			throws SQLException {
		dGetWrappedPS().setBinaryStream(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setBlob(int, java.sql.Blob)
	 */
	public void setBlob(int a_parameterIndex, Blob a_x) throws SQLException {
		dGetWrappedPS().setBlob(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setBlob(int, java.io.InputStream, long)
	 */
	public void setBlob(int a_parameterIndex, InputStream a_inputStream,
			long a_length) throws SQLException {
		dGetWrappedPS().setBlob(a_parameterIndex, a_inputStream, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setBlob(int, java.io.InputStream)
	 */
	public void setBlob(int a_parameterIndex, InputStream a_inputStream)
			throws SQLException {
		dGetWrappedPS().setBlob(a_parameterIndex, a_inputStream);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setBoolean(int, boolean)
	 */
	public void setBoolean(int a_parameterIndex, boolean a_x)
			throws SQLException {
		dGetWrappedPS().setBoolean(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setByte(int, byte)
	 */
	public void setByte(int a_parameterIndex, byte a_x) throws SQLException {
		dGetWrappedPS().setByte(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setBytes(int, byte[])
	 */
	public void setBytes(int a_parameterIndex, byte[] a_x) throws SQLException {
		dGetWrappedPS().setBytes(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setCharacterStream(int, java.io.Reader, int)
	 */
	public void setCharacterStream(int a_parameterIndex, Reader a_reader,
			int a_length) throws SQLException {
		dGetWrappedPS().setCharacterStream(a_parameterIndex, a_reader, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setCharacterStream(int, java.io.Reader, long)
	 */
	public void setCharacterStream(int a_parameterIndex, Reader a_reader,
			long a_length) throws SQLException {
		dGetWrappedPS().setCharacterStream(a_parameterIndex, a_reader, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setCharacterStream(int, java.io.Reader)
	 */
	public void setCharacterStream(int a_parameterIndex, Reader a_reader)
			throws SQLException {
		dGetWrappedPS().setCharacterStream(a_parameterIndex, a_reader);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setClob(int, java.sql.Clob)
	 */
	public void setClob(int a_parameterIndex, Clob a_x) throws SQLException {
		dGetWrappedPS().setClob(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setClob(int, java.io.Reader, long)
	 */
	public void setClob(int a_parameterIndex, Reader a_reader, long a_length)
			throws SQLException {
		dGetWrappedPS().setClob(a_parameterIndex, a_reader, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setClob(int, java.io.Reader)
	 */
	public void setClob(int a_parameterIndex, Reader a_reader)
			throws SQLException {
		dGetWrappedPS().setClob(a_parameterIndex, a_reader);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setDate(int, java.sql.Date, java.util.Calendar)
	 */
	public void setDate(int a_parameterIndex, Date a_x, Calendar a_cal)
			throws SQLException {
		dGetWrappedPS().setDate(a_parameterIndex, a_x, a_cal);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setDate(int, java.sql.Date)
	 */
	public void setDate(int a_parameterIndex, Date a_x) throws SQLException {
		dGetWrappedPS().setDate(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setDouble(int, double)
	 */
	public void setDouble(int a_parameterIndex, double a_x) throws SQLException {
		dGetWrappedPS().setDouble(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setFloat(int, float)
	 */
	public void setFloat(int a_parameterIndex, float a_x) throws SQLException {
		dGetWrappedPS().setFloat(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setInt(int, int)
	 */
	public void setInt(int a_parameterIndex, int a_x) throws SQLException {
		dGetWrappedPS().setInt(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setLong(int, long)
	 */
	public void setLong(int a_parameterIndex, long a_x) throws SQLException {
		dGetWrappedPS().setLong(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setNCharacterStream(int, java.io.Reader, long)
	 */
	public void setNCharacterStream(int a_parameterIndex, Reader a_value,
			long a_length) throws SQLException {
		dGetWrappedPS().setNCharacterStream(a_parameterIndex, a_value, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setNCharacterStream(int, java.io.Reader)
	 */
	public void setNCharacterStream(int a_parameterIndex, Reader a_value)
			throws SQLException {
		dGetWrappedPS().setNCharacterStream(a_parameterIndex, a_value);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setNClob(int, java.sql.NClob)
	 */
	public void setNClob(int a_parameterIndex, NClob a_value)
			throws SQLException {
		dGetWrappedPS().setNClob(a_parameterIndex, a_value);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setNClob(int, java.io.Reader, long)
	 */
	public void setNClob(int a_parameterIndex, Reader a_reader, long a_length)
			throws SQLException {
		dGetWrappedPS().setNClob(a_parameterIndex, a_reader, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setNClob(int, java.io.Reader)
	 */
	public void setNClob(int a_parameterIndex, Reader a_reader)
			throws SQLException {
		dGetWrappedPS().setNClob(a_parameterIndex, a_reader);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setNString(int, java.lang.String)
	 */
	public void setNString(int a_parameterIndex, String a_value)
			throws SQLException {
		dGetWrappedPS().setNString(a_parameterIndex, a_value);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setNull(int, int, java.lang.String)
	 */
	public void setNull(int a_parameterIndex, int a_sqlType, String a_typeName)
			throws SQLException {
		dGetWrappedPS().setNull(a_parameterIndex, a_sqlType, a_typeName);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setNull(int, int)
	 */
	public void setNull(int a_parameterIndex, int a_sqlType)
			throws SQLException {
		dGetWrappedPS().setNull(a_parameterIndex, a_sqlType);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setObject(int, java.lang.Object, int, int)
	 */
	public void setObject(int a_parameterIndex, Object a_x,
			int a_targetSqlType, int a_scaleOrLength) throws SQLException {
		dGetWrappedPS().setObject(a_parameterIndex, a_x, a_targetSqlType,
				a_scaleOrLength);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setObject(int, java.lang.Object, int)
	 */
	public void setObject(int a_parameterIndex, Object a_x, int a_targetSqlType)
			throws SQLException {
		dGetWrappedPS().setObject(a_parameterIndex, a_x, a_targetSqlType);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setObject(int, java.lang.Object)
	 */
	public void setObject(int a_parameterIndex, Object a_x) throws SQLException {
		dGetWrappedPS().setObject(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setRef(int, java.sql.Ref)
	 */
	public void setRef(int a_parameterIndex, Ref a_x) throws SQLException {
		dGetWrappedPS().setRef(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setRowId(int, java.sql.RowId)
	 */
	public void setRowId(int a_parameterIndex, RowId a_x) throws SQLException {
		dGetWrappedPS().setRowId(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setShort(int, short)
	 */
	public void setShort(int a_parameterIndex, short a_x) throws SQLException {
		dGetWrappedPS().setShort(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setSQLXML(int, java.sql.SQLXML)
	 */
	public void setSQLXML(int a_parameterIndex, SQLXML a_xmlObject)
			throws SQLException {
		dGetWrappedPS().setSQLXML(a_parameterIndex, a_xmlObject);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setString(int, java.lang.String)
	 */
	public void setString(int a_parameterIndex, String a_x) throws SQLException {
		dGetWrappedPS().setString(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setTime(int, java.sql.Time, java.util.Calendar)
	 */
	public void setTime(int a_parameterIndex, Time a_x, Calendar a_cal)
			throws SQLException {
		dGetWrappedPS().setTime(a_parameterIndex, a_x, a_cal);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setTime(int, java.sql.Time)
	 */
	public void setTime(int a_parameterIndex, Time a_x) throws SQLException {
		dGetWrappedPS().setTime(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setTimestamp(int, java.sql.Timestamp, java.util.Calendar)
	 */
	public void setTimestamp(int a_parameterIndex, Timestamp a_x, Calendar a_cal)
			throws SQLException {
		dGetWrappedPS().setTimestamp(a_parameterIndex, a_x, a_cal);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setTimestamp(int, java.sql.Timestamp)
	 */
	public void setTimestamp(int a_parameterIndex, Timestamp a_x)
			throws SQLException {
		dGetWrappedPS().setTimestamp(a_parameterIndex, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setUnicodeStream(int, java.io.InputStream, int)
	 */
	@Deprecated
	public void setUnicodeStream(int a_parameterIndex, InputStream a_x,
			int a_length) throws SQLException {
		dGetWrappedPS().setUnicodeStream(a_parameterIndex, a_x, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.PreparedStatement#setUnicodeStream(int, java.io.InputStream, int)
	 */
	public void setURL(int a_parameterIndex, URL a_x) throws SQLException {
		dGetWrappedPS().setURL(a_parameterIndex, a_x);
	}


	///////////////////////////////////
	// IMPLEMENT/DELEGATE (CallableStatement)
	//
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getArray(int)
	 */
	public Array getArray(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getArray(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getArray(java.lang.String)
	 */
	public Array getArray(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getArray(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getBigDecimal(int, int)
	 */
	@Deprecated
	public BigDecimal getBigDecimal(int a_parameterIndex, int a_scale)
			throws SQLException {
		return dGetWrappedCS().getBigDecimal(a_parameterIndex, a_scale);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getBigDecimal(int)
	 */
	public BigDecimal getBigDecimal(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getBigDecimal(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getBigDecimal(java.lang.String)
	 */
	public BigDecimal getBigDecimal(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getBigDecimal(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getBlob(int)
	 */
	public Blob getBlob(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getBlob(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getBlob(java.lang.String)
	 */
	public Blob getBlob(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getBlob(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getBoolean(int)
	 */
	public boolean getBoolean(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getBoolean(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getBoolean(java.lang.String)
	 */
	public boolean getBoolean(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getBoolean(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getByte(int)
	 */
	public byte getByte(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getByte(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getByte(java.lang.String)
	 */
	public byte getByte(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getByte(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getBytes(int)
	 */
	public byte[] getBytes(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getBytes(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getBytes(java.lang.String)
	 */
	public byte[] getBytes(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getBytes(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getCharacterStream(int)
	 */
	public Reader getCharacterStream(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getCharacterStream(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getCharacterStream(java.lang.String)
	 */
	public Reader getCharacterStream(String a_parameterName)
			throws SQLException {
		return dGetWrappedCS().getCharacterStream(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getClob(int)
	 */
	public Clob getClob(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getClob(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getClob(java.lang.String)
	 */
	public Clob getClob(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getClob(a_parameterName);
	}
	/**
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getDate(int, java.util.Calendar)
	 */
	public Date getDate(int a_parameterIndex, Calendar a_cal)
			throws SQLException {
		return dGetWrappedCS().getDate(a_parameterIndex, a_cal);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getDate(int)
	 */
	public Date getDate(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getDate(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getDate(java.lang.String, java.util.Calendar)
	 */
	public Date getDate(String a_parameterName, Calendar a_cal)
			throws SQLException {
		return dGetWrappedCS().getDate(a_parameterName, a_cal);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getDate(java.lang.String)
	 */
	public Date getDate(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getDate(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getDouble(int)
	 */
	public double getDouble(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getDouble(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getDouble(java.lang.String)
	 */
	public double getDouble(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getDouble(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getFloat(int)
	 */
	public float getFloat(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getFloat(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getFloat(java.lang.String)
	 */
	public float getFloat(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getFloat(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getInt(int)
	 */
	public int getInt(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getInt(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getInt(java.lang.String)
	 */
	public int getInt(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getInt(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getLong(int)
	 */
	public long getLong(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getLong(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getLong(java.lang.String)
	 */
	public long getLong(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getLong(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getNCharacterStream(int)
	 */
	public Reader getNCharacterStream(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getNCharacterStream(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getNCharacterStream(java.lang.String)
	 */
	public Reader getNCharacterStream(String a_parameterName)
			throws SQLException {
		return dGetWrappedCS().getNCharacterStream(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getNClob(int)
	 */
	public NClob getNClob(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getNClob(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getNClob(java.lang.String)
	 */
	public NClob getNClob(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getNClob(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getNString(int)
	 */
	public String getNString(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getNString(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getNString(java.lang.String)
	 */
	public String getNString(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getNString(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getObject(int, java.util.Map)
	 */
	public Object getObject(int a_parameterIndex, Map<String, Class<?>> a_map)
			throws SQLException {
		return dGetWrappedCS().getObject(a_parameterIndex, a_map);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getObject(int)
	 */
	public Object getObject(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getObject(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getObject(java.lang.String, java.util.Map)
	 */
	public Object getObject(String a_parameterName, Map<String, Class<?>> a_map)
			throws SQLException {
		return dGetWrappedCS().getObject(a_parameterName, a_map);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getObject(java.lang.String)
	 */
	public Object getObject(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getObject(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getRef(int)
	 */
	public Ref getRef(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getRef(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getRef(java.lang.String)
	 */
	public Ref getRef(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getRef(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getRowId(int)
	 */
	public RowId getRowId(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getRowId(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getRowId(java.lang.String)
	 */
	public RowId getRowId(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getRowId(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getShort(int)
	 */
	public short getShort(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getShort(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getShort(java.lang.String)
	 */
	public short getShort(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getShort(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getSQLXML(int)
	 */
	public SQLXML getSQLXML(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getSQLXML(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getSQLXML(java.lang.String)
	 */
	public SQLXML getSQLXML(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getSQLXML(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getString(int)
	 */
	public String getString(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getString(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getString(java.lang.String)
	 */
	public String getString(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getString(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getTime(int, java.util.Calendar)
	 */
	public Time getTime(int a_parameterIndex, Calendar a_cal)
			throws SQLException {
		return dGetWrappedCS().getTime(a_parameterIndex, a_cal);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getTime(int)
	 */
	public Time getTime(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getTime(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getTime(java.lang.String, java.util.Calendar)
	 */
	public Time getTime(String a_parameterName, Calendar a_cal)
			throws SQLException {
		return dGetWrappedCS().getTime(a_parameterName, a_cal);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getTime(java.lang.String)
	 */
	public Time getTime(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getTime(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getTimestamp(int, java.util.Calendar)
	 */
	public Timestamp getTimestamp(int a_parameterIndex, Calendar a_cal)
			throws SQLException {
		return dGetWrappedCS().getTimestamp(a_parameterIndex, a_cal);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getTimestamp(int)
	 */
	public Timestamp getTimestamp(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getTimestamp(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getTimestamp(java.lang.String, java.util.Calendar)
	 */
	public Timestamp getTimestamp(String a_parameterName, Calendar a_cal)
			throws SQLException {
		return dGetWrappedCS().getTimestamp(a_parameterName, a_cal);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getTimestamp(java.lang.String)
	 */
	public Timestamp getTimestamp(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getTimestamp(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getURL(int)
	 */
	public URL getURL(int a_parameterIndex) throws SQLException {
		return dGetWrappedCS().getURL(a_parameterIndex);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#getURL(java.lang.String)
	 */
	public URL getURL(String a_parameterName) throws SQLException {
		return dGetWrappedCS().getURL(a_parameterName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#registerOutParameter(int, int, int)
	 */
	public void registerOutParameter(int a_parameterIndex, int a_sqlType,
			int a_scale) throws SQLException {
		dGetWrappedCS().registerOutParameter(a_parameterIndex, a_sqlType, a_scale);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#registerOutParameter(int, int, java.lang.String)
	 */
	public void registerOutParameter(int a_parameterIndex, int a_sqlType,
			String a_typeName) throws SQLException {
		dGetWrappedCS().registerOutParameter(a_parameterIndex, a_sqlType, a_typeName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#registerOutParameter(int, int)
	 */
	public void registerOutParameter(int a_parameterIndex, int a_sqlType)
			throws SQLException {
		dGetWrappedCS().registerOutParameter(a_parameterIndex, a_sqlType);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#registerOutParameter(java.lang.String, int, int)
	 */
	public void registerOutParameter(String a_parameterName, int a_sqlType,
			int a_scale) throws SQLException {
		dGetWrappedCS().registerOutParameter(a_parameterName, a_sqlType, a_scale);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#registerOutParameter(java.lang.String, int, java.lang.String)
	 */
	public void registerOutParameter(String a_parameterName, int a_sqlType,
			String a_typeName) throws SQLException {
		dGetWrappedCS().registerOutParameter(a_parameterName, a_sqlType, a_typeName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#registerOutParameter(java.lang.String, int)
	 */
	public void registerOutParameter(String a_parameterName, int a_sqlType)
			throws SQLException {
		dGetWrappedCS().registerOutParameter(a_parameterName, a_sqlType);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setAsciiStream(java.lang.String, java.io.InputStream, int)
	 */
	public void setAsciiStream(String a_parameterName, InputStream a_x,
			int a_length) throws SQLException {
		dGetWrappedCS().setAsciiStream(a_parameterName, a_x, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setAsciiStream(java.lang.String, java.io.InputStream, long)
	 */
	public void setAsciiStream(String a_parameterName, InputStream a_x,
			long a_length) throws SQLException {
		dGetWrappedCS().setAsciiStream(a_parameterName, a_x, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setAsciiStream(java.lang.String, java.io.InputStream)
	 */
	public void setAsciiStream(String a_parameterName, InputStream a_x)
			throws SQLException {
		dGetWrappedCS().setAsciiStream(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setBigDecimal(java.lang.String, java.math.BigDecimal)
	 */
	public void setBigDecimal(String a_parameterName, BigDecimal a_x)
			throws SQLException {
		dGetWrappedCS().setBigDecimal(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setBinaryStream(java.lang.String, java.io.InputStream, int)
	 */
	public void setBinaryStream(String a_parameterName, InputStream a_x,
			int a_length) throws SQLException {
		dGetWrappedCS().setBinaryStream(a_parameterName, a_x, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setBinaryStream(java.lang.String, java.io.InputStream, long)
	 */
	public void setBinaryStream(String a_parameterName, InputStream a_x,
			long a_length) throws SQLException {
		dGetWrappedCS().setBinaryStream(a_parameterName, a_x, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setBinaryStream(java.lang.String, java.io.InputStream)
	 */
	public void setBinaryStream(String a_parameterName, InputStream a_x)
			throws SQLException {
		dGetWrappedCS().setBinaryStream(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setBlob(java.lang.String, java.sql.Blob)
	 */
	public void setBlob(String a_parameterName, Blob a_x) throws SQLException {
		dGetWrappedCS().setBlob(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setBlob(java.lang.String, java.io.InputStream, long)
	 */
	public void setBlob(String a_parameterName, InputStream a_inputStream,
			long a_length) throws SQLException {
		dGetWrappedCS().setBlob(a_parameterName, a_inputStream, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setBlob(java.lang.String, java.io.InputStream)
	 */
	public void setBlob(String a_parameterName, InputStream a_inputStream)
			throws SQLException {
		dGetWrappedCS().setBlob(a_parameterName, a_inputStream);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setBoolean(java.lang.String, boolean)
	 */
	public void setBoolean(String a_parameterName, boolean a_x)
			throws SQLException {
		dGetWrappedCS().setBoolean(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setByte(java.lang.String, byte)
	 */
	public void setByte(String a_parameterName, byte a_x) throws SQLException {
		dGetWrappedCS().setByte(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setBytes(java.lang.String, byte[])
	 */
	public void setBytes(String a_parameterName, byte[] a_x)
			throws SQLException {
		dGetWrappedCS().setBytes(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setCharacterStream(java.lang.String, java.io.Reader, int)
	 */
	public void setCharacterStream(String a_parameterName, Reader a_reader,
			int a_length) throws SQLException {
		dGetWrappedCS().setCharacterStream(a_parameterName, a_reader, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setCharacterStream(java.lang.String, java.io.Reader, long)
	 */
	public void setCharacterStream(String a_parameterName, Reader a_reader,
			long a_length) throws SQLException {
		dGetWrappedCS().setCharacterStream(a_parameterName, a_reader, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setCharacterStream(java.lang.String, java.io.Reader)
	 */
	public void setCharacterStream(String a_parameterName, Reader a_reader)
			throws SQLException {
		dGetWrappedCS().setCharacterStream(a_parameterName, a_reader);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setClob(java.lang.String, java.sql.Clob)
	 */
	public void setClob(String a_parameterName, Clob a_x) throws SQLException {
		dGetWrappedCS().setClob(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setClob(java.lang.String, java.io.Reader, long)
	 */
	public void setClob(String a_parameterName, Reader a_reader, long a_length)
			throws SQLException {
		dGetWrappedCS().setClob(a_parameterName, a_reader, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setClob(java.lang.String, java.io.Reader)
	 */
	public void setClob(String a_parameterName, Reader a_reader)
			throws SQLException {
		dGetWrappedCS().setClob(a_parameterName, a_reader);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setDate(java.lang.String, java.sql.Date, java.util.Calendar)
	 */
	public void setDate(String a_parameterName, Date a_x, Calendar a_cal)
			throws SQLException {
		dGetWrappedCS().setDate(a_parameterName, a_x, a_cal);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setDate(java.lang.String, java.sql.Date)
	 */
	public void setDate(String a_parameterName, Date a_x) throws SQLException {
		dGetWrappedCS().setDate(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setDouble(java.lang.String, double)
	 */
	public void setDouble(String a_parameterName, double a_x)
			throws SQLException {
		dGetWrappedCS().setDouble(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setFloat(java.lang.String, float)
	 */
	public void setFloat(String a_parameterName, float a_x) throws SQLException {
		dGetWrappedCS().setFloat(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setInt(java.lang.String, int)
	 */
	public void setInt(String a_parameterName, int a_x) throws SQLException {
		dGetWrappedCS().setInt(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setLong(java.lang.String, long)
	 */
	public void setLong(String a_parameterName, long a_x) throws SQLException {
		dGetWrappedCS().setLong(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setNCharacterStream(java.lang.String, java.io.Reader, long)
	 */
	public void setNCharacterStream(String a_parameterName, Reader a_value,
			long a_length) throws SQLException {
		dGetWrappedCS().setNCharacterStream(a_parameterName, a_value, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setNCharacterStream(java.lang.String, java.io.Reader)
	 */
	public void setNCharacterStream(String a_parameterName, Reader a_value)
			throws SQLException {
		dGetWrappedCS().setNCharacterStream(a_parameterName, a_value);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setNClob(java.lang.String, java.sql.NClob)
	 */
	public void setNClob(String a_parameterName, NClob a_value)
			throws SQLException {
		dGetWrappedCS().setNClob(a_parameterName, a_value);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setNClob(java.lang.String, java.io.Reader, long)
	 */
	public void setNClob(String a_parameterName, Reader a_reader, long a_length)
			throws SQLException {
		dGetWrappedCS().setNClob(a_parameterName, a_reader, a_length);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setNClob(java.lang.String, java.io.Reader)
	 */
	public void setNClob(String a_parameterName, Reader a_reader)
			throws SQLException {
		dGetWrappedCS().setNClob(a_parameterName, a_reader);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setNString(java.lang.String, java.lang.String)
	 */
	public void setNString(String a_parameterName, String a_value)
			throws SQLException {
		dGetWrappedCS().setNString(a_parameterName, a_value);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setNull(java.lang.String, int, java.lang.String)
	 */
	public void setNull(String a_parameterName, int a_sqlType, String a_typeName)
			throws SQLException {
		dGetWrappedCS().setNull(a_parameterName, a_sqlType, a_typeName);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setNull(java.lang.String, int)
	 */
	public void setNull(String a_parameterName, int a_sqlType)
			throws SQLException {
		dGetWrappedCS().setNull(a_parameterName, a_sqlType);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setObject(java.lang.String, java.lang.Object, int, int)
	 */
	public void setObject(String a_parameterName, Object a_x,
			int a_targetSqlType, int a_scale) throws SQLException {
		dGetWrappedCS().setObject(a_parameterName, a_x, a_targetSqlType, a_scale);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setObject(java.lang.String, java.lang.Object, int)
	 */
	public void setObject(String a_parameterName, Object a_x,
			int a_targetSqlType) throws SQLException {
		dGetWrappedCS().setObject(a_parameterName, a_x, a_targetSqlType);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setObject(java.lang.String, java.lang.Object)
	 */
	public void setObject(String a_parameterName, Object a_x)
			throws SQLException {
		dGetWrappedCS().setObject(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setRowId(java.lang.String, java.sql.RowId)
	 */
	public void setRowId(String a_parameterName, RowId a_x) throws SQLException {
		dGetWrappedCS().setRowId(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setShort(java.lang.String, short)
	 */
	public void setShort(String a_parameterName, short a_x) throws SQLException {
		dGetWrappedCS().setShort(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setSQLXML(java.lang.String, java.sql.SQLXML)
	 */
	public void setSQLXML(String a_parameterName, SQLXML a_xmlObject)
			throws SQLException {
		dGetWrappedCS().setSQLXML(a_parameterName, a_xmlObject);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setString(java.lang.String, java.lang.String)
	 */
	public void setString(String a_parameterName, String a_x)
			throws SQLException {
		dGetWrappedCS().setString(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setTime(java.lang.String, java.sql.Time, java.util.Calendar)
	 */
	public void setTime(String a_parameterName, Time a_x, Calendar a_cal)
			throws SQLException {
		dGetWrappedCS().setTime(a_parameterName, a_x, a_cal);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setTime(java.lang.String, java.sql.Time)
	 */
	public void setTime(String a_parameterName, Time a_x) throws SQLException {
		dGetWrappedCS().setTime(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setTimestamp(java.lang.String, java.sql.Timestamp, java.util.Calendar)
	 */
	public void setTimestamp(String a_parameterName, Timestamp a_x,
			Calendar a_cal) throws SQLException {
		dGetWrappedCS().setTimestamp(a_parameterName, a_x, a_cal);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setTimestamp(java.lang.String, java.sql.Timestamp)
	 */
	public void setTimestamp(String a_parameterName, Timestamp a_x)
			throws SQLException {
		dGetWrappedCS().setTimestamp(a_parameterName, a_x);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#setURL(java.lang.String, java.net.URL)
	 */
	public void setURL(String a_parameterName, URL a_val) throws SQLException {
		dGetWrappedCS().setURL(a_parameterName, a_val);
	}
	/* (non-Javadoc)
	 * @see java.sql.CallableStatement#wasNull()
	 */
	public boolean wasNull() throws SQLException {
		return dGetWrappedCS().wasNull();
	}
///////////////////////////////////////////////////////////
/// BOILERPLATE SECTION (END)
///

}
