package ddbc.impl;

import java.io.*;
import java.sql.Clob;
import java.sql.NClob;
import java.sql.SQLException;

//TODO Interesaría un proxy del Writer/Stream para controlar qué valores se introducen.
/**
 * Base Proxy/Decorator class for a java.sql.NClob.
 * It's just a filter-delegate implementation, ready to override in a subclass.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class DNClob implements NClob {
	/** JpConnection used to create the Clob. */
	private DConnection i_connection;
	/** Wrapped NClob object. */
	private NClob i_wrapped;
	
	// Default constructor, just in case a subclass needs it.
	protected DNClob() {
		super();
	}

	/**
	 * @param a_connection
	 * @param a_wrapped
	 */
	public DNClob(DConnection a_connection, NClob a_wrapped) {
		super();
		i_connection = a_connection;
		i_wrapped = a_wrapped;
	}
	/**
	 * Return the wrapped nclob object.
	 */
	public NClob getWrapped() {
		return i_wrapped;
	}

	/* (non-Javadoc)
	 * @see java.sql.Clob#free()
	 */
	public void free() throws SQLException {
		i_wrapped.free();
	}

	/* (non-Javadoc)
	 * @see java.sql.Clob#getAsciiStream()
	 */
	public InputStream getAsciiStream() throws SQLException {
		return i_wrapped.getAsciiStream();
	}

	/* (non-Javadoc)
	 * @see java.sql.Clob#getCharacterStream()
	 */
	public Reader getCharacterStream() throws SQLException {
		return i_wrapped.getCharacterStream();
	}

	/* (non-Javadoc)
	 * @see java.sql.Clob#getCharacterStream(long, long)
	 */
	public Reader getCharacterStream(long a_pos, long a_length)
			throws SQLException {
		return i_wrapped.getCharacterStream(a_pos, a_length);
	}

	/* (non-Javadoc)
	 * @see java.sql.Clob#getSubString(long, int)
	 */
	public String getSubString(long a_pos, int a_length) throws SQLException {
		return i_wrapped.getSubString(a_pos, a_length);
	}

	/* (non-Javadoc)
	 * @see java.sql.Clob#length()
	 */
	public long length() throws SQLException {
		return i_wrapped.length();
	}

	/* (non-Javadoc)
	 * @see java.sql.Clob#position(java.sql.Clob, long)
	 */
	public long position(Clob a_searchstr, long a_start) throws SQLException {
		return i_wrapped.position(a_searchstr, a_start);
	}

	/**
	/* (non-Javadoc)
	 * @see java.sql.Clob#position(java.lang.String, long)
	 */
	public long position(String a_searchstr, long a_start) throws SQLException {
		return i_wrapped.position(a_searchstr, a_start);
	}

	/* (non-Javadoc)
	 * @see java.sql.Clob#setAsciiStream(long)
	 */
	public OutputStream setAsciiStream(long a_pos) throws SQLException {
		return i_wrapped.setAsciiStream(a_pos);
	}

	/* (non-Javadoc)
	 * @see java.sql.Clob#setCharacterStream(long)
	 */
	public Writer setCharacterStream(long a_pos) throws SQLException {
		return i_wrapped.setCharacterStream(a_pos);
	}

	/* (non-Javadoc)
	 * @see java.sql.Clob#setString(long, java.lang.String, int, int)
	 */
	public int setString(long a_pos, String a_str, int a_offset, int a_len)
			throws SQLException {
		return i_wrapped.setString(a_pos, a_str, a_offset, a_len);
	}

	/* (non-Javadoc)
	 * @see java.sql.Clob#setString(long, java.lang.String)
	 */
	public int setString(long a_pos, String a_str) throws SQLException {
		return i_wrapped.setString(a_pos, a_str);
	}

	/* (non-Javadoc)
	 * @see java.sql.Clob#truncate(long)
	 */
	public void truncate(long a_len) throws SQLException {
		i_wrapped.truncate(a_len);
	}

}
