package ddbc.impl;

import java.sql.Connection;
import java.sql.Driver;
import java.sql.SQLException;
import java.util.Properties;

import ddbc.DDriver;
import ddbc.DDriverConnectionFactory;

public class DSimpleConnectionFactory implements DDriverConnectionFactory {
	public static DSimpleConnectionFactory createBackEnd(Driver driver, DWrapperFactory wrapper) {
		DSimpleConnectionFactory instance = new DSimpleConnectionFactory();
		instance.i_backendDriver = driver;
		instance.i_wrapper = wrapper;
		return instance;
	}
	
	public static DSimpleConnectionFactory createDelegator(DDriverConnectionFactory delegate, DWrapperFactory wrapper) {
		DSimpleConnectionFactory instance = new DSimpleConnectionFactory();
		instance.i_delegate = delegate;
		instance.i_wrapper = wrapper;
		return instance;
	}
	
	private Driver i_backendDriver;
	private DDriverConnectionFactory i_delegate;
	private DWrapperFactory i_wrapper;
	
	public Connection createConnection(String url, Properties connProperties) throws SQLException {
		Connection l_result = null;
		if (i_backendDriver != null) {
			l_result = i_backendDriver.connect(DDriver.trimUrl(url), connProperties);
		} else if (i_delegate != null) {
			l_result = i_delegate.createConnection(url, connProperties);
		} else {
			throw new SQLException("ConnectionFactory without setting can't return connection");
		}
		if (i_wrapper != null) {
			l_result = i_wrapper.wrapConnection(l_result);
		}
		return l_result;
	}

}
