package ddbc.impl;

import java.sql.*;

import ddbc.DDriverConnectionFactory;
import ddbc.cpn2.impl.CpConnection;
import ddbc.cpn2.impl.CpRef;
import ddbc.cpn2.impl.CpStruct;

/**
 * Factory instance used to produce many wrappers for common jdbc objects, in
 *   order to perform the jdbc-decoration/proxying.
 * This class is intended to be extended to define more specific wrappers.
 * @author F.Javier Aranda (fjarandag@gmail.com)
 */
public class DWrapperFactory {
	/** Singleton instance of the base WrapperFactory. */
	private static DWrapperFactory s_instance = new DWrapperFactory();
	/**
	 * Obtains an operative instance of the Wrapper Factory
	 * @return JspWrapperFactory instance
	 */
	public static DWrapperFactory instance() {
		return s_instance;
	}


	/**
	 * Obtains a wrapper connection which delegates on the given one.
	 * @param wrapped Given actual connection.
	 * @return Wrapper connection.
	 * @throws SQLException TODO
	 */
	public Connection wrapConnection(Connection wrapped) throws SQLException {
		return wrapped;
	}
	
	public DDriverConnectionFactory wrapConnectionFactory(DDriverConnectionFactory factory) {
		return factory;
	}

	/**
	 * Obtains a wrapper Statement which delegates on the given one.
	 * @param wrapped Given actual statement
	 * @param conn TODO
	 * @return Wrapper statement
	 * @throws SQLException TODO
	 */
	public Statement wrapStatement(Statement wrapped, Connection conn) throws SQLException {
		return wrapped;
	}
	
	/**
	 * Obtains a wrapper PreparedStatement which delegates on the given one.
	 * @param conn TODO
	 * @param conn Associated wrapper connection.
	 * @param ps Given actual prepared statement
	 * @return  Wrapper prepared statement
	 * @throws SQLException 
	 */
	public PreparedStatement wrapPreparedStatement(PreparedStatement wrapped, Connection conn) throws SQLException {
		return wrapped;
	}
	
	/**
	 * Obtains a wrapper CallableStatement which delegates on the given one.
	 * @param wrapped Given actual callable statement
	 * @param conn TODO
	 * @param conn Associated wrapper connection.
	 * @return  Wrapper callable statement
	 * @throws SQLException TODO
	 */
	public CallableStatement wrapCallableStatement(CallableStatement wrapped, Connection conn) throws SQLException {
		return wrapped;
	}
	
	/**
	 * Obtains a wrapper Blob which delegates on the given one.
	 * @param wrapped Given actual blob object.
	 * @param conn Associated wrapper connection.
	 * @return Wrapper blob object.
	 * @throws SQLException TODO
	 */
	public Blob wrapBlob(Blob wrapped, Connection conn) throws SQLException {
		return wrapped;
	}

	/**
	 * Obtains a wrapper Clob which delegates on the given one.
	 * @param conn Associated wrapper connection.
	 * @param blob Given actual clob object.
	 * @return Wrapper clob object.
	 * @throws SQLException TODO
	 */
	public Clob wrapClob(Clob wrapped, Connection conn) throws SQLException {
		return wrapped;
	}

	/**
	 * Obtains a wrapper NClob which delegates on the given one.
	 * @param conn Associated wrapper connection.
	 * @param blob Given actual nclob object.
	 * @return Wrapper nclob object.
	 * @throws SQLException TODO
	 */
	public NClob wrapNClob(NClob wrapped, Connection conn) throws SQLException {
		return wrapped;
	}

	public ResultSet wrapResultSet(ResultSet wrapped, Statement stmt) throws SQLException {
		return wrapped;
	}

	public Array wrapArray(Array wrapped, Connection rs) throws SQLException {
		return wrapped;
	}
	/** @deprecated Use {@link #wrapRef(Ref, Connection)} */
	public Ref wrapRef(Ref wrapped, ResultSet rs) throws SQLException {
		return wrapped;
	}
	public Ref wrapRef(Ref wrapped, Connection conn) throws SQLException {
		return wrapped;
	}
	public Struct wrapStruct(Struct wrapped, ResultSet rs) throws SQLException {
		return wrapped;
	}

	public Struct wrapStruct(Struct wrapped, Connection conn) throws SQLException {
		return wrapped;
	}

	public Savepoint wrapSavepoint(Savepoint wrapped, Connection conn) throws SQLException {
		return wrapped;
	}

	public DatabaseMetaData wrapDatabaseMetaData(DatabaseMetaData wrapped, Connection conn) throws SQLException {
		return wrapped;
	}
	public ParameterMetaData wrapParameterMetaData(ParameterMetaData wrapped, PreparedStatement ps) throws SQLException {
		return wrapped;
	}
	public ResultSetMetaData  wrapResultSetMetaData(ResultSetMetaData wrapped, ResultSet rs) throws SQLException {
		return wrapped;
	}
	public ResultSetMetaData  wrapResultSetMetaData(ResultSetMetaData wrapped, PreparedStatement ps) throws SQLException {
		return wrapped;
	}
	public SQLXML wrapSqlXml(SQLXML wrapped, Connection conn) throws SQLException {
		return wrapped;
	}
}
