/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.importers;

import java.util.*;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import ddbc.cpn2.st.StatementHandler;
import ddbc.cpn2.st.StatementMatcher;

import ddbc.commons.util.Strings;

public class ImportContext {
	private static Logger s_logger = LoggerFactory.getLogger(ImportContext.class);
	
	// TODO Consider that a handler could be a matcher at the same time.
	//   Is there a reason for separating matchers and handlers?
	private Map<String,Object> i_componentsById = new HashMap<String, Object>();
	private Map<String,NestedImportHandler<?>> i_typesByName = 
			new HashMap<String,NestedImportHandler<?>>();
	private Set<String> i_declaredStates = new HashSet<String>();

	public ImportContext() {
		super();
		i_typesByName.putAll(MapperImporter.BUILTIN_TYPES_IMPORTERS);
	}
	
	public StatementMatcher putMatcher(String idMatcher, StatementMatcher matcher) {
		return (StatementMatcher)i_componentsById.put(idMatcher, matcher);
	}
	public StatementMatcher getMatcher(String idMatcher) {
		return (StatementMatcher)i_componentsById.get(idMatcher);
	}
	public StatementHandler putHandler(String idHandler, StatementHandler handler) {
		return (StatementHandler)i_componentsById.put(idHandler, handler);
	}
	public StatementHandler getHandler(String idHandler) {
		return (StatementHandler)i_componentsById.get(idHandler);
	}
	
	@SuppressWarnings("unchecked")
	public <T> T referencedComponent(Map<String,String> attributes) {
		String l_ref = attributes.get("ref");
		if (Strings.isEmptyOrWhiteSpace(l_ref)) {
			return null;
		} else {
			T l_referenced = (T)i_componentsById.get(l_ref);
			if (l_referenced == null) {
				s_logger.warn("Found undefined reference to " + l_ref);
			}
			return l_referenced;
		}
	}
	
	public void registerComponent(Map<String,String> attributes, Object component) {
		String l_id = attributes.get("id");
		if (! Strings.isEmptyOrWhiteSpace(l_id)) {
			Object l_previous = i_componentsById.put(l_id, component);
			if (l_previous != null) {
				s_logger.warn("Component already registered for id {}", l_id);
			}
		}
	}
	
	
	public Set<String> declaredStates() {
		return i_declaredStates;
	}
	
	public Map<String,NestedImportHandler<?>> typesByName() {
		return i_typesByName;
	}
	
}
