/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.importers;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;

import org.apache.commons.xmlio.in.SimplePath;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.xml.sax.helpers.AttributesImpl;

import ddbc.cpn2.st.HandlerRegex;
import ddbc.commons.util.XmlUtils;

public class ImporterHandlerRegex implements NestedImportHandler<HandlerRegex> {
	private static final String ATTRIBUTE_RULE_EXCLUSIONGROUP = "exclusion-group";
	public static final String SUBPATH_RULE = "/rx-rule";
	public static final String SUBPATH_SUBSTMATCH = "/rx-rule/rx-match";
	public static final String SUBPATH_SUBSTREPLACE = "/rx-rule/rx-subst";

	private static Logger s_logger = LoggerFactory.getLogger(ImporterHandlerRegex.class);

	private String i_basePath;
	private HandlerRegex i_built;

	private String i_currentExclusion;
	private Pattern i_currentMatch;
	private String i_currentSubstitution;
	
	private Map<String,String> i_mapAttributesRoot;
	private List<Pattern> i_patterns;
	private List<String> i_replacements;
	private List<String> i_exclusions;
	
	public ImporterHandlerRegex() {
		super();
	}
	
	public void start(ImportContext context, String basePath) {
		i_basePath = basePath;
		// Reset, as the importer might be reused.
		i_built = null;
	}

	public HandlerRegex getBuilt() {
		return i_built;
	}

	public void startElement(SimplePath path, String name,
			AttributesImpl attributes, String leadingCDdata) {
		if (path.matches(i_basePath)) {
			i_mapAttributesRoot = XmlUtils.attributesToMap(attributes);
			i_patterns = new ArrayList<Pattern>();
			i_replacements = new ArrayList<String>();
			i_exclusions = new ArrayList<String>();
			
			// Finish element processing at the end.
		} else if (path.matches(i_basePath + SUBPATH_RULE)) {
			i_currentExclusion = attributes.getValue(ATTRIBUTE_RULE_EXCLUSIONGROUP);
			i_currentMatch = null;
			i_currentSubstitution = null;
			
			// Finish element processing at the end.
		} else if (path.matches(i_basePath + SUBPATH_SUBSTMATCH)) {
			String l_strMatch = leadingCDdata;
			try {
				i_currentMatch = Pattern.compile(l_strMatch, Pattern.CASE_INSENSITIVE);
			} catch(Exception e) {
				// TODO Make the built instance be null (or some alternative fail-fast).
				// TODO Why is varargs not working properly?
				s_logger.error("Invalid pattern {} @ type {}:{}", new Object[]{l_strMatch, i_mapAttributesRoot.get("type"), e.toString()});
			}
		} else if (path.matches(i_basePath + SUBPATH_SUBSTREPLACE)) {
			i_currentSubstitution = leadingCDdata;
		} else {
			// TODO Unexpected
		}
	}

	public void endElement(SimplePath path, String name) {
		if (path.matches(i_basePath)) {
			i_built = new HandlerRegex(i_mapAttributesRoot,i_patterns, i_replacements, i_exclusions);
		} else if (path.matches(i_basePath + SUBPATH_RULE)) {
			// TODO Consider controlling that match has a pattern
			//  At least, in case of bad expression (match==null), serves as whistle-blower of bad configuration.
			i_patterns.add(i_currentMatch);
			i_replacements.add(i_currentSubstitution);
			i_exclusions.add(i_currentExclusion);
		}
	}

	public void cData(SimplePath a_path, String a_cdata) {
		// Nothing to do
	}
	public void startDocument() {
		// Nothing to do
	}
	public void endDocument() {
		// Nothing to do
	}

}
