/*
 * ======================================================================== DDBC : Free for Java(tm) platform
 * ========================================================================
 * 
 * (C) Copyright 2010, by Fco.Javier Aranda.
 * 
 * Project Info: http://www.gorrion.info/ddbc/
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * 
 * [Java is a trademark or registered trademark of Oracle Corporation, Inc. in the United States and other countries.]
 */
package ddbc.importers;

import java.util.ArrayList;
import java.util.Map;

import org.apache.commons.xmlio.in.SimpleImportHandler;
import org.apache.commons.xmlio.in.SimplePath;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.xml.sax.helpers.AttributesImpl;

import ddbc.cpn2.JdbcMethod;
import ddbc.cpn2.log.*;
import ddbc.commons.util.FlyWeight;

public class LogEventImporter implements SimpleImportHandler {
	private static Logger LOGGER = LoggerFactory.getLogger(LogEventImporter.class);

//	private String i_basePath;
//	private LogEvent i_built;
//	private Map<String,String> i_startAttributes;
	private LogListener i_listener;

	public LogEventImporter (String basePath, Map<String,String> attributes, LogListener listener) {
		super();
		
//		i_basePath = basePath;
//		i_startAttributes = attributes;
		i_listener = listener;
	}
	
	// From event attributes
	private LogEventType cur_type;
	private String cur_conn;
	private String cur_src;
	private JdbcMethod cur_method;
	private String cur_tag;
	private long cur_start;
	private long cur_duration;
	// From parameters
	private ArrayList<Object> cur_parameters = new ArrayList<Object>();
	// From Stack
	private ArrayList<StackTraceElement> cur_frames = new ArrayList<StackTraceElement>();
	// From result
	private Object cur_result;
	
	/* (non-Javadoc)
	 * @see org.apache.commons.xmlio.in.SimpleImportHandler#startElement(org.apache.commons.xmlio.in.SimplePath, java.lang.String, org.xml.sax.helpers.AttributesImpl, java.lang.String)
	 */
	@Override
	public void startElement(SimplePath path, String name,
			AttributesImpl attributes, String leadingCDdata) {
		try {
			// TT_LOW Consider if fails should be replicated.
			if (name.equals("call") || name.equals("custom")) {
				// head of event. Initialize variables from attributes.
				if (name.equals("call")) {
					cur_type = LogEventType.METHOD_SUCCESS;
				} else if (name.equals("custom")) {
					cur_type = LogEventType.CUSTOM;
				}
				cur_conn = attributes.getValue("conn");
				cur_src = attributes.getValue("src");
				String l_methodName = attributes.getValue("m");
				if (l_methodName != null) {
					cur_method = JdbcMethod.valueOf(l_methodName);
					//cur_method = JdbcMethod.methodsById.get(l_methodName);
				}
				cur_tag = attributes.getValue("tag");
				String l_strStart = attributes.getValue("start");
				if (l_strStart == null) {
					cur_start = 0L;
				} else {
					cur_start = FlyWeight.getDateFormat(
							XmlWriterListener.TMS_FORMAT).parse(l_strStart)
							.getTime();
				}
				String l_strDuration = attributes.getValue("d");
				if (l_strDuration == null) {
					l_strDuration = "0";
				}
				cur_duration = Long.parseLong(l_strDuration);

				cur_parameters.clear();
				cur_result = null;
				cur_frames.clear();

				// Pending operation at end of element...
			} else if (name.equals("p")) {
				// Event parameter
				// TT_LOW Consider converting parameters/result to other type.
				cur_parameters.add(leadingCDdata);
			} else if (name.equals("r")) {
				// Event result
				cur_result = leadingCDdata;
			} else if (name.equals("f")) {
				// Stack frame
				// <f class="uwiki.evol.SampleTest" m="testListCurrent" f="SampleTest.java" l="92"/>
				String l_class = attributes.getValue("class");
				String l_method = attributes.getValue("m");
				String l_file = attributes.getValue("f");
				int l_line = Integer.parseInt(attributes.getValue("l"));
				StackTraceElement l_elem = new StackTraceElement(l_class,
						l_method, l_file, l_line);
				// Lots of stacktrace elements can be repeated
				l_elem = FlyWeight.getPreferred(l_elem);
				cur_frames.add(l_elem);
			}
		} catch (Exception e) {
			// Let the process continue...
			LOGGER.error("@startElement " + name + " " + cur_src, e);
		} 
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.xmlio.in.SimpleImportHandler#endElement(org.apache.commons.xmlio.in.SimplePath, java.lang.String)
	 */
	@Override
	public void endElement(SimplePath path, String name) {
		try {
			if (name.equals("call") || name.equals("custom")) {
				// Construct event object with the compiled data
				Object[] l_parameters = cur_parameters.toArray();

				StackTraceElement[] l_frames;
				if (cur_frames.isEmpty()) {
					l_frames = null;
				} else {
					l_frames = new StackTraceElement[cur_frames.size()];
					cur_frames.toArray(l_frames);
				}

				LogEvent l_event = new LogEvent(cur_conn, cur_src, cur_type,
						cur_method, cur_tag, cur_start, cur_duration,
						l_parameters, cur_result, l_frames);
				try {
					i_listener.process(l_event);
				} catch(Exception e) {
					LOGGER.error("processing event " + l_event, e);
				}
			}
		} catch (Exception e) {
			// Let the process continue...
			LOGGER.error("@endElement " + name + " " + cur_src, e);
		}
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.xmlio.in.SimpleImportHandler#cData(org.apache.commons.xmlio.in.SimplePath, java.lang.String)
	 */
	@Override
	public void cData(SimplePath path, String cdata) {
		// TODO Auto-generated method stub
		
	}
	
	/* (non-Javadoc)
	 * @see org.apache.commons.xmlio.in.SimpleImportHandler#startDocument()
	 */
	@Override
	public void startDocument() {
		// TODO Auto-generated method stub
		
	}

	/* (non-Javadoc)
	 * @see org.apache.commons.xmlio.in.SimpleImportHandler#endDocument()
	 */
	@Override
	public void endDocument() {
		// TODO Auto-generated method stub
		
	}

}
